Class: Vapi::AssistantFirstMessageMode

Inherits:
Object
  • Object
show all
Defined in:
lib/vapi_server_sdk/types/assistant_first_message_mode.rb

Overview

This is the mode for the first message. Default is 'assistant-speaks-first'. Use:

  • 'assistant-speaks-first' to have the assistant speak first.
  • 'assistant-waits-for-user' to have the assistant wait for the user to speak first.
  • 'assistant-speaks-first-with-model-generated-message' to have the assistant speak first with a message generated by the model based on the conversation state. (assistant.model.messages at call start, call.messages at squad transfer points). @default 'assistant-speaks-first'

Constant Summary collapse

ASSISTANT_SPEAKS_FIRST =
"assistant-speaks-first"
ASSISTANT_SPEAKS_FIRST_WITH_MODEL_GENERATED_MESSAGE =
"assistant-speaks-first-with-model-generated-message"
ASSISTANT_WAITS_FOR_USER =
"assistant-waits-for-user"