Class: Vapi::AzureVoice
- Inherits:
-
Object
- Object
- Vapi::AzureVoice
- Defined in:
- lib/vapi_server_sdk/types/azure_voice.rb
Constant Summary collapse
- OMIT =
Object.new
Instance Attribute Summary collapse
-
#additional_properties ⇒ OpenStruct
readonly
Additional properties unmapped to the current class definition.
-
#chunk_plan ⇒ Vapi::ChunkPlan
readonly
This is the plan for chunking the model output before it is sent to the voice provider.
-
#fallback_plan ⇒ Vapi::FallbackPlan
readonly
This is the plan for voice provider fallbacks in the event that the primary voice provider fails.
-
#speed ⇒ Float
readonly
This is the speed multiplier that will be used.
-
#voice_id ⇒ Vapi::AzureVoiceId
readonly
This is the provider-specific ID that will be used.
Class Method Summary collapse
-
.from_json(json_object:) ⇒ Vapi::AzureVoice
Deserialize a JSON object to an instance of AzureVoice.
-
.validate_raw(obj:) ⇒ Void
Leveraged for Union-type generation, validate_raw attempts to parse the given hash and check each fields type against the current object’s property definitions.
Instance Method Summary collapse
- #initialize(voice_id:, chunk_plan: OMIT, speed: OMIT, fallback_plan: OMIT, additional_properties: nil) ⇒ Vapi::AzureVoice constructor
-
#to_json(*_args) ⇒ String
Serialize an instance of AzureVoice to a JSON object.
Constructor Details
#initialize(voice_id:, chunk_plan: OMIT, speed: OMIT, fallback_plan: OMIT, additional_properties: nil) ⇒ Vapi::AzureVoice
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 |
# File 'lib/vapi_server_sdk/types/azure_voice.rb', line 37 def initialize(voice_id:, chunk_plan: OMIT, speed: OMIT, fallback_plan: OMIT, additional_properties: nil) @voice_id = voice_id @chunk_plan = chunk_plan if chunk_plan != OMIT @speed = speed if speed != OMIT @fallback_plan = fallback_plan if fallback_plan != OMIT @additional_properties = additional_properties @_field_set = { "voiceId": voice_id, "chunkPlan": chunk_plan, "speed": speed, "fallbackPlan": fallback_plan }.reject do |_k, v| v == OMIT end end |
Instance Attribute Details
#additional_properties ⇒ OpenStruct (readonly)
Returns Additional properties unmapped to the current class definition.
22 23 24 |
# File 'lib/vapi_server_sdk/types/azure_voice.rb', line 22 def additional_properties @additional_properties end |
#chunk_plan ⇒ Vapi::ChunkPlan (readonly)
Returns This is the plan for chunking the model output before it is sent to the voice provider.
15 16 17 |
# File 'lib/vapi_server_sdk/types/azure_voice.rb', line 15 def chunk_plan @chunk_plan end |
#fallback_plan ⇒ Vapi::FallbackPlan (readonly)
Returns This is the plan for voice provider fallbacks in the event that the primary voice provider fails.
20 21 22 |
# File 'lib/vapi_server_sdk/types/azure_voice.rb', line 20 def fallback_plan @fallback_plan end |
#speed ⇒ Float (readonly)
Returns This is the speed multiplier that will be used.
17 18 19 |
# File 'lib/vapi_server_sdk/types/azure_voice.rb', line 17 def speed @speed end |
#voice_id ⇒ Vapi::AzureVoiceId (readonly)
Returns This is the provider-specific ID that will be used.
12 13 14 |
# File 'lib/vapi_server_sdk/types/azure_voice.rb', line 12 def voice_id @voice_id end |
Class Method Details
.from_json(json_object:) ⇒ Vapi::AzureVoice
Deserialize a JSON object to an instance of AzureVoice
57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/vapi_server_sdk/types/azure_voice.rb', line 57 def self.from_json(json_object:) struct = JSON.parse(json_object, object_class: OpenStruct) parsed_json = JSON.parse(json_object) if parsed_json["voiceId"].nil? voice_id = nil else voice_id = parsed_json["voiceId"].to_json voice_id = Vapi::AzureVoiceId.from_json(json_object: voice_id) end if parsed_json["chunkPlan"].nil? chunk_plan = nil else chunk_plan = parsed_json["chunkPlan"].to_json chunk_plan = Vapi::ChunkPlan.from_json(json_object: chunk_plan) end speed = parsed_json["speed"] if parsed_json["fallbackPlan"].nil? fallback_plan = nil else fallback_plan = parsed_json["fallbackPlan"].to_json fallback_plan = Vapi::FallbackPlan.from_json(json_object: fallback_plan) end new( voice_id: voice_id, chunk_plan: chunk_plan, speed: speed, fallback_plan: fallback_plan, additional_properties: struct ) end |
.validate_raw(obj:) ⇒ Void
Leveraged for Union-type generation, validate_raw attempts to parse the given
hash and check each fields type against the current object's property
definitions.
101 102 103 104 105 106 |
# File 'lib/vapi_server_sdk/types/azure_voice.rb', line 101 def self.validate_raw(obj:) Vapi::AzureVoiceId.validate_raw(obj: obj.voice_id) obj.chunk_plan.nil? || Vapi::ChunkPlan.validate_raw(obj: obj.chunk_plan) obj.speed&.is_a?(Float) != false || raise("Passed value for field obj.speed is not the expected type, validation failed.") obj.fallback_plan.nil? || Vapi::FallbackPlan.validate_raw(obj: obj.fallback_plan) end |
Instance Method Details
#to_json(*_args) ⇒ String
Serialize an instance of AzureVoice to a JSON object
91 92 93 |
# File 'lib/vapi_server_sdk/types/azure_voice.rb', line 91 def to_json(*_args) @_field_set&.to_json end |