Class: Vapi::BlockCompleteMessage

Inherits:
Object
  • Object
show all
Defined in:
lib/vapi_server_sdk/types/block_complete_message.rb

Constant Summary collapse

OMIT =
Object.new

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(contents: OMIT, conditions: OMIT, content: OMIT, additional_properties: nil) ⇒ Vapi::BlockCompleteMessage

Parameters:

  • contents (Array<Vapi::TextContent>) (defaults to: OMIT)

    This is an alternative to the content property. It allows to specify variants of the same content, one per language. Usage:

    • If your assistants are multilingual, you can provide content for each

    language.

    • If you don’t provide content for a language, the first item in the array will

    be automatically translated to the active language at that moment. This will override the content property.

  • conditions (Array<Vapi::BlockCompleteMessageConditionsItem>) (defaults to: OMIT)

    This is an optional array of conditions that must be met for this message to be triggered.

  • content (String) (defaults to: OMIT)

    This is the content that the assistant will say when this message is triggered.

  • additional_properties (OpenStruct) (defaults to: nil)

    Additional properties unmapped to the current class definition



45
46
47
48
49
50
51
52
53
# File 'lib/vapi_server_sdk/types/block_complete_message.rb', line 45

def initialize(contents: OMIT, conditions: OMIT, content: OMIT, additional_properties: nil)
  @contents = contents if contents != OMIT
  @conditions = conditions if conditions != OMIT
  @content = content if content != OMIT
  @additional_properties = additional_properties
  @_field_set = { "contents": contents, "conditions": conditions, "content": content }.reject do |_k, v|
    v == OMIT
  end
end

Instance Attribute Details

#additional_propertiesOpenStruct (readonly)

Returns Additional properties unmapped to the current class definition.

Returns:

  • (OpenStruct)

    Additional properties unmapped to the current class definition



25
26
27
# File 'lib/vapi_server_sdk/types/block_complete_message.rb', line 25

def additional_properties
  @additional_properties
end

#conditionsArray<Vapi::BlockCompleteMessageConditionsItem> (readonly)

Returns This is an optional array of conditions that must be met for this message to be triggered.

Returns:



21
22
23
# File 'lib/vapi_server_sdk/types/block_complete_message.rb', line 21

def conditions
  @conditions
end

#contentString (readonly)

Returns This is the content that the assistant will say when this message is triggered.

Returns:

  • (String)

    This is the content that the assistant will say when this message is triggered.



23
24
25
# File 'lib/vapi_server_sdk/types/block_complete_message.rb', line 23

def content
  @content
end

#contentsArray<Vapi::TextContent> (readonly)

Returns This is an alternative to the content property. It allows to specify variants of the same content, one per language. Usage:

  • If your assistants are multilingual, you can provide content for each

language.

  • If you don’t provide content for a language, the first item in the array will

be automatically translated to the active language at that moment. This will override the content property.

Returns:

  • (Array<Vapi::TextContent>)

    This is an alternative to the content property. It allows to specify variants of the same content, one per language. Usage:

    • If your assistants are multilingual, you can provide content for each

    language.

    • If you don’t provide content for a language, the first item in the array will

    be automatically translated to the active language at that moment. This will override the content property.



18
19
20
# File 'lib/vapi_server_sdk/types/block_complete_message.rb', line 18

def contents
  @contents
end

Class Method Details

.from_json(json_object:) ⇒ Vapi::BlockCompleteMessage

Deserialize a JSON object to an instance of BlockCompleteMessage

Parameters:

  • json_object (String)

Returns:



59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
# File 'lib/vapi_server_sdk/types/block_complete_message.rb', line 59

def self.from_json(json_object:)
  struct = JSON.parse(json_object, object_class: OpenStruct)
  parsed_json = JSON.parse(json_object)
  contents = parsed_json["contents"]&.map do |item|
    item = item.to_json
    Vapi::TextContent.from_json(json_object: item)
  end
  conditions = parsed_json["conditions"]&.map do |item|
    item = item.to_json
    Vapi::BlockCompleteMessageConditionsItem.from_json(json_object: item)
  end
  content = parsed_json["content"]
  new(
    contents: contents,
    conditions: conditions,
    content: content,
    additional_properties: struct
  )
end

.validate_raw(obj:) ⇒ Void

Leveraged for Union-type generation, validate_raw attempts to parse the given

hash and check each fields type against the current object's property
definitions.

Parameters:

  • obj (Object)

Returns:

  • (Void)


92
93
94
95
96
# File 'lib/vapi_server_sdk/types/block_complete_message.rb', line 92

def self.validate_raw(obj:)
  obj.contents&.is_a?(Array) != false || raise("Passed value for field obj.contents is not the expected type, validation failed.")
  obj.conditions&.is_a?(Array) != false || raise("Passed value for field obj.conditions is not the expected type, validation failed.")
  obj.content&.is_a?(String) != false || raise("Passed value for field obj.content is not the expected type, validation failed.")
end

Instance Method Details

#to_json(*_args) ⇒ String

Serialize an instance of BlockCompleteMessage to a JSON object

Returns:

  • (String)


82
83
84
# File 'lib/vapi_server_sdk/types/block_complete_message.rb', line 82

def to_json(*_args)
  @_field_set&.to_json
end