Class: Vapi::ClientInboundMessageTransfer

Inherits:
Object
  • Object
show all
Defined in:
lib/vapi_server_sdk/types/client_inbound_message_transfer.rb

Constant Summary collapse

OMIT =
Object.new

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(destination: OMIT, additional_properties: nil) ⇒ Vapi::ClientInboundMessageTransfer

Parameters:

  • destination (Vapi::ClientInboundMessageTransferDestination) (defaults to: OMIT)

    This is the destination to transfer the call to.

  • additional_properties (OpenStruct) (defaults to: nil)

    Additional properties unmapped to the current class definition



22
23
24
25
26
27
28
# File 'lib/vapi_server_sdk/types/client_inbound_message_transfer.rb', line 22

def initialize(destination: OMIT, additional_properties: nil)
  @destination = destination if destination != OMIT
  @additional_properties = additional_properties
  @_field_set = { "destination": destination }.reject do |_k, v|
    v == OMIT
  end
end

Instance Attribute Details

#additional_propertiesOpenStruct (readonly)

Returns Additional properties unmapped to the current class definition.

Returns:

  • (OpenStruct)

    Additional properties unmapped to the current class definition



12
13
14
# File 'lib/vapi_server_sdk/types/client_inbound_message_transfer.rb', line 12

def additional_properties
  @additional_properties
end

#destinationVapi::ClientInboundMessageTransferDestination (readonly)

Returns This is the destination to transfer the call to.

Returns:



10
11
12
# File 'lib/vapi_server_sdk/types/client_inbound_message_transfer.rb', line 10

def destination
  @destination
end

Class Method Details

.from_json(json_object:) ⇒ Vapi::ClientInboundMessageTransfer

Deserialize a JSON object to an instance of ClientInboundMessageTransfer

Parameters:

  • json_object (String)

Returns:



34
35
36
37
38
39
40
41
42
43
44
# File 'lib/vapi_server_sdk/types/client_inbound_message_transfer.rb', line 34

def self.from_json(json_object:)
  struct = JSON.parse(json_object, object_class: OpenStruct)
  parsed_json = JSON.parse(json_object)
  if parsed_json["destination"].nil?
    destination = nil
  else
    destination = parsed_json["destination"].to_json
    destination = Vapi::ClientInboundMessageTransferDestination.from_json(json_object: destination)
  end
  new(destination: destination, additional_properties: struct)
end

.validate_raw(obj:) ⇒ Void

Leveraged for Union-type generation, validate_raw attempts to parse the given

hash and check each fields type against the current object's property
definitions.

Parameters:

  • obj (Object)

Returns:

  • (Void)


59
60
61
# File 'lib/vapi_server_sdk/types/client_inbound_message_transfer.rb', line 59

def self.validate_raw(obj:)
  obj.destination.nil? || Vapi::ClientInboundMessageTransferDestination.validate_raw(obj: obj.destination)
end

Instance Method Details

#to_json(*_args) ⇒ String

Serialize an instance of ClientInboundMessageTransfer to a JSON object

Returns:

  • (String)


49
50
51
# File 'lib/vapi_server_sdk/types/client_inbound_message_transfer.rb', line 49

def to_json(*_args)
  @_field_set&.to_json
end