Class: Vapi::ComputerTool

Inherits:
Object
  • Object
show all
Defined in:
lib/vapi_server_sdk/types/computer_tool.rb

Constant Summary collapse

OMIT =
Object.new

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(sub_type:, id:, org_id:, created_at:, updated_at:, name:, display_width_px:, display_height_px:, async: OMIT, messages: OMIT, function: OMIT, server: OMIT, display_number: OMIT, additional_properties: nil) ⇒ Vapi::ComputerTool

Parameters:

  • async (Boolean) (defaults to: OMIT)

    This determines if the tool is async. If async, the assistant will move forward without waiting for your server to respond. This is useful if you just want to trigger something on your server. If sync, the assistant will wait for your server to respond. This is useful if want assistant to respond with the result from your server. Defaults to synchronous (false).

  • messages (Array<Vapi::ComputerToolMessagesItem>) (defaults to: OMIT)

    These are the messages that will be spoken to the user as the tool is running. For some tools, this is auto-filled based on special fields like tool.destinations. For others like the function tool, these can be custom configured.

  • sub_type (String)

    The sub type of tool.

  • id (String)

    This is the unique identifier for the tool.

  • org_id (String)

    This is the unique identifier for the organization that this tool belongs to.

  • created_at (DateTime)

    This is the ISO 8601 date-time string of when the tool was created.

  • updated_at (DateTime)

    This is the ISO 8601 date-time string of when the tool was last updated.

  • function (Vapi::OpenAiFunction) (defaults to: OMIT)

    This is the function definition of the tool. For endCall, transferCall, and dtmf tools, this is auto-filled based on tool-specific fields like tool.destinations. But, even in those cases, you can provide a custom function definition for advanced use cases. An example of an advanced use case is if you want to customize the message that’s spoken for endCall tool. You can specify a function where it returns an argument “reason”. Then, in messages array, you can have many “request-complete” messages. One of these messages will be triggered if the messages[].conditions matches the “reason” argument.

  • server (Vapi::Server) (defaults to: OMIT)

    This is the server that will be hit when this tool is requested by the model. All requests will be sent with the call object among other things. You can find more details in the Server URL documentation. This overrides the serverUrl set on the org and the phoneNumber. Order of precedence: highest tool.server.url, then assistant.serverUrl, then phoneNumber.serverUrl, then org.serverUrl.

  • name (String)

    The name of the tool, fixed to ‘computer’

  • display_width_px (Float)

    The display width in pixels

  • display_height_px (Float)

    The display height in pixels

  • display_number (Float) (defaults to: OMIT)

    Optional display number

  • additional_properties (OpenStruct) (defaults to: nil)

    Additional properties unmapped to the current class definition



103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
# File 'lib/vapi_server_sdk/types/computer_tool.rb', line 103

def initialize(sub_type:, id:, org_id:, created_at:, updated_at:, name:, display_width_px:, display_height_px:, async: OMIT, messages: OMIT, function: OMIT,
               server: OMIT, display_number: OMIT, additional_properties: nil)
  @async = async if async != OMIT
  @messages = messages if messages != OMIT
  @sub_type = sub_type
  @id = id
  @org_id = org_id
  @created_at = created_at
  @updated_at = updated_at
  @function = function if function != OMIT
  @server = server if server != OMIT
  @name = name
  @display_width_px = display_width_px
  @display_height_px = display_height_px
  @display_number = display_number if display_number != OMIT
  @additional_properties = additional_properties
  @_field_set = {
    "async": async,
    "messages": messages,
    "subType": sub_type,
    "id": id,
    "orgId": org_id,
    "createdAt": created_at,
    "updatedAt": updated_at,
    "function": function,
    "server": server,
    "name": name,
    "displayWidthPx": display_width_px,
    "displayHeightPx": display_height_px,
    "displayNumber": display_number
  }.reject do |_k, v|
    v == OMIT
  end
end

Instance Attribute Details

#additional_propertiesOpenStruct (readonly)

Returns Additional properties unmapped to the current class definition.

Returns:

  • (OpenStruct)

    Additional properties unmapped to the current class definition



60
61
62
# File 'lib/vapi_server_sdk/types/computer_tool.rb', line 60

def additional_properties
  @additional_properties
end

#asyncBoolean (readonly)

Returns This determines if the tool is async. If async, the assistant will move forward without waiting for your server to respond. This is useful if you just want to trigger something on your server. If sync, the assistant will wait for your server to respond. This is useful if want assistant to respond with the result from your server. Defaults to synchronous (false).

Returns:

  • (Boolean)

    This determines if the tool is async. If async, the assistant will move forward without waiting for your server to respond. This is useful if you just want to trigger something on your server. If sync, the assistant will wait for your server to respond. This is useful if want assistant to respond with the result from your server. Defaults to synchronous (false).



18
19
20
# File 'lib/vapi_server_sdk/types/computer_tool.rb', line 18

def async
  @async
end

#created_atDateTime (readonly)

Returns This is the ISO 8601 date-time string of when the tool was created.

Returns:

  • (DateTime)

    This is the ISO 8601 date-time string of when the tool was created.



31
32
33
# File 'lib/vapi_server_sdk/types/computer_tool.rb', line 31

def created_at
  @created_at
end

#display_height_pxFloat (readonly)

Returns The display height in pixels.

Returns:

  • (Float)

    The display height in pixels



56
57
58
# File 'lib/vapi_server_sdk/types/computer_tool.rb', line 56

def display_height_px
  @display_height_px
end

#display_numberFloat (readonly)

Returns Optional display number.

Returns:

  • (Float)

    Optional display number



58
59
60
# File 'lib/vapi_server_sdk/types/computer_tool.rb', line 58

def display_number
  @display_number
end

#display_width_pxFloat (readonly)

Returns The display width in pixels.

Returns:

  • (Float)

    The display width in pixels



54
55
56
# File 'lib/vapi_server_sdk/types/computer_tool.rb', line 54

def display_width_px
  @display_width_px
end

#functionVapi::OpenAiFunction (readonly)

Returns This is the function definition of the tool. For endCall, transferCall, and dtmf tools, this is auto-filled based on tool-specific fields like tool.destinations. But, even in those cases, you can provide a custom function definition for advanced use cases. An example of an advanced use case is if you want to customize the message that’s spoken for endCall tool. You can specify a function where it returns an argument “reason”. Then, in messages array, you can have many “request-complete” messages. One of these messages will be triggered if the messages[].conditions matches the “reason” argument.

Returns:

  • (Vapi::OpenAiFunction)

    This is the function definition of the tool. For endCall, transferCall, and dtmf tools, this is auto-filled based on tool-specific fields like tool.destinations. But, even in those cases, you can provide a custom function definition for advanced use cases. An example of an advanced use case is if you want to customize the message that’s spoken for endCall tool. You can specify a function where it returns an argument “reason”. Then, in messages array, you can have many “request-complete” messages. One of these messages will be triggered if the messages[].conditions matches the “reason” argument.



43
44
45
# File 'lib/vapi_server_sdk/types/computer_tool.rb', line 43

def function
  @function
end

#idString (readonly)

Returns This is the unique identifier for the tool.

Returns:

  • (String)

    This is the unique identifier for the tool.



27
28
29
# File 'lib/vapi_server_sdk/types/computer_tool.rb', line 27

def id
  @id
end

#messagesArray<Vapi::ComputerToolMessagesItem> (readonly)

Returns These are the messages that will be spoken to the user as the tool is running. For some tools, this is auto-filled based on special fields like tool.destinations. For others like the function tool, these can be custom configured.

Returns:

  • (Array<Vapi::ComputerToolMessagesItem>)

    These are the messages that will be spoken to the user as the tool is running. For some tools, this is auto-filled based on special fields like tool.destinations. For others like the function tool, these can be custom configured.



23
24
25
# File 'lib/vapi_server_sdk/types/computer_tool.rb', line 23

def messages
  @messages
end

#nameString (readonly)

Returns The name of the tool, fixed to ‘computer’.

Returns:

  • (String)

    The name of the tool, fixed to ‘computer’



52
53
54
# File 'lib/vapi_server_sdk/types/computer_tool.rb', line 52

def name
  @name
end

#org_idString (readonly)

Returns This is the unique identifier for the organization that this tool belongs to.

Returns:

  • (String)

    This is the unique identifier for the organization that this tool belongs to.



29
30
31
# File 'lib/vapi_server_sdk/types/computer_tool.rb', line 29

def org_id
  @org_id
end

#serverVapi::Server (readonly)

Returns This is the server that will be hit when this tool is requested by the model. All requests will be sent with the call object among other things. You can find more details in the Server URL documentation. This overrides the serverUrl set on the org and the phoneNumber. Order of precedence: highest tool.server.url, then assistant.serverUrl, then phoneNumber.serverUrl, then org.serverUrl.

Returns:

  • (Vapi::Server)

    This is the server that will be hit when this tool is requested by the model. All requests will be sent with the call object among other things. You can find more details in the Server URL documentation. This overrides the serverUrl set on the org and the phoneNumber. Order of precedence: highest tool.server.url, then assistant.serverUrl, then phoneNumber.serverUrl, then org.serverUrl.



50
51
52
# File 'lib/vapi_server_sdk/types/computer_tool.rb', line 50

def server
  @server
end

#sub_typeString (readonly)

Returns The sub type of tool.

Returns:

  • (String)

    The sub type of tool.



25
26
27
# File 'lib/vapi_server_sdk/types/computer_tool.rb', line 25

def sub_type
  @sub_type
end

#updated_atDateTime (readonly)

Returns This is the ISO 8601 date-time string of when the tool was last updated.

Returns:

  • (DateTime)

    This is the ISO 8601 date-time string of when the tool was last updated.



33
34
35
# File 'lib/vapi_server_sdk/types/computer_tool.rb', line 33

def updated_at
  @updated_at
end

Class Method Details

.from_json(json_object:) ⇒ Vapi::ComputerTool

Deserialize a JSON object to an instance of ComputerTool

Parameters:

  • json_object (String)

Returns:



142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
# File 'lib/vapi_server_sdk/types/computer_tool.rb', line 142

def self.from_json(json_object:)
  struct = JSON.parse(json_object, object_class: OpenStruct)
  parsed_json = JSON.parse(json_object)
  async = parsed_json["async"]
  messages = parsed_json["messages"]&.map do |item|
    item = item.to_json
    Vapi::ComputerToolMessagesItem.from_json(json_object: item)
  end
  sub_type = parsed_json["subType"]
  id = parsed_json["id"]
  org_id = parsed_json["orgId"]
  created_at = (DateTime.parse(parsed_json["createdAt"]) unless parsed_json["createdAt"].nil?)
  updated_at = (DateTime.parse(parsed_json["updatedAt"]) unless parsed_json["updatedAt"].nil?)
  if parsed_json["function"].nil?
    function = nil
  else
    function = parsed_json["function"].to_json
    function = Vapi::OpenAiFunction.from_json(json_object: function)
  end
  if parsed_json["server"].nil?
    server = nil
  else
    server = parsed_json["server"].to_json
    server = Vapi::Server.from_json(json_object: server)
  end
  name = parsed_json["name"]
  display_width_px = parsed_json["displayWidthPx"]
  display_height_px = parsed_json["displayHeightPx"]
  display_number = parsed_json["displayNumber"]
  new(
    async: async,
    messages: messages,
    sub_type: sub_type,
    id: id,
    org_id: org_id,
    created_at: created_at,
    updated_at: updated_at,
    function: function,
    server: server,
    name: name,
    display_width_px: display_width_px,
    display_height_px: display_height_px,
    display_number: display_number,
    additional_properties: struct
  )
end

.validate_raw(obj:) ⇒ Void

Leveraged for Union-type generation, validate_raw attempts to parse the given

hash and check each fields type against the current object's property
definitions.

Parameters:

  • obj (Object)

Returns:

  • (Void)


202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
# File 'lib/vapi_server_sdk/types/computer_tool.rb', line 202

def self.validate_raw(obj:)
  obj.async&.is_a?(Boolean) != false || raise("Passed value for field obj.async is not the expected type, validation failed.")
  obj.messages&.is_a?(Array) != false || raise("Passed value for field obj.messages is not the expected type, validation failed.")
  obj.sub_type.is_a?(String) != false || raise("Passed value for field obj.sub_type is not the expected type, validation failed.")
  obj.id.is_a?(String) != false || raise("Passed value for field obj.id is not the expected type, validation failed.")
  obj.org_id.is_a?(String) != false || raise("Passed value for field obj.org_id is not the expected type, validation failed.")
  obj.created_at.is_a?(DateTime) != false || raise("Passed value for field obj.created_at is not the expected type, validation failed.")
  obj.updated_at.is_a?(DateTime) != false || raise("Passed value for field obj.updated_at is not the expected type, validation failed.")
  obj.function.nil? || Vapi::OpenAiFunction.validate_raw(obj: obj.function)
  obj.server.nil? || Vapi::Server.validate_raw(obj: obj.server)
  obj.name.is_a?(String) != false || raise("Passed value for field obj.name is not the expected type, validation failed.")
  obj.display_width_px.is_a?(Float) != false || raise("Passed value for field obj.display_width_px is not the expected type, validation failed.")
  obj.display_height_px.is_a?(Float) != false || raise("Passed value for field obj.display_height_px is not the expected type, validation failed.")
  obj.display_number&.is_a?(Float) != false || raise("Passed value for field obj.display_number is not the expected type, validation failed.")
end

Instance Method Details

#to_json(*_args) ⇒ String

Serialize an instance of ComputerTool to a JSON object

Returns:

  • (String)


192
193
194
# File 'lib/vapi_server_sdk/types/computer_tool.rb', line 192

def to_json(*_args)
  @_field_set&.to_json
end