Class: Vapi::CreateComputerToolDto

Inherits:
Object
  • Object
show all
Defined in:
lib/vapi_server_sdk/types/create_computer_tool_dto.rb

Constant Summary collapse

OMIT =
Object.new

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(sub_type:, name:, display_width_px:, display_height_px:, async: OMIT, messages: OMIT, display_number: OMIT, function: OMIT, server: OMIT, additional_properties: nil) ⇒ Vapi::CreateComputerToolDto

Parameters:

  • async (Boolean) (defaults to: OMIT)

    This determines if the tool is async. If async, the assistant will move forward without waiting for your server to respond. This is useful if you just want to trigger something on your server. If sync, the assistant will wait for your server to respond. This is useful if want assistant to respond with the result from your server. Defaults to synchronous (false).

  • messages (Array<Vapi::CreateComputerToolDtoMessagesItem>) (defaults to: OMIT)

    These are the messages that will be spoken to the user as the tool is running. For some tools, this is auto-filled based on special fields like tool.destinations. For others like the function tool, these can be custom configured.

  • sub_type (String)

    The sub type of tool.

  • name (String)

    The name of the tool, fixed to ‘computer’

  • display_width_px (Float)

    The display width in pixels

  • display_height_px (Float)

    The display height in pixels

  • display_number (Float) (defaults to: OMIT)

    Optional display number

  • function (Vapi::OpenAiFunction) (defaults to: OMIT)

    This is the function definition of the tool. For endCall, transferCall, and dtmf tools, this is auto-filled based on tool-specific fields like tool.destinations. But, even in those cases, you can provide a custom function definition for advanced use cases. An example of an advanced use case is if you want to customize the message that’s spoken for endCall tool. You can specify a function where it returns an argument “reason”. Then, in messages array, you can have many “request-complete” messages. One of these messages will be triggered if the messages[].conditions matches the “reason” argument.

  • server (Vapi::Server) (defaults to: OMIT)

    This is the server that will be hit when this tool is requested by the model. All requests will be sent with the call object among other things. You can find more details in the Server URL documentation. This overrides the serverUrl set on the org and the phoneNumber. Order of precedence: highest tool.server.url, then assistant.serverUrl, then phoneNumber.serverUrl, then org.serverUrl.

  • additional_properties (OpenStruct) (defaults to: nil)

    Additional properties unmapped to the current class definition



90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
# File 'lib/vapi_server_sdk/types/create_computer_tool_dto.rb', line 90

def initialize(sub_type:, name:, display_width_px:, display_height_px:, async: OMIT, messages: OMIT,
               display_number: OMIT, function: OMIT, server: OMIT, additional_properties: nil)
  @async = async if async != OMIT
  @messages = messages if messages != OMIT
  @sub_type = sub_type
  @name = name
  @display_width_px = display_width_px
  @display_height_px = display_height_px
  @display_number = display_number if display_number != OMIT
  @function = function if function != OMIT
  @server = server if server != OMIT
  @additional_properties = additional_properties
  @_field_set = {
    "async": async,
    "messages": messages,
    "subType": sub_type,
    "name": name,
    "displayWidthPx": display_width_px,
    "displayHeightPx": display_height_px,
    "displayNumber": display_number,
    "function": function,
    "server": server
  }.reject do |_k, v|
    v == OMIT
  end
end

Instance Attribute Details

#additional_propertiesOpenStruct (readonly)

Returns Additional properties unmapped to the current class definition.

Returns:

  • (OpenStruct)

    Additional properties unmapped to the current class definition



51
52
53
# File 'lib/vapi_server_sdk/types/create_computer_tool_dto.rb', line 51

def additional_properties
  @additional_properties
end

#asyncBoolean (readonly)

Returns This determines if the tool is async. If async, the assistant will move forward without waiting for your server to respond. This is useful if you just want to trigger something on your server. If sync, the assistant will wait for your server to respond. This is useful if want assistant to respond with the result from your server. Defaults to synchronous (false).

Returns:

  • (Boolean)

    This determines if the tool is async. If async, the assistant will move forward without waiting for your server to respond. This is useful if you just want to trigger something on your server. If sync, the assistant will wait for your server to respond. This is useful if want assistant to respond with the result from your server. Defaults to synchronous (false).



17
18
19
# File 'lib/vapi_server_sdk/types/create_computer_tool_dto.rb', line 17

def async
  @async
end

#display_height_pxFloat (readonly)

Returns The display height in pixels.

Returns:

  • (Float)

    The display height in pixels



30
31
32
# File 'lib/vapi_server_sdk/types/create_computer_tool_dto.rb', line 30

def display_height_px
  @display_height_px
end

#display_numberFloat (readonly)

Returns Optional display number.

Returns:

  • (Float)

    Optional display number



32
33
34
# File 'lib/vapi_server_sdk/types/create_computer_tool_dto.rb', line 32

def display_number
  @display_number
end

#display_width_pxFloat (readonly)

Returns The display width in pixels.

Returns:

  • (Float)

    The display width in pixels



28
29
30
# File 'lib/vapi_server_sdk/types/create_computer_tool_dto.rb', line 28

def display_width_px
  @display_width_px
end

#functionVapi::OpenAiFunction (readonly)

Returns This is the function definition of the tool. For endCall, transferCall, and dtmf tools, this is auto-filled based on tool-specific fields like tool.destinations. But, even in those cases, you can provide a custom function definition for advanced use cases. An example of an advanced use case is if you want to customize the message that’s spoken for endCall tool. You can specify a function where it returns an argument “reason”. Then, in messages array, you can have many “request-complete” messages. One of these messages will be triggered if the messages[].conditions matches the “reason” argument.

Returns:

  • (Vapi::OpenAiFunction)

    This is the function definition of the tool. For endCall, transferCall, and dtmf tools, this is auto-filled based on tool-specific fields like tool.destinations. But, even in those cases, you can provide a custom function definition for advanced use cases. An example of an advanced use case is if you want to customize the message that’s spoken for endCall tool. You can specify a function where it returns an argument “reason”. Then, in messages array, you can have many “request-complete” messages. One of these messages will be triggered if the messages[].conditions matches the “reason” argument.



42
43
44
# File 'lib/vapi_server_sdk/types/create_computer_tool_dto.rb', line 42

def function
  @function
end

#messagesArray<Vapi::CreateComputerToolDtoMessagesItem> (readonly)

Returns These are the messages that will be spoken to the user as the tool is running. For some tools, this is auto-filled based on special fields like tool.destinations. For others like the function tool, these can be custom configured.

Returns:

  • (Array<Vapi::CreateComputerToolDtoMessagesItem>)

    These are the messages that will be spoken to the user as the tool is running. For some tools, this is auto-filled based on special fields like tool.destinations. For others like the function tool, these can be custom configured.



22
23
24
# File 'lib/vapi_server_sdk/types/create_computer_tool_dto.rb', line 22

def messages
  @messages
end

#nameString (readonly)

Returns The name of the tool, fixed to ‘computer’.

Returns:

  • (String)

    The name of the tool, fixed to ‘computer’



26
27
28
# File 'lib/vapi_server_sdk/types/create_computer_tool_dto.rb', line 26

def name
  @name
end

#serverVapi::Server (readonly)

Returns This is the server that will be hit when this tool is requested by the model. All requests will be sent with the call object among other things. You can find more details in the Server URL documentation. This overrides the serverUrl set on the org and the phoneNumber. Order of precedence: highest tool.server.url, then assistant.serverUrl, then phoneNumber.serverUrl, then org.serverUrl.

Returns:

  • (Vapi::Server)

    This is the server that will be hit when this tool is requested by the model. All requests will be sent with the call object among other things. You can find more details in the Server URL documentation. This overrides the serverUrl set on the org and the phoneNumber. Order of precedence: highest tool.server.url, then assistant.serverUrl, then phoneNumber.serverUrl, then org.serverUrl.



49
50
51
# File 'lib/vapi_server_sdk/types/create_computer_tool_dto.rb', line 49

def server
  @server
end

#sub_typeString (readonly)

Returns The sub type of tool.

Returns:

  • (String)

    The sub type of tool.



24
25
26
# File 'lib/vapi_server_sdk/types/create_computer_tool_dto.rb', line 24

def sub_type
  @sub_type
end

Class Method Details

.from_json(json_object:) ⇒ Vapi::CreateComputerToolDto

Deserialize a JSON object to an instance of CreateComputerToolDto

Parameters:

  • json_object (String)

Returns:



121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
# File 'lib/vapi_server_sdk/types/create_computer_tool_dto.rb', line 121

def self.from_json(json_object:)
  struct = JSON.parse(json_object, object_class: OpenStruct)
  parsed_json = JSON.parse(json_object)
  async = parsed_json["async"]
  messages = parsed_json["messages"]&.map do |item|
    item = item.to_json
    Vapi::CreateComputerToolDtoMessagesItem.from_json(json_object: item)
  end
  sub_type = parsed_json["subType"]
  name = parsed_json["name"]
  display_width_px = parsed_json["displayWidthPx"]
  display_height_px = parsed_json["displayHeightPx"]
  display_number = parsed_json["displayNumber"]
  if parsed_json["function"].nil?
    function = nil
  else
    function = parsed_json["function"].to_json
    function = Vapi::OpenAiFunction.from_json(json_object: function)
  end
  if parsed_json["server"].nil?
    server = nil
  else
    server = parsed_json["server"].to_json
    server = Vapi::Server.from_json(json_object: server)
  end
  new(
    async: async,
    messages: messages,
    sub_type: sub_type,
    name: name,
    display_width_px: display_width_px,
    display_height_px: display_height_px,
    display_number: display_number,
    function: function,
    server: server,
    additional_properties: struct
  )
end

.validate_raw(obj:) ⇒ Void

Leveraged for Union-type generation, validate_raw attempts to parse the given

hash and check each fields type against the current object's property
definitions.

Parameters:

  • obj (Object)

Returns:

  • (Void)


173
174
175
176
177
178
179
180
181
182
183
# File 'lib/vapi_server_sdk/types/create_computer_tool_dto.rb', line 173

def self.validate_raw(obj:)
  obj.async&.is_a?(Boolean) != false || raise("Passed value for field obj.async is not the expected type, validation failed.")
  obj.messages&.is_a?(Array) != false || raise("Passed value for field obj.messages is not the expected type, validation failed.")
  obj.sub_type.is_a?(String) != false || raise("Passed value for field obj.sub_type is not the expected type, validation failed.")
  obj.name.is_a?(String) != false || raise("Passed value for field obj.name is not the expected type, validation failed.")
  obj.display_width_px.is_a?(Float) != false || raise("Passed value for field obj.display_width_px is not the expected type, validation failed.")
  obj.display_height_px.is_a?(Float) != false || raise("Passed value for field obj.display_height_px is not the expected type, validation failed.")
  obj.display_number&.is_a?(Float) != false || raise("Passed value for field obj.display_number is not the expected type, validation failed.")
  obj.function.nil? || Vapi::OpenAiFunction.validate_raw(obj: obj.function)
  obj.server.nil? || Vapi::Server.validate_raw(obj: obj.server)
end

Instance Method Details

#to_json(*_args) ⇒ String

Serialize an instance of CreateComputerToolDto to a JSON object

Returns:

  • (String)


163
164
165
# File 'lib/vapi_server_sdk/types/create_computer_tool_dto.rb', line 163

def to_json(*_args)
  @_field_set&.to_json
end