Class: Vapi::CreateGcpCredentialDto
- Inherits:
-
Object
- Object
- Vapi::CreateGcpCredentialDto
- Defined in:
- lib/vapi_server_sdk/types/create_gcp_credential_dto.rb
Constant Summary collapse
- OMIT =
Object.new
Instance Attribute Summary collapse
-
#additional_properties ⇒ OpenStruct
readonly
Additional properties unmapped to the current class definition.
-
#bucket_plan ⇒ Vapi::BucketPlan
readonly
This is the bucket plan that can be provided to store call artifacts in GCP.
-
#gcp_key ⇒ Vapi::GcpKey
readonly
This is the GCP key.
-
#name ⇒ String
readonly
This is the name of credential.
Class Method Summary collapse
-
.from_json(json_object:) ⇒ Vapi::CreateGcpCredentialDto
Deserialize a JSON object to an instance of CreateGcpCredentialDto.
-
.validate_raw(obj:) ⇒ Void
Leveraged for Union-type generation, validate_raw attempts to parse the given hash and check each fields type against the current object's property definitions.
Instance Method Summary collapse
- #initialize(gcp_key:, bucket_plan: OMIT, name: OMIT, additional_properties: nil) ⇒ Vapi::CreateGcpCredentialDto constructor
-
#to_json(*_args) ⇒ String
Serialize an instance of CreateGcpCredentialDto to a JSON object.
Constructor Details
#initialize(gcp_key:, bucket_plan: OMIT, name: OMIT, additional_properties: nil) ⇒ Vapi::CreateGcpCredentialDto
35 36 37 38 39 40 41 42 43 |
# File 'lib/vapi_server_sdk/types/create_gcp_credential_dto.rb', line 35 def initialize(gcp_key:, bucket_plan: OMIT, name: OMIT, additional_properties: nil) @gcp_key = gcp_key @bucket_plan = bucket_plan if bucket_plan != OMIT @name = name if name != OMIT @additional_properties = additional_properties @_field_set = { "gcpKey": gcp_key, "bucketPlan": bucket_plan, "name": name }.reject do |_k, v| v == OMIT end end |
Instance Attribute Details
#additional_properties ⇒ OpenStruct (readonly)
Returns Additional properties unmapped to the current class definition.
20 21 22 |
# File 'lib/vapi_server_sdk/types/create_gcp_credential_dto.rb', line 20 def additional_properties @additional_properties end |
#bucket_plan ⇒ Vapi::BucketPlan (readonly)
Returns This is the bucket plan that can be provided to store call artifacts in GCP.
16 17 18 |
# File 'lib/vapi_server_sdk/types/create_gcp_credential_dto.rb', line 16 def bucket_plan @bucket_plan end |
#gcp_key ⇒ Vapi::GcpKey (readonly)
Returns This is the GCP key. This is the JSON that can be generated in the Google Cloud
Console at
le.cloud.google.com/iam-admin/serviceaccounts/details/
14 15 16 |
# File 'lib/vapi_server_sdk/types/create_gcp_credential_dto.rb', line 14 def gcp_key @gcp_key end |
#name ⇒ String (readonly)
Returns This is the name of credential. This is just for your reference.
18 19 20 |
# File 'lib/vapi_server_sdk/types/create_gcp_credential_dto.rb', line 18 def name @name end |
Class Method Details
.from_json(json_object:) ⇒ Vapi::CreateGcpCredentialDto
Deserialize a JSON object to an instance of CreateGcpCredentialDto
49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/vapi_server_sdk/types/create_gcp_credential_dto.rb', line 49 def self.from_json(json_object:) struct = JSON.parse(json_object, object_class: OpenStruct) parsed_json = JSON.parse(json_object) if parsed_json["gcpKey"].nil? gcp_key = nil else gcp_key = parsed_json["gcpKey"].to_json gcp_key = Vapi::GcpKey.from_json(json_object: gcp_key) end if parsed_json["bucketPlan"].nil? bucket_plan = nil else bucket_plan = parsed_json["bucketPlan"].to_json bucket_plan = Vapi::BucketPlan.from_json(json_object: bucket_plan) end name = parsed_json["name"] new( gcp_key: gcp_key, bucket_plan: bucket_plan, name: name, additional_properties: struct ) end |
.validate_raw(obj:) ⇒ Void
Leveraged for Union-type generation, validate_raw attempts to parse the given hash and check each fields type against the current object's property definitions.
86 87 88 89 90 |
# File 'lib/vapi_server_sdk/types/create_gcp_credential_dto.rb', line 86 def self.validate_raw(obj:) Vapi::GcpKey.validate_raw(obj: obj.gcp_key) obj.bucket_plan.nil? || Vapi::BucketPlan.validate_raw(obj: obj.bucket_plan) obj.name&.is_a?(String) != false || raise("Passed value for field obj.name is not the expected type, validation failed.") end |
Instance Method Details
#to_json(*_args) ⇒ String
Serialize an instance of CreateGcpCredentialDto to a JSON object
76 77 78 |
# File 'lib/vapi_server_sdk/types/create_gcp_credential_dto.rb', line 76 def to_json(*_args) @_field_set&.to_json end |