Class: Vapi::CreateTwilioPhoneNumberDto

Inherits:
Object
  • Object
show all
Defined in:
lib/vapi_server_sdk/types/create_twilio_phone_number_dto.rb

Constant Summary collapse

OMIT =
Object.new

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(number:, twilio_account_sid:, twilio_auth_token:, fallback_destination: OMIT, name: OMIT, assistant_id: OMIT, squad_id: OMIT, server: OMIT, additional_properties: nil) ⇒ Vapi::CreateTwilioPhoneNumberDto

Parameters:

  • fallback_destination (Vapi::CreateTwilioPhoneNumberDtoFallbackDestination) (defaults to: OMIT)

    This is the fallback destination an inbound call will be transferred to if:

    1. assistantId is not set
    2. squadId is not set
    3. and, assistant-request message to the serverUrl fails If this is not set and above conditions are met, the inbound call is hung up with an error message.
  • number (String)

    These are the digits of the phone number you own on your Twilio.

  • twilio_account_sid (String)

    This is the Twilio Account SID for the phone number.

  • twilio_auth_token (String)

    This is the Twilio Auth Token for the phone number.

  • name (String) (defaults to: OMIT)

    This is the name of the phone number. This is just for your own reference.

  • assistant_id (String) (defaults to: OMIT)

    This is the assistant that will be used for incoming calls to this phone number. If neither assistantId nor squadId is set, assistant-request will be sent to your Server URL. Check ServerMessage and ServerMessageResponse for the shape of the message and response that is expected.

  • squad_id (String) (defaults to: OMIT)

    This is the squad that will be used for incoming calls to this phone number. If neither assistantId nor squadId is set, assistant-request will be sent to your Server URL. Check ServerMessage and ServerMessageResponse for the shape of the message and response that is expected.

  • server (Vapi::Server) (defaults to: OMIT)

    This is where Vapi will send webhooks. You can find all webhooks available along with their shape in ServerMessage schema. The order of precedence is:

    1. assistant.server
    2. phoneNumber.server
    3. org.server
  • additional_properties (OpenStruct) (defaults to: nil)

    Additional properties unmapped to the current class definition



76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
# File 'lib/vapi_server_sdk/types/create_twilio_phone_number_dto.rb', line 76

def initialize(number:, twilio_account_sid:, twilio_auth_token:, fallback_destination: OMIT, name: OMIT,
               assistant_id: OMIT, squad_id: OMIT, server: OMIT, additional_properties: nil)
  @fallback_destination = fallback_destination if fallback_destination != OMIT
  @number = number
   = 
  @twilio_auth_token = twilio_auth_token
  @name = name if name != OMIT
  @assistant_id = assistant_id if assistant_id != OMIT
  @squad_id = squad_id if squad_id != OMIT
  @server = server if server != OMIT
  @additional_properties = additional_properties
  @_field_set = {
    "fallbackDestination": fallback_destination,
    "number": number,
    "twilioAccountSid": ,
    "twilioAuthToken": twilio_auth_token,
    "name": name,
    "assistantId": assistant_id,
    "squadId": squad_id,
    "server": server
  }.reject do |_k, v|
    v == OMIT
  end
end

Instance Attribute Details

#additional_propertiesOpenStruct (readonly)

Returns Additional properties unmapped to the current class definition.

Returns:

  • (OpenStruct)

    Additional properties unmapped to the current class definition



43
44
45
# File 'lib/vapi_server_sdk/types/create_twilio_phone_number_dto.rb', line 43

def additional_properties
  @additional_properties
end

#assistant_idString (readonly)

Returns This is the assistant that will be used for incoming calls to this phone number. If neither assistantId nor squadId is set, assistant-request will be sent to your Server URL. Check ServerMessage and ServerMessageResponse for the shape of the message and response that is expected.

Returns:

  • (String)

    This is the assistant that will be used for incoming calls to this phone number. If neither assistantId nor squadId is set, assistant-request will be sent to your Server URL. Check ServerMessage and ServerMessageResponse for the shape of the message and response that is expected.



29
30
31
# File 'lib/vapi_server_sdk/types/create_twilio_phone_number_dto.rb', line 29

def assistant_id
  @assistant_id
end

#fallback_destinationVapi::CreateTwilioPhoneNumberDtoFallbackDestination (readonly)

Returns This is the fallback destination an inbound call will be transferred to if:

  1. assistantId is not set
  2. squadId is not set
  3. and, assistant-request message to the serverUrl fails If this is not set and above conditions are met, the inbound call is hung up with an error message.

Returns:

  • (Vapi::CreateTwilioPhoneNumberDtoFallbackDestination)

    This is the fallback destination an inbound call will be transferred to if:

    1. assistantId is not set
    2. squadId is not set
    3. and, assistant-request message to the serverUrl fails If this is not set and above conditions are met, the inbound call is hung up with an error message.


16
17
18
# File 'lib/vapi_server_sdk/types/create_twilio_phone_number_dto.rb', line 16

def fallback_destination
  @fallback_destination
end

#nameString (readonly)

Returns This is the name of the phone number. This is just for your own reference.

Returns:

  • (String)

    This is the name of the phone number. This is just for your own reference.



24
25
26
# File 'lib/vapi_server_sdk/types/create_twilio_phone_number_dto.rb', line 24

def name
  @name
end

#numberString (readonly)

Returns These are the digits of the phone number you own on your Twilio.

Returns:

  • (String)

    These are the digits of the phone number you own on your Twilio.



18
19
20
# File 'lib/vapi_server_sdk/types/create_twilio_phone_number_dto.rb', line 18

def number
  @number
end

#serverVapi::Server (readonly)

Returns This is where Vapi will send webhooks. You can find all webhooks available along with their shape in ServerMessage schema. The order of precedence is:

  1. assistant.server
  2. phoneNumber.server
  3. org.server.

Returns:

  • (Vapi::Server)

    This is where Vapi will send webhooks. You can find all webhooks available along with their shape in ServerMessage schema. The order of precedence is:

    1. assistant.server
    2. phoneNumber.server
    3. org.server


41
42
43
# File 'lib/vapi_server_sdk/types/create_twilio_phone_number_dto.rb', line 41

def server
  @server
end

#squad_idString (readonly)

Returns This is the squad that will be used for incoming calls to this phone number. If neither assistantId nor squadId is set, assistant-request will be sent to your Server URL. Check ServerMessage and ServerMessageResponse for the shape of the message and response that is expected.

Returns:

  • (String)

    This is the squad that will be used for incoming calls to this phone number. If neither assistantId nor squadId is set, assistant-request will be sent to your Server URL. Check ServerMessage and ServerMessageResponse for the shape of the message and response that is expected.



34
35
36
# File 'lib/vapi_server_sdk/types/create_twilio_phone_number_dto.rb', line 34

def squad_id
  @squad_id
end

#twilio_account_sidString (readonly)

Returns This is the Twilio Account SID for the phone number.

Returns:

  • (String)

    This is the Twilio Account SID for the phone number.



20
21
22
# File 'lib/vapi_server_sdk/types/create_twilio_phone_number_dto.rb', line 20

def 
  
end

#twilio_auth_tokenString (readonly)

Returns This is the Twilio Auth Token for the phone number.

Returns:

  • (String)

    This is the Twilio Auth Token for the phone number.



22
23
24
# File 'lib/vapi_server_sdk/types/create_twilio_phone_number_dto.rb', line 22

def twilio_auth_token
  @twilio_auth_token
end

Class Method Details

.from_json(json_object:) ⇒ Vapi::CreateTwilioPhoneNumberDto

Deserialize a JSON object to an instance of CreateTwilioPhoneNumberDto

Parameters:

  • json_object (String)

Returns:



105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
# File 'lib/vapi_server_sdk/types/create_twilio_phone_number_dto.rb', line 105

def self.from_json(json_object:)
  struct = JSON.parse(json_object, object_class: OpenStruct)
  parsed_json = JSON.parse(json_object)
  if parsed_json["fallbackDestination"].nil?
    fallback_destination = nil
  else
    fallback_destination = parsed_json["fallbackDestination"].to_json
    fallback_destination = Vapi::CreateTwilioPhoneNumberDtoFallbackDestination.from_json(json_object: fallback_destination)
  end
  number = parsed_json["number"]
   = parsed_json["twilioAccountSid"]
  twilio_auth_token = parsed_json["twilioAuthToken"]
  name = parsed_json["name"]
  assistant_id = parsed_json["assistantId"]
  squad_id = parsed_json["squadId"]
  if parsed_json["server"].nil?
    server = nil
  else
    server = parsed_json["server"].to_json
    server = Vapi::Server.from_json(json_object: server)
  end
  new(
    fallback_destination: fallback_destination,
    number: number,
    twilio_account_sid: ,
    twilio_auth_token: twilio_auth_token,
    name: name,
    assistant_id: assistant_id,
    squad_id: squad_id,
    server: server,
    additional_properties: struct
  )
end

.validate_raw(obj:) ⇒ Void

Leveraged for Union-type generation, validate_raw attempts to parse the given hash and check each fields type against the current object's property definitions.

Parameters:

  • obj (Object)

Returns:

  • (Void)


152
153
154
155
156
157
158
159
160
161
# File 'lib/vapi_server_sdk/types/create_twilio_phone_number_dto.rb', line 152

def self.validate_raw(obj:)
  obj.fallback_destination.nil? || Vapi::CreateTwilioPhoneNumberDtoFallbackDestination.validate_raw(obj: obj.fallback_destination)
  obj.number.is_a?(String) != false || raise("Passed value for field obj.number is not the expected type, validation failed.")
  obj..is_a?(String) != false || raise("Passed value for field obj.twilio_account_sid is not the expected type, validation failed.")
  obj.twilio_auth_token.is_a?(String) != false || raise("Passed value for field obj.twilio_auth_token is not the expected type, validation failed.")
  obj.name&.is_a?(String) != false || raise("Passed value for field obj.name is not the expected type, validation failed.")
  obj.assistant_id&.is_a?(String) != false || raise("Passed value for field obj.assistant_id is not the expected type, validation failed.")
  obj.squad_id&.is_a?(String) != false || raise("Passed value for field obj.squad_id is not the expected type, validation failed.")
  obj.server.nil? || Vapi::Server.validate_raw(obj: obj.server)
end

Instance Method Details

#to_json(*_args) ⇒ String

Serialize an instance of CreateTwilioPhoneNumberDto to a JSON object

Returns:

  • (String)


142
143
144
# File 'lib/vapi_server_sdk/types/create_twilio_phone_number_dto.rb', line 142

def to_json(*_args)
  @_field_set&.to_json
end