Class: Vapi::CreateVonagePhoneNumberDto

Inherits:
Object
  • Object
show all
Defined in:
lib/vapi_server_sdk/types/create_vonage_phone_number_dto.rb

Constant Summary collapse

OMIT =
Object.new

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(number:, credential_id:, fallback_destination: OMIT, name: OMIT, assistant_id: OMIT, squad_id: OMIT, server: OMIT, additional_properties: nil) ⇒ Vapi::CreateVonagePhoneNumberDto

Parameters:

  • fallback_destination (Vapi::CreateVonagePhoneNumberDtoFallbackDestination) (defaults to: OMIT)

    This is the fallback destination an inbound call will be transferred to if:

    1. assistantId is not set
    2. squadId is not set
    3. and, assistant-request message to the serverUrl fails If this is not set and above conditions are met, the inbound call is hung up with an error message.
  • number (String)

    These are the digits of the phone number you own on your Vonage.

  • credential_id (String)

    This is the credential that is used to make outgoing calls, and do operations like call transfer and hang up.

  • name (String) (defaults to: OMIT)

    This is the name of the phone number. This is just for your own reference.

  • assistant_id (String) (defaults to: OMIT)

    This is the assistant that will be used for incoming calls to this phone number. If neither assistantId nor squadId is set, assistant-request will be sent to your Server URL. Check ServerMessage and ServerMessageResponse for the shape of the message and response that is expected.

  • squad_id (String) (defaults to: OMIT)

    This is the squad that will be used for incoming calls to this phone number. If neither assistantId nor squadId is set, assistant-request will be sent to your Server URL. Check ServerMessage and ServerMessageResponse for the shape of the message and response that is expected.

  • server (Vapi::Server) (defaults to: OMIT)

    This is where Vapi will send webhooks. You can find all webhooks available along with their shape in ServerMessage schema. The order of precedence is:

    1. assistant.server
    2. phoneNumber.server
    3. org.server
  • additional_properties (OpenStruct) (defaults to: nil)

    Additional properties unmapped to the current class definition



75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
# File 'lib/vapi_server_sdk/types/create_vonage_phone_number_dto.rb', line 75

def initialize(number:, credential_id:, fallback_destination: OMIT, name: OMIT, assistant_id: OMIT, squad_id: OMIT,
               server: OMIT, additional_properties: nil)
  @fallback_destination = fallback_destination if fallback_destination != OMIT
  @number = number
  @credential_id = credential_id
  @name = name if name != OMIT
  @assistant_id = assistant_id if assistant_id != OMIT
  @squad_id = squad_id if squad_id != OMIT
  @server = server if server != OMIT
  @additional_properties = additional_properties
  @_field_set = {
    "fallbackDestination": fallback_destination,
    "number": number,
    "credentialId": credential_id,
    "name": name,
    "assistantId": assistant_id,
    "squadId": squad_id,
    "server": server
  }.reject do |_k, v|
    v == OMIT
  end
end

Instance Attribute Details

#additional_propertiesOpenStruct (readonly)

Returns Additional properties unmapped to the current class definition.

Returns:

  • (OpenStruct)

    Additional properties unmapped to the current class definition



42
43
44
# File 'lib/vapi_server_sdk/types/create_vonage_phone_number_dto.rb', line 42

def additional_properties
  @additional_properties
end

#assistant_idString (readonly)

Returns This is the assistant that will be used for incoming calls to this phone number. If neither assistantId nor squadId is set, assistant-request will be sent to your Server URL. Check ServerMessage and ServerMessageResponse for the shape of the message and response that is expected.

Returns:

  • (String)

    This is the assistant that will be used for incoming calls to this phone number. If neither assistantId nor squadId is set, assistant-request will be sent to your Server URL. Check ServerMessage and ServerMessageResponse for the shape of the message and response that is expected.



28
29
30
# File 'lib/vapi_server_sdk/types/create_vonage_phone_number_dto.rb', line 28

def assistant_id
  @assistant_id
end

#credential_idString (readonly)

Returns This is the credential that is used to make outgoing calls, and do operations like call transfer and hang up.

Returns:

  • (String)

    This is the credential that is used to make outgoing calls, and do operations like call transfer and hang up.



21
22
23
# File 'lib/vapi_server_sdk/types/create_vonage_phone_number_dto.rb', line 21

def credential_id
  @credential_id
end

#fallback_destinationVapi::CreateVonagePhoneNumberDtoFallbackDestination (readonly)

Returns This is the fallback destination an inbound call will be transferred to if:

  1. assistantId is not set
  2. squadId is not set
  3. and, assistant-request message to the serverUrl fails If this is not set and above conditions are met, the inbound call is hung up with an error message.

Returns:

  • (Vapi::CreateVonagePhoneNumberDtoFallbackDestination)

    This is the fallback destination an inbound call will be transferred to if:

    1. assistantId is not set
    2. squadId is not set
    3. and, assistant-request message to the serverUrl fails If this is not set and above conditions are met, the inbound call is hung up with an error message.


16
17
18
# File 'lib/vapi_server_sdk/types/create_vonage_phone_number_dto.rb', line 16

def fallback_destination
  @fallback_destination
end

#nameString (readonly)

Returns This is the name of the phone number. This is just for your own reference.

Returns:

  • (String)

    This is the name of the phone number. This is just for your own reference.



23
24
25
# File 'lib/vapi_server_sdk/types/create_vonage_phone_number_dto.rb', line 23

def name
  @name
end

#numberString (readonly)

Returns These are the digits of the phone number you own on your Vonage.

Returns:

  • (String)

    These are the digits of the phone number you own on your Vonage.



18
19
20
# File 'lib/vapi_server_sdk/types/create_vonage_phone_number_dto.rb', line 18

def number
  @number
end

#serverVapi::Server (readonly)

Returns This is where Vapi will send webhooks. You can find all webhooks available along with their shape in ServerMessage schema. The order of precedence is:

  1. assistant.server
  2. phoneNumber.server
  3. org.server.

Returns:

  • (Vapi::Server)

    This is where Vapi will send webhooks. You can find all webhooks available along with their shape in ServerMessage schema. The order of precedence is:

    1. assistant.server
    2. phoneNumber.server
    3. org.server


40
41
42
# File 'lib/vapi_server_sdk/types/create_vonage_phone_number_dto.rb', line 40

def server
  @server
end

#squad_idString (readonly)

Returns This is the squad that will be used for incoming calls to this phone number. If neither assistantId nor squadId is set, assistant-request will be sent to your Server URL. Check ServerMessage and ServerMessageResponse for the shape of the message and response that is expected.

Returns:

  • (String)

    This is the squad that will be used for incoming calls to this phone number. If neither assistantId nor squadId is set, assistant-request will be sent to your Server URL. Check ServerMessage and ServerMessageResponse for the shape of the message and response that is expected.



33
34
35
# File 'lib/vapi_server_sdk/types/create_vonage_phone_number_dto.rb', line 33

def squad_id
  @squad_id
end

Class Method Details

.from_json(json_object:) ⇒ Vapi::CreateVonagePhoneNumberDto

Deserialize a JSON object to an instance of CreateVonagePhoneNumberDto

Parameters:

  • json_object (String)

Returns:



102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
# File 'lib/vapi_server_sdk/types/create_vonage_phone_number_dto.rb', line 102

def self.from_json(json_object:)
  struct = JSON.parse(json_object, object_class: OpenStruct)
  parsed_json = JSON.parse(json_object)
  if parsed_json["fallbackDestination"].nil?
    fallback_destination = nil
  else
    fallback_destination = parsed_json["fallbackDestination"].to_json
    fallback_destination = Vapi::CreateVonagePhoneNumberDtoFallbackDestination.from_json(json_object: fallback_destination)
  end
  number = parsed_json["number"]
  credential_id = parsed_json["credentialId"]
  name = parsed_json["name"]
  assistant_id = parsed_json["assistantId"]
  squad_id = parsed_json["squadId"]
  if parsed_json["server"].nil?
    server = nil
  else
    server = parsed_json["server"].to_json
    server = Vapi::Server.from_json(json_object: server)
  end
  new(
    fallback_destination: fallback_destination,
    number: number,
    credential_id: credential_id,
    name: name,
    assistant_id: assistant_id,
    squad_id: squad_id,
    server: server,
    additional_properties: struct
  )
end

.validate_raw(obj:) ⇒ Void

Leveraged for Union-type generation, validate_raw attempts to parse the given hash and check each fields type against the current object's property definitions.

Parameters:

  • obj (Object)

Returns:

  • (Void)


147
148
149
150
151
152
153
154
155
# File 'lib/vapi_server_sdk/types/create_vonage_phone_number_dto.rb', line 147

def self.validate_raw(obj:)
  obj.fallback_destination.nil? || Vapi::CreateVonagePhoneNumberDtoFallbackDestination.validate_raw(obj: obj.fallback_destination)
  obj.number.is_a?(String) != false || raise("Passed value for field obj.number is not the expected type, validation failed.")
  obj.credential_id.is_a?(String) != false || raise("Passed value for field obj.credential_id is not the expected type, validation failed.")
  obj.name&.is_a?(String) != false || raise("Passed value for field obj.name is not the expected type, validation failed.")
  obj.assistant_id&.is_a?(String) != false || raise("Passed value for field obj.assistant_id is not the expected type, validation failed.")
  obj.squad_id&.is_a?(String) != false || raise("Passed value for field obj.squad_id is not the expected type, validation failed.")
  obj.server.nil? || Vapi::Server.validate_raw(obj: obj.server)
end

Instance Method Details

#to_json(*_args) ⇒ String

Serialize an instance of CreateVonagePhoneNumberDto to a JSON object

Returns:

  • (String)


137
138
139
# File 'lib/vapi_server_sdk/types/create_vonage_phone_number_dto.rb', line 137

def to_json(*_args)
  @_field_set&.to_json
end