Class: Vapi::CreateWorkflowDtoNodesItem
- Inherits:
-
Object
- Object
- Vapi::CreateWorkflowDtoNodesItem
- Defined in:
- lib/vapi_server_sdk/types/create_workflow_dto_nodes_item.rb
Class Method Summary collapse
-
.from_json(json_object:) ⇒ Vapi::CreateWorkflowDtoNodesItem
Deserialize a JSON object to an instance of CreateWorkflowDtoNodesItem.
-
.validate_raw(obj:) ⇒ Void
Leveraged for Union-type generation, validate_raw attempts to parse the given hash and check each fields type against the current object’s property definitions.
Class Method Details
.from_json(json_object:) ⇒ Vapi::CreateWorkflowDtoNodesItem
Deserialize a JSON object to an instance of CreateWorkflowDtoNodesItem
14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 |
# File 'lib/vapi_server_sdk/types/create_workflow_dto_nodes_item.rb', line 14 def self.from_json(json_object:) struct = JSON.parse(json_object, object_class: OpenStruct) begin Vapi::Say.validate_raw(obj: struct) return Vapi::Say.from_json(json_object: struct) unless struct.nil? return nil rescue StandardError # noop end begin Vapi::Gather.validate_raw(obj: struct) return Vapi::Gather.from_json(json_object: struct) unless struct.nil? return nil rescue StandardError # noop end begin struct.is_a?(Object) != false || raise("Passed value for field struct is not the expected type, validation failed.") return struct unless struct.nil? return nil rescue StandardError # noop end begin Vapi::CreateWorkflowDto.validate_raw(obj: struct) return Vapi::CreateWorkflowDto.from_json(json_object: struct) unless struct.nil? return nil rescue StandardError # noop end struct end |
.validate_raw(obj:) ⇒ Void
Leveraged for Union-type generation, validate_raw attempts to parse the given
hash and check each fields type against the current object's property
definitions.
57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/vapi_server_sdk/types/create_workflow_dto_nodes_item.rb', line 57 def self.validate_raw(obj:) begin return Vapi::Say.validate_raw(obj: obj) rescue StandardError # noop end begin return Vapi::Gather.validate_raw(obj: obj) rescue StandardError # noop end begin return obj.is_a?(Object) != false || raise("Passed value for field obj is not the expected type, validation failed.") rescue StandardError # noop end begin return Vapi::CreateWorkflowDto.validate_raw(obj: obj) rescue StandardError # noop end raise("Passed value matched no type within the union, validation failed.") end |