Class: Vapi::ElevenLabsVoice
- Inherits:
-
Object
- Object
- Vapi::ElevenLabsVoice
- Defined in:
- lib/vapi_server_sdk/types/eleven_labs_voice.rb
Constant Summary collapse
- OMIT =
Object.new
Instance Attribute Summary collapse
-
#additional_properties ⇒ OpenStruct
readonly
Additional properties unmapped to the current class definition.
-
#chunk_plan ⇒ Vapi::ChunkPlan
readonly
This is the plan for chunking the model output before it is sent to the voice provider.
-
#enable_ssml_parsing ⇒ Boolean
readonly
This enables the use of https://elevenlabs.io/docs/speech-synthesis/prompting#pronunciation.
-
#fallback_plan ⇒ Vapi::FallbackPlan
readonly
This is the plan for voice provider fallbacks in the event that the primary voice provider fails.
-
#language ⇒ String
readonly
This is the language (ISO 639-1) that is enforced for the model.
-
#model ⇒ Vapi::ElevenLabsVoiceModel
readonly
This is the model that will be used.
-
#optimize_streaming_latency ⇒ Float
readonly
Defines the optimize streaming latency for voice settings.
-
#similarity_boost ⇒ Float
readonly
Defines the similarity boost for voice settings.
-
#stability ⇒ Float
readonly
Defines the stability for voice settings.
-
#style ⇒ Float
readonly
Defines the style for voice settings.
-
#use_speaker_boost ⇒ Boolean
readonly
Defines the use speaker boost for voice settings.
-
#voice_id ⇒ Vapi::ElevenLabsVoiceId
readonly
This is the provider-specific ID that will be used.
Class Method Summary collapse
-
.from_json(json_object:) ⇒ Vapi::ElevenLabsVoice
Deserialize a JSON object to an instance of ElevenLabsVoice.
-
.validate_raw(obj:) ⇒ Void
Leveraged for Union-type generation, validate_raw attempts to parse the given hash and check each fields type against the current object's property definitions.
Instance Method Summary collapse
- #initialize(voice_id:, stability: OMIT, similarity_boost: OMIT, style: OMIT, use_speaker_boost: OMIT, optimize_streaming_latency: OMIT, enable_ssml_parsing: OMIT, model: OMIT, chunk_plan: OMIT, language: OMIT, fallback_plan: OMIT, additional_properties: nil) ⇒ Vapi::ElevenLabsVoice constructor
-
#to_json(*_args) ⇒ String
Serialize an instance of ElevenLabsVoice to a JSON object.
Constructor Details
#initialize(voice_id:, stability: OMIT, similarity_boost: OMIT, style: OMIT, use_speaker_boost: OMIT, optimize_streaming_latency: OMIT, enable_ssml_parsing: OMIT, model: OMIT, chunk_plan: OMIT, language: OMIT, fallback_plan: OMIT, additional_properties: nil) ⇒ Vapi::ElevenLabsVoice
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 |
# File 'lib/vapi_server_sdk/types/eleven_labs_voice.rb', line 73 def initialize(voice_id:, stability: OMIT, similarity_boost: OMIT, style: OMIT, use_speaker_boost: OMIT, optimize_streaming_latency: OMIT, enable_ssml_parsing: OMIT, model: OMIT, chunk_plan: OMIT, language: OMIT, fallback_plan: OMIT, additional_properties: nil) @voice_id = voice_id @stability = stability if stability != OMIT @similarity_boost = similarity_boost if similarity_boost != OMIT @style = style if style != OMIT @use_speaker_boost = use_speaker_boost if use_speaker_boost != OMIT @optimize_streaming_latency = optimize_streaming_latency if optimize_streaming_latency != OMIT @enable_ssml_parsing = enable_ssml_parsing if enable_ssml_parsing != OMIT @model = model if model != OMIT @chunk_plan = chunk_plan if chunk_plan != OMIT @language = language if language != OMIT @fallback_plan = fallback_plan if fallback_plan != OMIT @additional_properties = additional_properties @_field_set = { "voiceId": voice_id, "stability": stability, "similarityBoost": similarity_boost, "style": style, "useSpeakerBoost": use_speaker_boost, "optimizeStreamingLatency": optimize_streaming_latency, "enableSsmlParsing": enable_ssml_parsing, "model": model, "chunkPlan": chunk_plan, "language": language, "fallbackPlan": fallback_plan }.reject do |_k, v| v == OMIT end end |
Instance Attribute Details
#additional_properties ⇒ OpenStruct (readonly)
Returns Additional properties unmapped to the current class definition.
44 45 46 |
# File 'lib/vapi_server_sdk/types/eleven_labs_voice.rb', line 44 def additional_properties @additional_properties end |
#chunk_plan ⇒ Vapi::ChunkPlan (readonly)
Returns This is the plan for chunking the model output before it is sent to the voice provider.
35 36 37 |
# File 'lib/vapi_server_sdk/types/eleven_labs_voice.rb', line 35 def chunk_plan @chunk_plan end |
#enable_ssml_parsing ⇒ Boolean (readonly)
Returns This enables the use of https://elevenlabs.io/docs/speech-synthesis/prompting#pronunciation. Defaults to false to save latency. @default false.
29 30 31 |
# File 'lib/vapi_server_sdk/types/eleven_labs_voice.rb', line 29 def enable_ssml_parsing @enable_ssml_parsing end |
#fallback_plan ⇒ Vapi::FallbackPlan (readonly)
Returns This is the plan for voice provider fallbacks in the event that the primary voice provider fails.
42 43 44 |
# File 'lib/vapi_server_sdk/types/eleven_labs_voice.rb', line 42 def fallback_plan @fallback_plan end |
#language ⇒ String (readonly)
This is the language (ISO 639-1) that is enforced for the model. Currently only Turbo v2.5 supports language enforcement. For other models, an error will be returned if language code is provided.
39 40 41 |
# File 'lib/vapi_server_sdk/types/eleven_labs_voice.rb', line 39 def language @language end |
#model ⇒ Vapi::ElevenLabsVoiceModel (readonly)
Returns This is the model that will be used. Defaults to 'eleven_turbo_v2' if not specified.
32 33 34 |
# File 'lib/vapi_server_sdk/types/eleven_labs_voice.rb', line 32 def model @model end |
#optimize_streaming_latency ⇒ Float (readonly)
Returns Defines the optimize streaming latency for voice settings. Defaults to 3.
24 25 26 |
# File 'lib/vapi_server_sdk/types/eleven_labs_voice.rb', line 24 def optimize_streaming_latency @optimize_streaming_latency end |
#similarity_boost ⇒ Float (readonly)
Returns Defines the similarity boost for voice settings.
18 19 20 |
# File 'lib/vapi_server_sdk/types/eleven_labs_voice.rb', line 18 def similarity_boost @similarity_boost end |
#stability ⇒ Float (readonly)
Returns Defines the stability for voice settings.
16 17 18 |
# File 'lib/vapi_server_sdk/types/eleven_labs_voice.rb', line 16 def stability @stability end |
#style ⇒ Float (readonly)
Returns Defines the style for voice settings.
20 21 22 |
# File 'lib/vapi_server_sdk/types/eleven_labs_voice.rb', line 20 def style @style end |
#use_speaker_boost ⇒ Boolean (readonly)
Returns Defines the use speaker boost for voice settings.
22 23 24 |
# File 'lib/vapi_server_sdk/types/eleven_labs_voice.rb', line 22 def use_speaker_boost @use_speaker_boost end |
#voice_id ⇒ Vapi::ElevenLabsVoiceId (readonly)
Returns This is the provider-specific ID that will be used. Ensure the Voice is present in your 11Labs Voice Library.
14 15 16 |
# File 'lib/vapi_server_sdk/types/eleven_labs_voice.rb', line 14 def voice_id @voice_id end |
Class Method Details
.from_json(json_object:) ⇒ Vapi::ElevenLabsVoice
Deserialize a JSON object to an instance of ElevenLabsVoice
108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 |
# File 'lib/vapi_server_sdk/types/eleven_labs_voice.rb', line 108 def self.from_json(json_object:) struct = JSON.parse(json_object, object_class: OpenStruct) parsed_json = JSON.parse(json_object) if parsed_json["voiceId"].nil? voice_id = nil else voice_id = parsed_json["voiceId"].to_json voice_id = Vapi::ElevenLabsVoiceId.from_json(json_object: voice_id) end stability = parsed_json["stability"] similarity_boost = parsed_json["similarityBoost"] style = parsed_json["style"] use_speaker_boost = parsed_json["useSpeakerBoost"] optimize_streaming_latency = parsed_json["optimizeStreamingLatency"] enable_ssml_parsing = parsed_json["enableSsmlParsing"] model = parsed_json["model"] if parsed_json["chunkPlan"].nil? chunk_plan = nil else chunk_plan = parsed_json["chunkPlan"].to_json chunk_plan = Vapi::ChunkPlan.from_json(json_object: chunk_plan) end language = parsed_json["language"] if parsed_json["fallbackPlan"].nil? fallback_plan = nil else fallback_plan = parsed_json["fallbackPlan"].to_json fallback_plan = Vapi::FallbackPlan.from_json(json_object: fallback_plan) end new( voice_id: voice_id, stability: stability, similarity_boost: similarity_boost, style: style, use_speaker_boost: use_speaker_boost, optimize_streaming_latency: optimize_streaming_latency, enable_ssml_parsing: enable_ssml_parsing, model: model, chunk_plan: chunk_plan, language: language, fallback_plan: fallback_plan, additional_properties: struct ) end |
.validate_raw(obj:) ⇒ Void
Leveraged for Union-type generation, validate_raw attempts to parse the given hash and check each fields type against the current object's property definitions.
166 167 168 169 170 171 172 173 174 175 176 177 178 |
# File 'lib/vapi_server_sdk/types/eleven_labs_voice.rb', line 166 def self.validate_raw(obj:) Vapi::ElevenLabsVoiceId.validate_raw(obj: obj.voice_id) obj.stability&.is_a?(Float) != false || raise("Passed value for field obj.stability is not the expected type, validation failed.") obj.similarity_boost&.is_a?(Float) != false || raise("Passed value for field obj.similarity_boost is not the expected type, validation failed.") obj.style&.is_a?(Float) != false || raise("Passed value for field obj.style is not the expected type, validation failed.") obj.use_speaker_boost&.is_a?(Boolean) != false || raise("Passed value for field obj.use_speaker_boost is not the expected type, validation failed.") obj.optimize_streaming_latency&.is_a?(Float) != false || raise("Passed value for field obj.optimize_streaming_latency is not the expected type, validation failed.") obj.enable_ssml_parsing&.is_a?(Boolean) != false || raise("Passed value for field obj.enable_ssml_parsing is not the expected type, validation failed.") obj.model&.is_a?(Vapi::ElevenLabsVoiceModel) != false || raise("Passed value for field obj.model is not the expected type, validation failed.") obj.chunk_plan.nil? || Vapi::ChunkPlan.validate_raw(obj: obj.chunk_plan) obj.language&.is_a?(String) != false || raise("Passed value for field obj.language is not the expected type, validation failed.") obj.fallback_plan.nil? || Vapi::FallbackPlan.validate_raw(obj: obj.fallback_plan) end |
Instance Method Details
#to_json(*_args) ⇒ String
Serialize an instance of ElevenLabsVoice to a JSON object
156 157 158 |
# File 'lib/vapi_server_sdk/types/eleven_labs_voice.rb', line 156 def to_json(*_args) @_field_set&.to_json end |