Class: Vapi::FallbackOpenAiVoice
- Inherits:
-
Object
- Object
- Vapi::FallbackOpenAiVoice
- Defined in:
- lib/vapi_server_sdk/types/fallback_open_ai_voice.rb
Constant Summary collapse
- OMIT =
Object.new
Instance Attribute Summary collapse
-
#additional_properties ⇒ OpenStruct
readonly
Additional properties unmapped to the current class definition.
-
#chunk_plan ⇒ Vapi::ChunkPlan
readonly
This is the plan for chunking the model output before it is sent to the voice provider.
-
#speed ⇒ Float
readonly
This is the speed multiplier that will be used.
-
#voice_id ⇒ Vapi::FallbackOpenAiVoiceId
readonly
This is the provider-specific ID that will be used.
Class Method Summary collapse
-
.from_json(json_object:) ⇒ Vapi::FallbackOpenAiVoice
Deserialize a JSON object to an instance of FallbackOpenAiVoice.
-
.validate_raw(obj:) ⇒ Void
Leveraged for Union-type generation, validate_raw attempts to parse the given hash and check each fields type against the current object’s property definitions.
Instance Method Summary collapse
- #initialize(voice_id:, speed: OMIT, chunk_plan: OMIT, additional_properties: nil) ⇒ Vapi::FallbackOpenAiVoice constructor
-
#to_json(*_args) ⇒ String
Serialize an instance of FallbackOpenAiVoice to a JSON object.
Constructor Details
#initialize(voice_id:, speed: OMIT, chunk_plan: OMIT, additional_properties: nil) ⇒ Vapi::FallbackOpenAiVoice
35 36 37 38 39 40 41 42 43 |
# File 'lib/vapi_server_sdk/types/fallback_open_ai_voice.rb', line 35 def initialize(voice_id:, speed: OMIT, chunk_plan: OMIT, additional_properties: nil) @voice_id = voice_id @speed = speed if speed != OMIT @chunk_plan = chunk_plan if chunk_plan != OMIT @additional_properties = additional_properties @_field_set = { "voiceId": voice_id, "speed": speed, "chunkPlan": chunk_plan }.reject do |_k, v| v == OMIT end end |
Instance Attribute Details
#additional_properties ⇒ OpenStruct (readonly)
Returns Additional properties unmapped to the current class definition.
20 21 22 |
# File 'lib/vapi_server_sdk/types/fallback_open_ai_voice.rb', line 20 def additional_properties @additional_properties end |
#chunk_plan ⇒ Vapi::ChunkPlan (readonly)
Returns This is the plan for chunking the model output before it is sent to the voice provider.
18 19 20 |
# File 'lib/vapi_server_sdk/types/fallback_open_ai_voice.rb', line 18 def chunk_plan @chunk_plan end |
#speed ⇒ Float (readonly)
Returns This is the speed multiplier that will be used.
15 16 17 |
# File 'lib/vapi_server_sdk/types/fallback_open_ai_voice.rb', line 15 def speed @speed end |
#voice_id ⇒ Vapi::FallbackOpenAiVoiceId (readonly)
Returns This is the provider-specific ID that will be used. Please note that ash, ballad, coral, sage, and verse may only be used with realtime models.
13 14 15 |
# File 'lib/vapi_server_sdk/types/fallback_open_ai_voice.rb', line 13 def voice_id @voice_id end |
Class Method Details
.from_json(json_object:) ⇒ Vapi::FallbackOpenAiVoice
Deserialize a JSON object to an instance of FallbackOpenAiVoice
49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 |
# File 'lib/vapi_server_sdk/types/fallback_open_ai_voice.rb', line 49 def self.from_json(json_object:) struct = JSON.parse(json_object, object_class: OpenStruct) parsed_json = JSON.parse(json_object) voice_id = parsed_json["voiceId"] speed = parsed_json["speed"] if parsed_json["chunkPlan"].nil? chunk_plan = nil else chunk_plan = parsed_json["chunkPlan"].to_json chunk_plan = Vapi::ChunkPlan.from_json(json_object: chunk_plan) end new( voice_id: voice_id, speed: speed, chunk_plan: chunk_plan, additional_properties: struct ) end |
.validate_raw(obj:) ⇒ Void
Leveraged for Union-type generation, validate_raw attempts to parse the given
hash and check each fields type against the current object's property
definitions.
81 82 83 84 85 |
# File 'lib/vapi_server_sdk/types/fallback_open_ai_voice.rb', line 81 def self.validate_raw(obj:) obj.voice_id.is_a?(Vapi::FallbackOpenAiVoiceId) != false || raise("Passed value for field obj.voice_id is not the expected type, validation failed.") obj.speed&.is_a?(Float) != false || raise("Passed value for field obj.speed is not the expected type, validation failed.") obj.chunk_plan.nil? || Vapi::ChunkPlan.validate_raw(obj: obj.chunk_plan) end |
Instance Method Details
#to_json(*_args) ⇒ String
Serialize an instance of FallbackOpenAiVoice to a JSON object
71 72 73 |
# File 'lib/vapi_server_sdk/types/fallback_open_ai_voice.rb', line 71 def to_json(*_args) @_field_set&.to_json end |