Class: Vapi::FallbackPlayHtVoice
- Inherits:
-
Object
- Object
- Vapi::FallbackPlayHtVoice
- Defined in:
- lib/vapi_server_sdk/types/fallback_play_ht_voice.rb
Constant Summary collapse
- OMIT =
Object.new
Instance Attribute Summary collapse
-
#additional_properties ⇒ OpenStruct
readonly
Additional properties unmapped to the current class definition.
-
#chunk_plan ⇒ Vapi::ChunkPlan
readonly
This is the plan for chunking the model output before it is sent to the voice provider.
-
#emotion ⇒ Vapi::FallbackPlayHtVoiceEmotion
readonly
An emotion to be applied to the speech.
-
#language ⇒ Vapi::FallbackPlayHtVoiceLanguage
readonly
The language to use for the speech.
-
#model ⇒ Vapi::FallbackPlayHtVoiceModel
readonly
Playht voice model/engine to use.
-
#speed ⇒ Float
readonly
This is the speed multiplier that will be used.
-
#style_guidance ⇒ Float
readonly
A number between 1 and 30.
-
#temperature ⇒ Float
readonly
A floating point number between 0, exclusive, and 2, inclusive.
-
#text_guidance ⇒ Float
readonly
A number between 1 and 2.
-
#voice_guidance ⇒ Float
readonly
A number between 1 and 6.
-
#voice_id ⇒ Vapi::FallbackPlayHtVoiceId
readonly
This is the provider-specific ID that will be used.
Class Method Summary collapse
-
.from_json(json_object:) ⇒ Vapi::FallbackPlayHtVoice
Deserialize a JSON object to an instance of FallbackPlayHtVoice.
-
.validate_raw(obj:) ⇒ Void
Leveraged for Union-type generation, validate_raw attempts to parse the given hash and check each fields type against the current object's property definitions.
Instance Method Summary collapse
- #initialize(voice_id:, speed: OMIT, temperature: OMIT, emotion: OMIT, voice_guidance: OMIT, style_guidance: OMIT, text_guidance: OMIT, model: OMIT, language: OMIT, chunk_plan: OMIT, additional_properties: nil) ⇒ Vapi::FallbackPlayHtVoice constructor
-
#to_json(*_args) ⇒ String
Serialize an instance of FallbackPlayHtVoice to a JSON object.
Constructor Details
#initialize(voice_id:, speed: OMIT, temperature: OMIT, emotion: OMIT, voice_guidance: OMIT, style_guidance: OMIT, text_guidance: OMIT, model: OMIT, language: OMIT, chunk_plan: OMIT, additional_properties: nil) ⇒ Vapi::FallbackPlayHtVoice
75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 |
# File 'lib/vapi_server_sdk/types/fallback_play_ht_voice.rb', line 75 def initialize(voice_id:, speed: OMIT, temperature: OMIT, emotion: OMIT, voice_guidance: OMIT, style_guidance: OMIT, text_guidance: OMIT, model: OMIT, language: OMIT, chunk_plan: OMIT, additional_properties: nil) @voice_id = voice_id @speed = speed if speed != OMIT @temperature = temperature if temperature != OMIT @emotion = emotion if emotion != OMIT @voice_guidance = voice_guidance if voice_guidance != OMIT @style_guidance = style_guidance if style_guidance != OMIT @text_guidance = text_guidance if text_guidance != OMIT @model = model if model != OMIT @language = language if language != OMIT @chunk_plan = chunk_plan if chunk_plan != OMIT @additional_properties = additional_properties @_field_set = { "voiceId": voice_id, "speed": speed, "temperature": temperature, "emotion": emotion, "voiceGuidance": voice_guidance, "styleGuidance": style_guidance, "textGuidance": text_guidance, "model": model, "language": language, "chunkPlan": chunk_plan }.reject do |_k, v| v == OMIT end end |
Instance Attribute Details
#additional_properties ⇒ OpenStruct (readonly)
Returns Additional properties unmapped to the current class definition.
45 46 47 |
# File 'lib/vapi_server_sdk/types/fallback_play_ht_voice.rb', line 45 def additional_properties @additional_properties end |
#chunk_plan ⇒ Vapi::ChunkPlan (readonly)
Returns This is the plan for chunking the model output before it is sent to the voice provider.
43 44 45 |
# File 'lib/vapi_server_sdk/types/fallback_play_ht_voice.rb', line 43 def chunk_plan @chunk_plan end |
#emotion ⇒ Vapi::FallbackPlayHtVoiceEmotion (readonly)
Returns An emotion to be applied to the speech.
24 25 26 |
# File 'lib/vapi_server_sdk/types/fallback_play_ht_voice.rb', line 24 def emotion @emotion end |
#language ⇒ Vapi::FallbackPlayHtVoiceLanguage (readonly)
Returns The language to use for the speech.
40 41 42 |
# File 'lib/vapi_server_sdk/types/fallback_play_ht_voice.rb', line 40 def language @language end |
#model ⇒ Vapi::FallbackPlayHtVoiceModel (readonly)
Returns Playht voice model/engine to use.
38 39 40 |
# File 'lib/vapi_server_sdk/types/fallback_play_ht_voice.rb', line 38 def model @model end |
#speed ⇒ Float (readonly)
Returns This is the speed multiplier that will be used.
16 17 18 |
# File 'lib/vapi_server_sdk/types/fallback_play_ht_voice.rb', line 16 def speed @speed end |
#style_guidance ⇒ Float (readonly)
Returns A number between 1 and 30. Use lower numbers to to reduce how strong your chosen emotion will be. Higher numbers will create a very emotional performance.
30 31 32 |
# File 'lib/vapi_server_sdk/types/fallback_play_ht_voice.rb', line 30 def style_guidance @style_guidance end |
#temperature ⇒ Float (readonly)
Returns A floating point number between 0, exclusive, and 2, inclusive. If equal to null or not provided, the model's default temperature will be used. The temperature parameter controls variance. Lower temperatures result in more predictable results, higher temperatures allow each run to vary more, so the voice may sound less like the baseline voice.
22 23 24 |
# File 'lib/vapi_server_sdk/types/fallback_play_ht_voice.rb', line 22 def temperature @temperature end |
#text_guidance ⇒ Float (readonly)
Returns A number between 1 and 2. This number influences how closely the generated speech adheres to the input text. Use lower values to create more fluid speech, but with a higher chance of deviating from the input text. Higher numbers will make the generated speech more accurate to the input text, ensuring that the words spoken align closely with the provided text.
36 37 38 |
# File 'lib/vapi_server_sdk/types/fallback_play_ht_voice.rb', line 36 def text_guidance @text_guidance end |
#voice_guidance ⇒ Float (readonly)
Returns A number between 1 and 6. Use lower numbers to reduce how unique your chosen voice will be compared to other voices.
27 28 29 |
# File 'lib/vapi_server_sdk/types/fallback_play_ht_voice.rb', line 27 def voice_guidance @voice_guidance end |
#voice_id ⇒ Vapi::FallbackPlayHtVoiceId (readonly)
Returns This is the provider-specific ID that will be used.
14 15 16 |
# File 'lib/vapi_server_sdk/types/fallback_play_ht_voice.rb', line 14 def voice_id @voice_id end |
Class Method Details
.from_json(json_object:) ⇒ Vapi::FallbackPlayHtVoice
Deserialize a JSON object to an instance of FallbackPlayHtVoice
108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 |
# File 'lib/vapi_server_sdk/types/fallback_play_ht_voice.rb', line 108 def self.from_json(json_object:) struct = JSON.parse(json_object, object_class: OpenStruct) parsed_json = JSON.parse(json_object) if parsed_json["voiceId"].nil? voice_id = nil else voice_id = parsed_json["voiceId"].to_json voice_id = Vapi::FallbackPlayHtVoiceId.from_json(json_object: voice_id) end speed = parsed_json["speed"] temperature = parsed_json["temperature"] emotion = parsed_json["emotion"] voice_guidance = parsed_json["voiceGuidance"] style_guidance = parsed_json["styleGuidance"] text_guidance = parsed_json["textGuidance"] model = parsed_json["model"] language = parsed_json["language"] if parsed_json["chunkPlan"].nil? chunk_plan = nil else chunk_plan = parsed_json["chunkPlan"].to_json chunk_plan = Vapi::ChunkPlan.from_json(json_object: chunk_plan) end new( voice_id: voice_id, speed: speed, temperature: temperature, emotion: emotion, voice_guidance: voice_guidance, style_guidance: style_guidance, text_guidance: text_guidance, model: model, language: language, chunk_plan: chunk_plan, additional_properties: struct ) end |
.validate_raw(obj:) ⇒ Void
Leveraged for Union-type generation, validate_raw attempts to parse the given hash and check each fields type against the current object's property definitions.
159 160 161 162 163 164 165 166 167 168 169 170 |
# File 'lib/vapi_server_sdk/types/fallback_play_ht_voice.rb', line 159 def self.validate_raw(obj:) Vapi::FallbackPlayHtVoiceId.validate_raw(obj: obj.voice_id) obj.speed&.is_a?(Float) != false || raise("Passed value for field obj.speed is not the expected type, validation failed.") obj.temperature&.is_a?(Float) != false || raise("Passed value for field obj.temperature is not the expected type, validation failed.") obj.emotion&.is_a?(Vapi::FallbackPlayHtVoiceEmotion) != false || raise("Passed value for field obj.emotion is not the expected type, validation failed.") obj.voice_guidance&.is_a?(Float) != false || raise("Passed value for field obj.voice_guidance is not the expected type, validation failed.") obj.style_guidance&.is_a?(Float) != false || raise("Passed value for field obj.style_guidance is not the expected type, validation failed.") obj.text_guidance&.is_a?(Float) != false || raise("Passed value for field obj.text_guidance is not the expected type, validation failed.") obj.model&.is_a?(Vapi::FallbackPlayHtVoiceModel) != false || raise("Passed value for field obj.model is not the expected type, validation failed.") obj.language&.is_a?(Vapi::FallbackPlayHtVoiceLanguage) != false || raise("Passed value for field obj.language is not the expected type, validation failed.") obj.chunk_plan.nil? || Vapi::ChunkPlan.validate_raw(obj: obj.chunk_plan) end |
Instance Method Details
#to_json(*_args) ⇒ String
Serialize an instance of FallbackPlayHtVoice to a JSON object
149 150 151 |
# File 'lib/vapi_server_sdk/types/fallback_play_ht_voice.rb', line 149 def to_json(*_args) @_field_set&.to_json end |