Class: Vapi::Gather

Inherits:
Object
  • Object
show all
Defined in:
lib/vapi_server_sdk/types/gather.rb

Constant Summary collapse

OMIT =
Object.new

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(type:, instruction:, name:, schema: OMIT, additional_properties: nil) ⇒ Vapi::Gather

Parameters:

  • type (String)
  • schema (Vapi::JsonSchema) (defaults to: OMIT)
  • instruction (String)
  • name (String)
  • additional_properties (OpenStruct) (defaults to: nil)

    Additional properties unmapped to the current class definition



31
32
33
34
35
36
37
38
39
40
# File 'lib/vapi_server_sdk/types/gather.rb', line 31

def initialize(type:, instruction:, name:, schema: OMIT, additional_properties: nil)
  @type = type
  @schema = schema if schema != OMIT
  @instruction = instruction
  @name = name
  @additional_properties = additional_properties
  @_field_set = { "type": type, "schema": schema, "instruction": instruction, "name": name }.reject do |_k, v|
    v == OMIT
  end
end

Instance Attribute Details

#additional_propertiesOpenStruct (readonly)

Returns Additional properties unmapped to the current class definition.

Returns:

  • (OpenStruct)

    Additional properties unmapped to the current class definition



18
19
20
# File 'lib/vapi_server_sdk/types/gather.rb', line 18

def additional_properties
  @additional_properties
end

#instructionString (readonly)

Returns:

  • (String)


14
15
16
# File 'lib/vapi_server_sdk/types/gather.rb', line 14

def instruction
  @instruction
end

#nameString (readonly)

Returns:

  • (String)


16
17
18
# File 'lib/vapi_server_sdk/types/gather.rb', line 16

def name
  @name
end

#schemaVapi::JsonSchema (readonly)

Returns:



12
13
14
# File 'lib/vapi_server_sdk/types/gather.rb', line 12

def schema
  @schema
end

#typeString (readonly)

Returns:

  • (String)


10
11
12
# File 'lib/vapi_server_sdk/types/gather.rb', line 10

def type
  @type
end

Class Method Details

.from_json(json_object:) ⇒ Vapi::Gather

Deserialize a JSON object to an instance of Gather

Parameters:

  • json_object (String)

Returns:



46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
# File 'lib/vapi_server_sdk/types/gather.rb', line 46

def self.from_json(json_object:)
  struct = JSON.parse(json_object, object_class: OpenStruct)
  parsed_json = JSON.parse(json_object)
  type = parsed_json["type"]
  if parsed_json["schema"].nil?
    schema = nil
  else
    schema = parsed_json["schema"].to_json
    schema = Vapi::JsonSchema.from_json(json_object: schema)
  end
  instruction = parsed_json["instruction"]
  name = parsed_json["name"]
  new(
    type: type,
    schema: schema,
    instruction: instruction,
    name: name,
    additional_properties: struct
  )
end

.validate_raw(obj:) ⇒ Void

Leveraged for Union-type generation, validate_raw attempts to parse the given hash and check each fields type against the current object's property definitions.

Parameters:

  • obj (Object)

Returns:

  • (Void)


80
81
82
83
84
85
# File 'lib/vapi_server_sdk/types/gather.rb', line 80

def self.validate_raw(obj:)
  obj.type.is_a?(String) != false || raise("Passed value for field obj.type is not the expected type, validation failed.")
  obj.schema.nil? || Vapi::JsonSchema.validate_raw(obj: obj.schema)
  obj.instruction.is_a?(String) != false || raise("Passed value for field obj.instruction is not the expected type, validation failed.")
  obj.name.is_a?(String) != false || raise("Passed value for field obj.name is not the expected type, validation failed.")
end

Instance Method Details

#to_json(*_args) ⇒ String

Serialize an instance of Gather to a JSON object

Returns:

  • (String)


70
71
72
# File 'lib/vapi_server_sdk/types/gather.rb', line 70

def to_json(*_args)
  @_field_set&.to_json
end