Class: Vapi::OpenAiVoice
- Inherits:
-
Object
- Object
- Vapi::OpenAiVoice
- Defined in:
- lib/vapi_server_sdk/types/open_ai_voice.rb
Constant Summary collapse
- OMIT =
Object.new
Instance Attribute Summary collapse
-
#additional_properties ⇒ OpenStruct
readonly
Additional properties unmapped to the current class definition.
-
#chunk_plan ⇒ Vapi::ChunkPlan
readonly
This is the plan for chunking the model output before it is sent to the voice provider.
-
#fallback_plan ⇒ Vapi::FallbackPlan
readonly
This is the plan for voice provider fallbacks in the event that the primary voice provider fails.
-
#speed ⇒ Float
readonly
This is the speed multiplier that will be used.
-
#voice_id ⇒ Vapi::OpenAiVoiceId
readonly
This is the provider-specific ID that will be used.
Class Method Summary collapse
-
.from_json(json_object:) ⇒ Vapi::OpenAiVoice
Deserialize a JSON object to an instance of OpenAiVoice.
-
.validate_raw(obj:) ⇒ Void
Leveraged for Union-type generation, validate_raw attempts to parse the given hash and check each fields type against the current object's property definitions.
Instance Method Summary collapse
- #initialize(voice_id:, speed: OMIT, chunk_plan: OMIT, fallback_plan: OMIT, additional_properties: nil) ⇒ Vapi::OpenAiVoice constructor
-
#to_json(*_args) ⇒ String
Serialize an instance of OpenAiVoice to a JSON object.
Constructor Details
#initialize(voice_id:, speed: OMIT, chunk_plan: OMIT, fallback_plan: OMIT, additional_properties: nil) ⇒ Vapi::OpenAiVoice
41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 |
# File 'lib/vapi_server_sdk/types/open_ai_voice.rb', line 41 def initialize(voice_id:, speed: OMIT, chunk_plan: OMIT, fallback_plan: OMIT, additional_properties: nil) @voice_id = voice_id @speed = speed if speed != OMIT @chunk_plan = chunk_plan if chunk_plan != OMIT @fallback_plan = fallback_plan if fallback_plan != OMIT @additional_properties = additional_properties @_field_set = { "voiceId": voice_id, "speed": speed, "chunkPlan": chunk_plan, "fallbackPlan": fallback_plan }.reject do |_k, v| v == OMIT end end |
Instance Attribute Details
#additional_properties ⇒ OpenStruct (readonly)
Returns Additional properties unmapped to the current class definition.
24 25 26 |
# File 'lib/vapi_server_sdk/types/open_ai_voice.rb', line 24 def additional_properties @additional_properties end |
#chunk_plan ⇒ Vapi::ChunkPlan (readonly)
Returns This is the plan for chunking the model output before it is sent to the voice provider.
19 20 21 |
# File 'lib/vapi_server_sdk/types/open_ai_voice.rb', line 19 def chunk_plan @chunk_plan end |
#fallback_plan ⇒ Vapi::FallbackPlan (readonly)
Returns This is the plan for voice provider fallbacks in the event that the primary voice provider fails.
22 23 24 |
# File 'lib/vapi_server_sdk/types/open_ai_voice.rb', line 22 def fallback_plan @fallback_plan end |
#speed ⇒ Float (readonly)
Returns This is the speed multiplier that will be used.
16 17 18 |
# File 'lib/vapi_server_sdk/types/open_ai_voice.rb', line 16 def speed @speed end |
#voice_id ⇒ Vapi::OpenAiVoiceId (readonly)
Returns This is the provider-specific ID that will be used. Please note that ash, ballad, coral, sage, and verse may only be used with realtime models.
14 15 16 |
# File 'lib/vapi_server_sdk/types/open_ai_voice.rb', line 14 def voice_id @voice_id end |
Class Method Details
.from_json(json_object:) ⇒ Vapi::OpenAiVoice
Deserialize a JSON object to an instance of OpenAiVoice
61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 |
# File 'lib/vapi_server_sdk/types/open_ai_voice.rb', line 61 def self.from_json(json_object:) struct = JSON.parse(json_object, object_class: OpenStruct) parsed_json = JSON.parse(json_object) voice_id = parsed_json["voiceId"] speed = parsed_json["speed"] if parsed_json["chunkPlan"].nil? chunk_plan = nil else chunk_plan = parsed_json["chunkPlan"].to_json chunk_plan = Vapi::ChunkPlan.from_json(json_object: chunk_plan) end if parsed_json["fallbackPlan"].nil? fallback_plan = nil else fallback_plan = parsed_json["fallbackPlan"].to_json fallback_plan = Vapi::FallbackPlan.from_json(json_object: fallback_plan) end new( voice_id: voice_id, speed: speed, chunk_plan: chunk_plan, fallback_plan: fallback_plan, additional_properties: struct ) end |
.validate_raw(obj:) ⇒ Void
Leveraged for Union-type generation, validate_raw attempts to parse the given hash and check each fields type against the current object's property definitions.
100 101 102 103 104 105 |
# File 'lib/vapi_server_sdk/types/open_ai_voice.rb', line 100 def self.validate_raw(obj:) obj.voice_id.is_a?(Vapi::OpenAiVoiceId) != false || raise("Passed value for field obj.voice_id is not the expected type, validation failed.") obj.speed&.is_a?(Float) != false || raise("Passed value for field obj.speed is not the expected type, validation failed.") obj.chunk_plan.nil? || Vapi::ChunkPlan.validate_raw(obj: obj.chunk_plan) obj.fallback_plan.nil? || Vapi::FallbackPlan.validate_raw(obj: obj.fallback_plan) end |
Instance Method Details
#to_json(*_args) ⇒ String
Serialize an instance of OpenAiVoice to a JSON object
90 91 92 |
# File 'lib/vapi_server_sdk/types/open_ai_voice.rb', line 90 def to_json(*_args) @_field_set&.to_json end |