Class: Vapi::ProgrammaticEdgeCondition
- Inherits:
-
Object
- Object
- Vapi::ProgrammaticEdgeCondition
- Defined in:
- lib/vapi_server_sdk/types/programmatic_edge_condition.rb
Constant Summary collapse
- OMIT =
Object.new
Instance Attribute Summary collapse
-
#additional_properties ⇒ OpenStruct
readonly
Additional properties unmapped to the current class definition.
- #boolean_expression ⇒ String readonly
Class Method Summary collapse
-
.from_json(json_object:) ⇒ Vapi::ProgrammaticEdgeCondition
Deserialize a JSON object to an instance of ProgrammaticEdgeCondition.
-
.validate_raw(obj:) ⇒ Void
Leveraged for Union-type generation, validate_raw attempts to parse the given hash and check each fields type against the current object’s property definitions.
Instance Method Summary collapse
- #initialize(boolean_expression: OMIT, additional_properties: nil) ⇒ Vapi::ProgrammaticEdgeCondition constructor
-
#to_json(*_args) ⇒ String
Serialize an instance of ProgrammaticEdgeCondition to a JSON object.
Constructor Details
#initialize(boolean_expression: OMIT, additional_properties: nil) ⇒ Vapi::ProgrammaticEdgeCondition
21 22 23 24 25 26 27 |
# File 'lib/vapi_server_sdk/types/programmatic_edge_condition.rb', line 21 def initialize(boolean_expression: OMIT, additional_properties: nil) @boolean_expression = boolean_expression if boolean_expression != OMIT @additional_properties = additional_properties @_field_set = { "booleanExpression": boolean_expression }.reject do |_k, v| v == OMIT end end |
Instance Attribute Details
#additional_properties ⇒ OpenStruct (readonly)
Returns Additional properties unmapped to the current class definition.
11 12 13 |
# File 'lib/vapi_server_sdk/types/programmatic_edge_condition.rb', line 11 def additional_properties @additional_properties end |
#boolean_expression ⇒ String (readonly)
9 10 11 |
# File 'lib/vapi_server_sdk/types/programmatic_edge_condition.rb', line 9 def boolean_expression @boolean_expression end |
Class Method Details
.from_json(json_object:) ⇒ Vapi::ProgrammaticEdgeCondition
Deserialize a JSON object to an instance of ProgrammaticEdgeCondition
33 34 35 36 37 38 |
# File 'lib/vapi_server_sdk/types/programmatic_edge_condition.rb', line 33 def self.from_json(json_object:) struct = JSON.parse(json_object, object_class: OpenStruct) parsed_json = JSON.parse(json_object) boolean_expression = parsed_json["booleanExpression"] new(boolean_expression: boolean_expression, additional_properties: struct) end |
.validate_raw(obj:) ⇒ Void
Leveraged for Union-type generation, validate_raw attempts to parse the given
hash and check each fields type against the current object's property
definitions.
53 54 55 |
# File 'lib/vapi_server_sdk/types/programmatic_edge_condition.rb', line 53 def self.validate_raw(obj:) obj.boolean_expression&.is_a?(String) != false || raise("Passed value for field obj.boolean_expression is not the expected type, validation failed.") end |
Instance Method Details
#to_json(*_args) ⇒ String
Serialize an instance of ProgrammaticEdgeCondition to a JSON object
43 44 45 |
# File 'lib/vapi_server_sdk/types/programmatic_edge_condition.rb', line 43 def to_json(*_args) @_field_set&.to_json end |