Class: Vapi::Say

Inherits:
Object
  • Object
show all
Defined in:
lib/vapi_server_sdk/types/say.rb

Constant Summary collapse

OMIT =
Object.new

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(type:, instruction:, name:, additional_properties: nil) ⇒ Vapi::Say

Parameters:

  • type (String)
  • instruction (String)
  • name (String)
  • additional_properties (OpenStruct) (defaults to: nil)

    Additional properties unmapped to the current class definition



27
28
29
30
31
32
33
# File 'lib/vapi_server_sdk/types/say.rb', line 27

def initialize(type:, instruction:, name:, additional_properties: nil)
  @type = type
  @instruction = instruction
  @name = name
  @additional_properties = additional_properties
  @_field_set = { "type": type, "instruction": instruction, "name": name }
end

Instance Attribute Details

#additional_propertiesOpenStruct (readonly)

Returns Additional properties unmapped to the current class definition.

Returns:

  • (OpenStruct)

    Additional properties unmapped to the current class definition



15
16
17
# File 'lib/vapi_server_sdk/types/say.rb', line 15

def additional_properties
  @additional_properties
end

#instructionString (readonly)

Returns:

  • (String)


11
12
13
# File 'lib/vapi_server_sdk/types/say.rb', line 11

def instruction
  @instruction
end

#nameString (readonly)

Returns:

  • (String)


13
14
15
# File 'lib/vapi_server_sdk/types/say.rb', line 13

def name
  @name
end

#typeString (readonly)

Returns:

  • (String)


9
10
11
# File 'lib/vapi_server_sdk/types/say.rb', line 9

def type
  @type
end

Class Method Details

.from_json(json_object:) ⇒ Vapi::Say

Deserialize a JSON object to an instance of Say

Parameters:

  • json_object (String)

Returns:



39
40
41
42
43
44
45
46
47
48
49
50
51
# File 'lib/vapi_server_sdk/types/say.rb', line 39

def self.from_json(json_object:)
  struct = JSON.parse(json_object, object_class: OpenStruct)
  parsed_json = JSON.parse(json_object)
  type = parsed_json["type"]
  instruction = parsed_json["instruction"]
  name = parsed_json["name"]
  new(
    type: type,
    instruction: instruction,
    name: name,
    additional_properties: struct
  )
end

.validate_raw(obj:) ⇒ Void

Leveraged for Union-type generation, validate_raw attempts to parse the given

hash and check each fields type against the current object's property
definitions.

Parameters:

  • obj (Object)

Returns:

  • (Void)


66
67
68
69
70
# File 'lib/vapi_server_sdk/types/say.rb', line 66

def self.validate_raw(obj:)
  obj.type.is_a?(String) != false || raise("Passed value for field obj.type is not the expected type, validation failed.")
  obj.instruction.is_a?(String) != false || raise("Passed value for field obj.instruction is not the expected type, validation failed.")
  obj.name.is_a?(String) != false || raise("Passed value for field obj.name is not the expected type, validation failed.")
end

Instance Method Details

#to_json(*_args) ⇒ String

Serialize an instance of Say to a JSON object

Returns:

  • (String)


56
57
58
# File 'lib/vapi_server_sdk/types/say.rb', line 56

def to_json(*_args)
  @_field_set&.to_json
end