Class: Vapi::ServerMessageResponseAssistantRequestDestination
- Inherits:
-
Object
- Object
- Vapi::ServerMessageResponseAssistantRequestDestination
- Defined in:
- lib/vapi_server_sdk/types/server_message_response_assistant_request_destination.rb
Overview
This is the destination to transfer the inbound call to. This will immediately
transfer without using any assistants.
If this is sent, assistantId, assistant, squadId, and squad are ignored.
Instance Attribute Summary collapse
- #discriminant ⇒ String readonly
- #member ⇒ Object readonly
Class Method Summary collapse
-
.from_json(json_object:) ⇒ Vapi::ServerMessageResponseAssistantRequestDestination
Deserialize a JSON object to an instance of ServerMessageResponseAssistantRequestDestination.
- .number(member:) ⇒ Vapi::ServerMessageResponseAssistantRequestDestination
- .sip(member:) ⇒ Vapi::ServerMessageResponseAssistantRequestDestination
-
.validate_raw(obj:) ⇒ Void
Leveraged for Union-type generation, validate_raw attempts to parse the given hash and check each fields type against the current object's property definitions.
Instance Method Summary collapse
- #initialize(member:, discriminant:) ⇒ Vapi::ServerMessageResponseAssistantRequestDestination constructor
-
#is_a?(obj) ⇒ Boolean
For Union Types, is_a? functionality is delegated to the wrapped member.
- #kind_of? ⇒ Object
-
#to_json(*_args) ⇒ String
For Union Types, to_json functionality is delegated to the wrapped member.
Constructor Details
#initialize(member:, discriminant:) ⇒ Vapi::ServerMessageResponseAssistantRequestDestination
23 24 25 26 |
# File 'lib/vapi_server_sdk/types/server_message_response_assistant_request_destination.rb', line 23 def initialize(member:, discriminant:) @member = member @discriminant = discriminant end |
Instance Attribute Details
#discriminant ⇒ String (readonly)
15 16 17 |
# File 'lib/vapi_server_sdk/types/server_message_response_assistant_request_destination.rb', line 15 def discriminant @discriminant end |
#member ⇒ Object (readonly)
13 14 15 |
# File 'lib/vapi_server_sdk/types/server_message_response_assistant_request_destination.rb', line 13 def member @member end |
Class Method Details
.from_json(json_object:) ⇒ Vapi::ServerMessageResponseAssistantRequestDestination
Deserialize a JSON object to an instance of ServerMessageResponseAssistantRequestDestination
33 34 35 36 37 38 39 40 41 42 43 44 |
# File 'lib/vapi_server_sdk/types/server_message_response_assistant_request_destination.rb', line 33 def self.from_json(json_object:) struct = JSON.parse(json_object, object_class: OpenStruct) member = case struct.type when "number" Vapi::TransferDestinationNumber.from_json(json_object: json_object) when "sip" Vapi::TransferDestinationSip.from_json(json_object: json_object) else Vapi::TransferDestinationNumber.from_json(json_object: json_object) end new(member: member, discriminant: struct.type) end |
.number(member:) ⇒ Vapi::ServerMessageResponseAssistantRequestDestination
88 89 90 |
# File 'lib/vapi_server_sdk/types/server_message_response_assistant_request_destination.rb', line 88 def self.number(member:) new(member: member, discriminant: "number") end |
.sip(member:) ⇒ Vapi::ServerMessageResponseAssistantRequestDestination
94 95 96 |
# File 'lib/vapi_server_sdk/types/server_message_response_assistant_request_destination.rb', line 94 def self.sip(member:) new(member: member, discriminant: "sip") end |
.validate_raw(obj:) ⇒ Void
Leveraged for Union-type generation, validate_raw attempts to parse the given hash and check each fields type against the current object's property definitions.
67 68 69 70 71 72 73 74 75 76 |
# File 'lib/vapi_server_sdk/types/server_message_response_assistant_request_destination.rb', line 67 def self.validate_raw(obj:) case obj.type when "number" Vapi::TransferDestinationNumber.validate_raw(obj: obj) when "sip" Vapi::TransferDestinationSip.validate_raw(obj: obj) else raise("Passed value matched no type within the union, validation failed.") end end |
Instance Method Details
#is_a?(obj) ⇒ Boolean
For Union Types, is_a? functionality is delegated to the wrapped member.
82 83 84 |
# File 'lib/vapi_server_sdk/types/server_message_response_assistant_request_destination.rb', line 82 def is_a?(obj) @member.is_a?(obj) end |
#kind_of? ⇒ Object
18 |
# File 'lib/vapi_server_sdk/types/server_message_response_assistant_request_destination.rb', line 18 alias kind_of? is_a? |
#to_json(*_args) ⇒ String
For Union Types, to_json functionality is delegated to the wrapped member.
49 50 51 52 53 54 55 56 57 58 59 |
# File 'lib/vapi_server_sdk/types/server_message_response_assistant_request_destination.rb', line 49 def to_json(*_args) case @discriminant when "number" { **@member.to_json, type: @discriminant }.to_json when "sip" { **@member.to_json, type: @discriminant }.to_json else { "type": @discriminant, value: @member }.to_json end @member.to_json end |