Class: Vapi::StructuredOutputs::Types::UpdateStructuredOutputDtoModel
- Inherits:
-
Internal::Types::Model
- Object
- Internal::Types::Model
- Vapi::StructuredOutputs::Types::UpdateStructuredOutputDtoModel
- Extended by:
- Internal::Types::Union
- Defined in:
- lib/vapi/structured_outputs/types/update_structured_output_dto_model.rb
Overview
This is the model that will be used to extract the structured output.
To provide your own custom system and user prompts for structured output extraction, populate the messages array
with your system and user messages. You can specify liquid templating in your system and user messages.
Between the system or user messages, you must reference either 'transcript' or 'messages' with the {{}} syntax
to access the conversation history.
Between the system or user messages, you must reference a variation of the structured output with the {{}}
syntax to access the structured output definition.
i.e.:
{{structuredOutput}}
{{structuredOutput.name}}
{{structuredOutput.description}}
{{structuredOutput.schema}}
If model is not specified, GPT-4.1 will be used by default for extraction, utilizing default system and user prompts. If messages or required fields are not specified, the default system and user prompts will be used.
Method Summary
Methods included from Internal::Types::Union
coerce, discriminant, load, member, members, type_member?
Methods included from Internal::Types::Type
Methods included from Internal::JSON::Serializable
Methods inherited from Internal::Types::Model
#==, ===, add_extra_field_definition, coerce, extra_fields, field, fields, #initialize, #inspect, literal, load, #to_h
Constructor Details
This class inherits a constructor from Vapi::Internal::Types::Model