Class: Vapi::TextEditorToolWithToolCall
- Inherits:
-
Object
- Object
- Vapi::TextEditorToolWithToolCall
- Defined in:
- lib/vapi_server_sdk/types/text_editor_tool_with_tool_call.rb
Constant Summary collapse
- OMIT =
Object.new
Instance Attribute Summary collapse
-
#additional_properties ⇒ OpenStruct
readonly
Additional properties unmapped to the current class definition.
-
#async ⇒ Boolean
readonly
This determines if the tool is async.
-
#function ⇒ Vapi::OpenAiFunction
readonly
This is the function definition of the tool.
-
#messages ⇒ Array<Vapi::TextEditorToolWithToolCallMessagesItem>
readonly
These are the messages that will be spoken to the user as the tool is running.
-
#name ⇒ String
readonly
The name of the tool, fixed to ‘str_replace_editor’.
-
#server ⇒ Vapi::Server
readonly
This is the server that will be hit when this tool is requested by the model.
-
#sub_type ⇒ String
readonly
The sub type of tool.
- #tool_call ⇒ Vapi::ToolCall readonly
Class Method Summary collapse
-
.from_json(json_object:) ⇒ Vapi::TextEditorToolWithToolCall
Deserialize a JSON object to an instance of TextEditorToolWithToolCall.
-
.validate_raw(obj:) ⇒ Void
Leveraged for Union-type generation, validate_raw attempts to parse the given hash and check each fields type against the current object’s property definitions.
Instance Method Summary collapse
- #initialize(sub_type:, tool_call:, name:, async: OMIT, messages: OMIT, function: OMIT, server: OMIT, additional_properties: nil) ⇒ Vapi::TextEditorToolWithToolCall constructor
-
#to_json(*_args) ⇒ String
Serialize an instance of TextEditorToolWithToolCall to a JSON object.
Constructor Details
#initialize(sub_type:, tool_call:, name:, async: OMIT, messages: OMIT, function: OMIT, server: OMIT, additional_properties: nil) ⇒ Vapi::TextEditorToolWithToolCall
85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 |
# File 'lib/vapi_server_sdk/types/text_editor_tool_with_tool_call.rb', line 85 def initialize(sub_type:, tool_call:, name:, async: OMIT, messages: OMIT, function: OMIT, server: OMIT, additional_properties: nil) @async = async if async != OMIT @messages = if != OMIT @sub_type = sub_type @tool_call = tool_call @name = name @function = function if function != OMIT @server = server if server != OMIT @additional_properties = additional_properties @_field_set = { "async": async, "messages": , "subType": sub_type, "toolCall": tool_call, "name": name, "function": function, "server": server }.reject do |_k, v| v == OMIT end end |
Instance Attribute Details
#additional_properties ⇒ OpenStruct (readonly)
Returns Additional properties unmapped to the current class definition.
48 49 50 |
# File 'lib/vapi_server_sdk/types/text_editor_tool_with_tool_call.rb', line 48 def additional_properties @additional_properties end |
#async ⇒ Boolean (readonly)
Returns This determines if the tool is async. If async, the assistant will move forward without waiting for your server to respond. This is useful if you just want to trigger something on your server. If sync, the assistant will wait for your server to respond. This is useful if want assistant to respond with the result from your server. Defaults to synchronous (false).
18 19 20 |
# File 'lib/vapi_server_sdk/types/text_editor_tool_with_tool_call.rb', line 18 def async @async end |
#function ⇒ Vapi::OpenAiFunction (readonly)
Returns This is the function definition of the tool. For endCall, transferCall, and dtmf tools, this is auto-filled based on tool-specific fields like tool.destinations. But, even in those cases, you can provide a custom function definition for advanced use cases. An example of an advanced use case is if you want to customize the message that’s spoken for endCall tool. You can specify a function where it returns an argument “reason”. Then, in messages array, you can have many “request-complete” messages. One of these messages will be triggered if the messages[].conditions matches the “reason” argument.
39 40 41 |
# File 'lib/vapi_server_sdk/types/text_editor_tool_with_tool_call.rb', line 39 def function @function end |
#messages ⇒ Array<Vapi::TextEditorToolWithToolCallMessagesItem> (readonly)
Returns These are the messages that will be spoken to the user as the tool is running. For some tools, this is auto-filled based on special fields like tool.destinations. For others like the function tool, these can be custom configured.
23 24 25 |
# File 'lib/vapi_server_sdk/types/text_editor_tool_with_tool_call.rb', line 23 def @messages end |
#name ⇒ String (readonly)
Returns The name of the tool, fixed to ‘str_replace_editor’.
29 30 31 |
# File 'lib/vapi_server_sdk/types/text_editor_tool_with_tool_call.rb', line 29 def name @name end |
#server ⇒ Vapi::Server (readonly)
Returns This is the server that will be hit when this tool is requested by the model. All requests will be sent with the call object among other things. You can find more details in the Server URL documentation. This overrides the serverUrl set on the org and the phoneNumber. Order of precedence: highest tool.server.url, then assistant.serverUrl, then phoneNumber.serverUrl, then org.serverUrl.
46 47 48 |
# File 'lib/vapi_server_sdk/types/text_editor_tool_with_tool_call.rb', line 46 def server @server end |
#sub_type ⇒ String (readonly)
Returns The sub type of tool.
25 26 27 |
# File 'lib/vapi_server_sdk/types/text_editor_tool_with_tool_call.rb', line 25 def sub_type @sub_type end |
#tool_call ⇒ Vapi::ToolCall (readonly)
27 28 29 |
# File 'lib/vapi_server_sdk/types/text_editor_tool_with_tool_call.rb', line 27 def tool_call @tool_call end |
Class Method Details
.from_json(json_object:) ⇒ Vapi::TextEditorToolWithToolCall
Deserialize a JSON object to an instance of TextEditorToolWithToolCall
112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 |
# File 'lib/vapi_server_sdk/types/text_editor_tool_with_tool_call.rb', line 112 def self.from_json(json_object:) struct = JSON.parse(json_object, object_class: OpenStruct) parsed_json = JSON.parse(json_object) async = parsed_json["async"] = parsed_json["messages"]&.map do |item| item = item.to_json Vapi::TextEditorToolWithToolCallMessagesItem.from_json(json_object: item) end sub_type = parsed_json["subType"] if parsed_json["toolCall"].nil? tool_call = nil else tool_call = parsed_json["toolCall"].to_json tool_call = Vapi::ToolCall.from_json(json_object: tool_call) end name = parsed_json["name"] if parsed_json["function"].nil? function = nil else function = parsed_json["function"].to_json function = Vapi::OpenAiFunction.from_json(json_object: function) end if parsed_json["server"].nil? server = nil else server = parsed_json["server"].to_json server = Vapi::Server.from_json(json_object: server) end new( async: async, messages: , sub_type: sub_type, tool_call: tool_call, name: name, function: function, server: server, additional_properties: struct ) end |
.validate_raw(obj:) ⇒ Void
Leveraged for Union-type generation, validate_raw attempts to parse the given
hash and check each fields type against the current object's property
definitions.
165 166 167 168 169 170 171 172 173 |
# File 'lib/vapi_server_sdk/types/text_editor_tool_with_tool_call.rb', line 165 def self.validate_raw(obj:) obj.async&.is_a?(Boolean) != false || raise("Passed value for field obj.async is not the expected type, validation failed.") obj.&.is_a?(Array) != false || raise("Passed value for field obj.messages is not the expected type, validation failed.") obj.sub_type.is_a?(String) != false || raise("Passed value for field obj.sub_type is not the expected type, validation failed.") Vapi::ToolCall.validate_raw(obj: obj.tool_call) obj.name.is_a?(String) != false || raise("Passed value for field obj.name is not the expected type, validation failed.") obj.function.nil? || Vapi::OpenAiFunction.validate_raw(obj: obj.function) obj.server.nil? || Vapi::Server.validate_raw(obj: obj.server) end |
Instance Method Details
#to_json(*_args) ⇒ String
Serialize an instance of TextEditorToolWithToolCall to a JSON object
155 156 157 |
# File 'lib/vapi_server_sdk/types/text_editor_tool_with_tool_call.rb', line 155 def to_json(*_args) @_field_set&.to_json end |