Class: Vapi::ToolMessageCompleteRole

Inherits:
Object
  • Object
show all
Defined in:
lib/vapi_server_sdk/types/tool_message_complete_role.rb

Overview

This is optional and defaults to "assistant". When role=assistant, content is said out loud. When role=system, content is passed to the model in a system message. Example: system: default one assistant: user: assistant: user: assistant: user: assistant: tool called tool: your server response <--- system prompt as hint ---> model generates response which is spoken This is useful when you want to provide a hint to the model about what to say next.

Constant Summary collapse

ASSISTANT =
"assistant"
SYSTEM =
"system"