Class: Vapi::TransferCallTool

Inherits:
Object
  • Object
show all
Defined in:
lib/vapi_server_sdk/types/transfer_call_tool.rb

Constant Summary collapse

OMIT =
Object.new

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(id:, org_id:, created_at:, updated_at:, async: OMIT, messages: OMIT, destinations: OMIT, function: OMIT, server: OMIT, additional_properties: nil) ⇒ Vapi::TransferCallTool

Parameters:

  • async (Boolean) (defaults to: OMIT)

    This determines if the tool is async. If async, the assistant will move forward without waiting for your server to respond. This is useful if you just want to trigger something on your server. If sync, the assistant will wait for your server to respond. This is useful if want assistant to respond with the result from your server. Defaults to synchronous (false).

  • messages (Array<Vapi::TransferCallToolMessagesItem>) (defaults to: OMIT)

    These are the messages that will be spoken to the user as the tool is running. For some tools, this is auto-filled based on special fields like tool.destinations. For others like the function tool, these can be custom configured.

  • destinations (Array<Vapi::TransferCallToolDestinationsItem>) (defaults to: OMIT)

    These are the destinations that the call can be transferred to. If no destinations are provided, server.url will be used to get the transfer destination once the tool is called.

  • id (String)

    This is the unique identifier for the tool.

  • org_id (String)

    This is the unique identifier for the organization that this tool belongs to.

  • created_at (DateTime)

    This is the ISO 8601 date-time string of when the tool was created.

  • updated_at (DateTime)

    This is the ISO 8601 date-time string of when the tool was last updated.

  • function (Vapi::OpenAiFunction) (defaults to: OMIT)

    This is the function definition of the tool. For endCall, transferCall, and dtmf tools, this is auto-filled based on tool-specific fields like tool.destinations. But, even in those cases, you can provide a custom function definition for advanced use cases. An example of an advanced use case is if you want to customize the message that’s spoken for endCall tool. You can specify a function where it returns an argument “reason”. Then, in messages array, you can have many “request-complete” messages. One of these messages will be triggered if the messages[].conditions matches the “reason” argument.

  • server (Vapi::Server) (defaults to: OMIT)

    This is the server that will be hit when this tool is requested by the model. All requests will be sent with the call object among other things. You can find more details in the Server URL documentation. This overrides the serverUrl set on the org and the phoneNumber. Order of precedence: highest tool.server.url, then assistant.serverUrl, then phoneNumber.serverUrl, then org.serverUrl.

  • additional_properties (OpenStruct) (defaults to: nil)

    Additional properties unmapped to the current class definition



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
# File 'lib/vapi_server_sdk/types/transfer_call_tool.rb', line 96

def initialize(id:, org_id:, created_at:, updated_at:, async: OMIT, messages: OMIT, destinations: OMIT,
               function: OMIT, server: OMIT, additional_properties: nil)
  @async = async if async != OMIT
  @messages = messages if messages != OMIT
  @destinations = destinations if destinations != OMIT
  @id = id
  @org_id = org_id
  @created_at = created_at
  @updated_at = updated_at
  @function = function if function != OMIT
  @server = server if server != OMIT
  @additional_properties = additional_properties
  @_field_set = {
    "async": async,
    "messages": messages,
    "destinations": destinations,
    "id": id,
    "orgId": org_id,
    "createdAt": created_at,
    "updatedAt": updated_at,
    "function": function,
    "server": server
  }.reject do |_k, v|
    v == OMIT
  end
end

Instance Attribute Details

#additional_propertiesOpenStruct (readonly)

Returns Additional properties unmapped to the current class definition.

Returns:

  • (OpenStruct)

    Additional properties unmapped to the current class definition



55
56
57
# File 'lib/vapi_server_sdk/types/transfer_call_tool.rb', line 55

def additional_properties
  @additional_properties
end

#asyncBoolean (readonly)

Returns This determines if the tool is async. If async, the assistant will move forward without waiting for your server to respond. This is useful if you just want to trigger something on your server. If sync, the assistant will wait for your server to respond. This is useful if want assistant to respond with the result from your server. Defaults to synchronous (false).

Returns:

  • (Boolean)

    This determines if the tool is async. If async, the assistant will move forward without waiting for your server to respond. This is useful if you just want to trigger something on your server. If sync, the assistant will wait for your server to respond. This is useful if want assistant to respond with the result from your server. Defaults to synchronous (false).



19
20
21
# File 'lib/vapi_server_sdk/types/transfer_call_tool.rb', line 19

def async
  @async
end

#created_atDateTime (readonly)

Returns This is the ISO 8601 date-time string of when the tool was created.

Returns:

  • (DateTime)

    This is the ISO 8601 date-time string of when the tool was created.



34
35
36
# File 'lib/vapi_server_sdk/types/transfer_call_tool.rb', line 34

def created_at
  @created_at
end

#destinationsArray<Vapi::TransferCallToolDestinationsItem> (readonly)

Returns These are the destinations that the call can be transferred to. If no destinations are provided, server.url will be used to get the transfer destination once the tool is called.

Returns:

  • (Array<Vapi::TransferCallToolDestinationsItem>)

    These are the destinations that the call can be transferred to. If no destinations are provided, server.url will be used to get the transfer destination once the tool is called.



28
29
30
# File 'lib/vapi_server_sdk/types/transfer_call_tool.rb', line 28

def destinations
  @destinations
end

#functionVapi::OpenAiFunction (readonly)

Returns This is the function definition of the tool. For endCall, transferCall, and dtmf tools, this is auto-filled based on tool-specific fields like tool.destinations. But, even in those cases, you can provide a custom function definition for advanced use cases. An example of an advanced use case is if you want to customize the message that’s spoken for endCall tool. You can specify a function where it returns an argument “reason”. Then, in messages array, you can have many “request-complete” messages. One of these messages will be triggered if the messages[].conditions matches the “reason” argument.

Returns:

  • (Vapi::OpenAiFunction)

    This is the function definition of the tool. For endCall, transferCall, and dtmf tools, this is auto-filled based on tool-specific fields like tool.destinations. But, even in those cases, you can provide a custom function definition for advanced use cases. An example of an advanced use case is if you want to customize the message that’s spoken for endCall tool. You can specify a function where it returns an argument “reason”. Then, in messages array, you can have many “request-complete” messages. One of these messages will be triggered if the messages[].conditions matches the “reason” argument.



46
47
48
# File 'lib/vapi_server_sdk/types/transfer_call_tool.rb', line 46

def function
  @function
end

#idString (readonly)

Returns This is the unique identifier for the tool.

Returns:

  • (String)

    This is the unique identifier for the tool.



30
31
32
# File 'lib/vapi_server_sdk/types/transfer_call_tool.rb', line 30

def id
  @id
end

#messagesArray<Vapi::TransferCallToolMessagesItem> (readonly)

Returns These are the messages that will be spoken to the user as the tool is running. For some tools, this is auto-filled based on special fields like tool.destinations. For others like the function tool, these can be custom configured.

Returns:

  • (Array<Vapi::TransferCallToolMessagesItem>)

    These are the messages that will be spoken to the user as the tool is running. For some tools, this is auto-filled based on special fields like tool.destinations. For others like the function tool, these can be custom configured.



24
25
26
# File 'lib/vapi_server_sdk/types/transfer_call_tool.rb', line 24

def messages
  @messages
end

#org_idString (readonly)

Returns This is the unique identifier for the organization that this tool belongs to.

Returns:

  • (String)

    This is the unique identifier for the organization that this tool belongs to.



32
33
34
# File 'lib/vapi_server_sdk/types/transfer_call_tool.rb', line 32

def org_id
  @org_id
end

#serverVapi::Server (readonly)

Returns This is the server that will be hit when this tool is requested by the model. All requests will be sent with the call object among other things. You can find more details in the Server URL documentation. This overrides the serverUrl set on the org and the phoneNumber. Order of precedence: highest tool.server.url, then assistant.serverUrl, then phoneNumber.serverUrl, then org.serverUrl.

Returns:

  • (Vapi::Server)

    This is the server that will be hit when this tool is requested by the model. All requests will be sent with the call object among other things. You can find more details in the Server URL documentation. This overrides the serverUrl set on the org and the phoneNumber. Order of precedence: highest tool.server.url, then assistant.serverUrl, then phoneNumber.serverUrl, then org.serverUrl.



53
54
55
# File 'lib/vapi_server_sdk/types/transfer_call_tool.rb', line 53

def server
  @server
end

#updated_atDateTime (readonly)

Returns This is the ISO 8601 date-time string of when the tool was last updated.

Returns:

  • (DateTime)

    This is the ISO 8601 date-time string of when the tool was last updated.



36
37
38
# File 'lib/vapi_server_sdk/types/transfer_call_tool.rb', line 36

def updated_at
  @updated_at
end

Class Method Details

.from_json(json_object:) ⇒ Vapi::TransferCallTool

Deserialize a JSON object to an instance of TransferCallTool

Parameters:

  • json_object (String)

Returns:



127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
# File 'lib/vapi_server_sdk/types/transfer_call_tool.rb', line 127

def self.from_json(json_object:)
  struct = JSON.parse(json_object, object_class: OpenStruct)
  parsed_json = JSON.parse(json_object)
  async = parsed_json["async"]
  messages = parsed_json["messages"]&.map do |item|
    item = item.to_json
    Vapi::TransferCallToolMessagesItem.from_json(json_object: item)
  end
  destinations = parsed_json["destinations"]&.map do |item|
    item = item.to_json
    Vapi::TransferCallToolDestinationsItem.from_json(json_object: item)
  end
  id = parsed_json["id"]
  org_id = parsed_json["orgId"]
  created_at = (DateTime.parse(parsed_json["createdAt"]) unless parsed_json["createdAt"].nil?)
  updated_at = (DateTime.parse(parsed_json["updatedAt"]) unless parsed_json["updatedAt"].nil?)
  if parsed_json["function"].nil?
    function = nil
  else
    function = parsed_json["function"].to_json
    function = Vapi::OpenAiFunction.from_json(json_object: function)
  end
  if parsed_json["server"].nil?
    server = nil
  else
    server = parsed_json["server"].to_json
    server = Vapi::Server.from_json(json_object: server)
  end
  new(
    async: async,
    messages: messages,
    destinations: destinations,
    id: id,
    org_id: org_id,
    created_at: created_at,
    updated_at: updated_at,
    function: function,
    server: server,
    additional_properties: struct
  )
end

.validate_raw(obj:) ⇒ Void

Leveraged for Union-type generation, validate_raw attempts to parse the given

hash and check each fields type against the current object's property
definitions.

Parameters:

  • obj (Object)

Returns:

  • (Void)


182
183
184
185
186
187
188
189
190
191
192
# File 'lib/vapi_server_sdk/types/transfer_call_tool.rb', line 182

def self.validate_raw(obj:)
  obj.async&.is_a?(Boolean) != false || raise("Passed value for field obj.async is not the expected type, validation failed.")
  obj.messages&.is_a?(Array) != false || raise("Passed value for field obj.messages is not the expected type, validation failed.")
  obj.destinations&.is_a?(Array) != false || raise("Passed value for field obj.destinations is not the expected type, validation failed.")
  obj.id.is_a?(String) != false || raise("Passed value for field obj.id is not the expected type, validation failed.")
  obj.org_id.is_a?(String) != false || raise("Passed value for field obj.org_id is not the expected type, validation failed.")
  obj.created_at.is_a?(DateTime) != false || raise("Passed value for field obj.created_at is not the expected type, validation failed.")
  obj.updated_at.is_a?(DateTime) != false || raise("Passed value for field obj.updated_at is not the expected type, validation failed.")
  obj.function.nil? || Vapi::OpenAiFunction.validate_raw(obj: obj.function)
  obj.server.nil? || Vapi::Server.validate_raw(obj: obj.server)
end

Instance Method Details

#to_json(*_args) ⇒ String

Serialize an instance of TransferCallTool to a JSON object

Returns:

  • (String)


172
173
174
# File 'lib/vapi_server_sdk/types/transfer_call_tool.rb', line 172

def to_json(*_args)
  @_field_set&.to_json
end