Class: Vapi::Types::AssistantMessageJudgePlanAiModel

Inherits:
Internal::Types::Model show all
Extended by:
Internal::Types::Union
Defined in:
lib/vapi/types/assistant_message_judge_plan_ai_model.rb

Overview

This is the model to use for the LLM-as-a-judge. If not provided, will default to the assistant's model.

The instructions on how to evaluate the model output with this LLM-Judge must be passed as a system message in the messages array of the model.

The Mock conversation can be passed to the LLM-Judge to evaluate using the prompt {messages} and will be evaluated as a LiquidJS Variable. To access and judge only the last message, use {messages[-1]}

The LLM-Judge must respond with "pass" or "fail" and only those two responses are allowed.

Method Summary

Methods included from Internal::Types::Union

coerce, discriminant, load, member, members, type_member?

Methods included from Internal::Types::Type

#coerce, #strict!, #strict?

Methods included from Internal::JSON::Serializable

#dump, #load

Methods inherited from Internal::Types::Model

#==, ===, add_extra_field_definition, coerce, extra_fields, field, fields, #initialize, #inspect, literal, load, #to_h

Constructor Details

This class inherits a constructor from Vapi::Internal::Types::Model