Class: Vapi::Types::ChatEvalAssistantMessageEvaluationJudgePlan

Inherits:
Internal::Types::Model show all
Extended by:
Internal::Types::Union
Defined in:
lib/vapi/types/chat_eval_assistant_message_evaluation_judge_plan.rb

Overview

This is the judge plan that instructs how to evaluate the assistant message. The assistant message can be evaluated against fixed content (exact match or RegEx) or with an LLM-as-judge by defining the evaluation criteria in a prompt.

Method Summary

Methods included from Internal::Types::Union

coerce, discriminant, load, member, members, type_member?

Methods included from Internal::Types::Type

#coerce, #strict!, #strict?

Methods included from Internal::JSON::Serializable

#dump, #load

Methods inherited from Internal::Types::Model

#==, ===, add_extra_field_definition, coerce, extra_fields, field, fields, #initialize, #inspect, literal, load, #to_h

Constructor Details

This class inherits a constructor from Vapi::Internal::Types::Model