Class: Vapi::Types::CreateTwilioPhoneNumberDtoFallbackDestination
- Inherits:
-
Internal::Types::Model
- Object
- Internal::Types::Model
- Vapi::Types::CreateTwilioPhoneNumberDtoFallbackDestination
- Extended by:
- Internal::Types::Union
- Defined in:
- lib/vapi/types/create_twilio_phone_number_dto_fallback_destination.rb
Overview
This is the fallback destination an inbound call will be transferred to if:
assistantIdis not setsquadIdis not set- and,
assistant-requestmessage to theserverUrlfails
If this is not set and above conditions are met, the inbound call is hung up with an error message.
Method Summary
Methods included from Internal::Types::Union
coerce, discriminant, load, member, members, type_member?
Methods included from Internal::Types::Type
Methods included from Internal::JSON::Serializable
Methods inherited from Internal::Types::Model
#==, ===, add_extra_field_definition, coerce, extra_fields, field, fields, #initialize, #inspect, literal, load, #to_h
Constructor Details
This class inherits a constructor from Vapi::Internal::Types::Model