Class: Vapi::Types::StartSpeakingPlanSmartEndpointingPlan

Inherits:
Internal::Types::Model show all
Extended by:
Internal::Types::Union
Defined in:
lib/vapi/types/start_speaking_plan_smart_endpointing_plan.rb

Overview

This is the plan for smart endpointing. Pick between Vapi smart endpointing, LiveKit, or custom endpointing model (or nothing). We strongly recommend using livekit endpointing when working in English. LiveKit endpointing is not supported in other languages, yet.

If this is set, it will override and take precedence over transcriptionEndpointingPlan. This plan will still be overridden by any matching customEndpointingRules.

If this is not set, the system will automatically use the transcriber's built-in endpointing capabilities if available.

Method Summary

Methods included from Internal::Types::Union

coerce, discriminant, load, member, members, type_member?

Methods included from Internal::Types::Type

#coerce, #strict!, #strict?

Methods included from Internal::JSON::Serializable

#dump, #load

Methods inherited from Internal::Types::Model

#==, ===, add_extra_field_definition, coerce, extra_fields, field, fields, #initialize, #inspect, literal, load, #to_h

Constructor Details

This class inherits a constructor from Vapi::Internal::Types::Model