Class: Vapi::Types::TransferDestinationNumberMessage
- Inherits:
-
Internal::Types::Model
- Object
- Internal::Types::Model
- Vapi::Types::TransferDestinationNumberMessage
- Extended by:
- Internal::Types::Union
- Defined in:
- lib/vapi/types/transfer_destination_number_message.rb
Overview
This is spoken to the customer before connecting them to the destination.
Usage:
- If this is not provided and transfer tool messages is not provided, default is "Transferring the call now".
- If set to "", nothing is spoken. This is useful when you want to silently transfer. This is especially useful
when transferring between assistants in a squad. In this scenario, you likely also want to set
assistant.firstMessageMode=assistant-speaks-first-with-model-generated-messagefor the destination assistant.
This accepts a string or a ToolMessageStart class. Latter is useful if you want to specify multiple messages for
different languages through the contents field.
Method Summary
Methods included from Internal::Types::Union
coerce, discriminant, load, member, members, type_member?
Methods included from Internal::Types::Type
Methods included from Internal::JSON::Serializable
Methods inherited from Internal::Types::Model
#==, ===, add_extra_field_definition, coerce, extra_fields, field, fields, #initialize, #inspect, literal, load, #to_h
Constructor Details
This class inherits a constructor from Vapi::Internal::Types::Model