Class: Vapi::Types::TransferDestinationSipMessage

Inherits:
Internal::Types::Model show all
Extended by:
Internal::Types::Union
Defined in:
lib/vapi/types/transfer_destination_sip_message.rb

Overview

This is spoken to the customer before connecting them to the destination.

Usage:

  • If this is not provided and transfer tool messages is not provided, default is "Transferring the call now".
  • If set to "", nothing is spoken. This is useful when you want to silently transfer. This is especially useful when transferring between assistants in a squad. In this scenario, you likely also want to set assistant.firstMessageMode=assistant-speaks-first-with-model-generated-message for the destination assistant.

This accepts a string or a ToolMessageStart class. Latter is useful if you want to specify multiple messages for different languages through the contents field.

Method Summary

Methods included from Internal::Types::Union

coerce, discriminant, load, member, members, type_member?

Methods included from Internal::Types::Type

#coerce, #strict!, #strict?

Methods included from Internal::JSON::Serializable

#dump, #load

Methods inherited from Internal::Types::Model

#==, ===, add_extra_field_definition, coerce, extra_fields, field, fields, #initialize, #inspect, literal, load, #to_h

Constructor Details

This class inherits a constructor from Vapi::Internal::Types::Model