Class: Vapi::Types::TransferPlanContextEngineeringPlan

Inherits:
Internal::Types::Model show all
Extended by:
Internal::Types::Union
Defined in:
lib/vapi/types/transfer_plan_context_engineering_plan.rb

Overview

This is the plan for manipulating the message context before initiating the warm transfer. Usage:

  • Used only when mode is warm-transfer-experimental.
  • These messages will automatically be added to the transferAssistant's system message.
  • If 'none', we will not add any transcript to the transferAssistant's system message.
  • If you want to provide your own messages, use transferAssistant.model.messages instead.

Method Summary

Methods included from Internal::Types::Union

coerce, discriminant, load, member, members, type_member?

Methods included from Internal::Types::Type

#coerce, #strict!, #strict?

Methods included from Internal::JSON::Serializable

#dump, #load

Methods inherited from Internal::Types::Model

#==, ===, add_extra_field_definition, coerce, extra_fields, field, fields, #initialize, #inspect, literal, load, #to_h

Constructor Details

This class inherits a constructor from Vapi::Internal::Types::Model