Class: Vapi::UpdateComputerToolDto
- Inherits:
-
Object
- Object
- Vapi::UpdateComputerToolDto
- Defined in:
- lib/vapi_server_sdk/types/update_computer_tool_dto.rb
Constant Summary collapse
- OMIT =
Object.new
Instance Attribute Summary collapse
-
#additional_properties ⇒ OpenStruct
readonly
Additional properties unmapped to the current class definition.
-
#async ⇒ Boolean
readonly
This determines if the tool is async.
-
#display_height_px ⇒ Float
readonly
The display height in pixels.
-
#display_number ⇒ Float
readonly
Optional display number.
-
#display_width_px ⇒ Float
readonly
The display width in pixels.
-
#function ⇒ Vapi::OpenAiFunction
readonly
This is the function definition of the tool.
-
#messages ⇒ Array<Vapi::UpdateComputerToolDtoMessagesItem>
readonly
These are the messages that will be spoken to the user as the tool is running.
-
#name ⇒ String
readonly
The name of the tool, fixed to 'computer'.
-
#server ⇒ Vapi::Server
readonly
This is the server that will be hit when this tool is requested by the model.
-
#sub_type ⇒ String
readonly
The sub type of tool.
Class Method Summary collapse
-
.from_json(json_object:) ⇒ Vapi::UpdateComputerToolDto
Deserialize a JSON object to an instance of UpdateComputerToolDto.
-
.validate_raw(obj:) ⇒ Void
Leveraged for Union-type generation, validate_raw attempts to parse the given hash and check each fields type against the current object's property definitions.
Instance Method Summary collapse
- #initialize(async: OMIT, messages: OMIT, sub_type: OMIT, function: OMIT, server: OMIT, name: OMIT, display_width_px: OMIT, display_height_px: OMIT, display_number: OMIT, additional_properties: nil) ⇒ Vapi::UpdateComputerToolDto constructor
-
#to_json(*_args) ⇒ String
Serialize an instance of UpdateComputerToolDto to a JSON object.
Constructor Details
#initialize(async: OMIT, messages: OMIT, sub_type: OMIT, function: OMIT, server: OMIT, name: OMIT, display_width_px: OMIT, display_height_px: OMIT, display_number: OMIT, additional_properties: nil) ⇒ Vapi::UpdateComputerToolDto
90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 |
# File 'lib/vapi_server_sdk/types/update_computer_tool_dto.rb', line 90 def initialize(async: OMIT, messages: OMIT, sub_type: OMIT, function: OMIT, server: OMIT, name: OMIT, display_width_px: OMIT, display_height_px: OMIT, display_number: OMIT, additional_properties: nil) @async = async if async != OMIT @messages = if != OMIT @sub_type = sub_type if sub_type != OMIT @function = function if function != OMIT @server = server if server != OMIT @name = name if name != OMIT @display_width_px = display_width_px if display_width_px != OMIT @display_height_px = display_height_px if display_height_px != OMIT @display_number = display_number if display_number != OMIT @additional_properties = additional_properties @_field_set = { "async": async, "messages": , "subType": sub_type, "function": function, "server": server, "name": name, "displayWidthPx": display_width_px, "displayHeightPx": display_height_px, "displayNumber": display_number }.reject do |_k, v| v == OMIT end end |
Instance Attribute Details
#additional_properties ⇒ OpenStruct (readonly)
Returns Additional properties unmapped to the current class definition.
51 52 53 |
# File 'lib/vapi_server_sdk/types/update_computer_tool_dto.rb', line 51 def additional_properties @additional_properties end |
#async ⇒ Boolean (readonly)
Returns This determines if the tool is async.
If async, the assistant will move forward without waiting for your server to
respond. This is useful if you just want to trigger something on your server.
If sync, the assistant will wait for your server to respond. This is useful if
want assistant to respond with the result from your server.
Defaults to synchronous (false).
17 18 19 |
# File 'lib/vapi_server_sdk/types/update_computer_tool_dto.rb', line 17 def async @async end |
#display_height_px ⇒ Float (readonly)
Returns The display height in pixels.
47 48 49 |
# File 'lib/vapi_server_sdk/types/update_computer_tool_dto.rb', line 47 def display_height_px @display_height_px end |
#display_number ⇒ Float (readonly)
Returns Optional display number.
49 50 51 |
# File 'lib/vapi_server_sdk/types/update_computer_tool_dto.rb', line 49 def display_number @display_number end |
#display_width_px ⇒ Float (readonly)
Returns The display width in pixels.
45 46 47 |
# File 'lib/vapi_server_sdk/types/update_computer_tool_dto.rb', line 45 def display_width_px @display_width_px end |
#function ⇒ Vapi::OpenAiFunction (readonly)
Returns This is the function definition of the tool.
For endCall, transferCall, and dtmf tools, this is auto-filled based on
tool-specific fields like tool.destinations. But, even in those cases, you can
provide a custom function definition for advanced use cases.
An example of an advanced use case is if you want to customize the message
that's spoken for endCall tool. You can specify a function where it returns an
argument "reason". Then, in messages array, you can have many
"request-complete" messages. One of these messages will be triggered if the
messages[].conditions matches the "reason" argument.
34 35 36 |
# File 'lib/vapi_server_sdk/types/update_computer_tool_dto.rb', line 34 def function @function end |
#messages ⇒ Array<Vapi::UpdateComputerToolDtoMessagesItem> (readonly)
Returns These are the messages that will be spoken to the user as the tool is running.
For some tools, this is auto-filled based on special fields like
tool.destinations. For others like the function tool, these can be custom
configured.
22 23 24 |
# File 'lib/vapi_server_sdk/types/update_computer_tool_dto.rb', line 22 def @messages end |
#name ⇒ String (readonly)
Returns The name of the tool, fixed to 'computer'.
43 44 45 |
# File 'lib/vapi_server_sdk/types/update_computer_tool_dto.rb', line 43 def name @name end |
#server ⇒ Vapi::Server (readonly)
Returns This is the server that will be hit when this tool is requested by the model. All requests will be sent with the call object among other things. You can find more details in the Server URL documentation. This overrides the serverUrl set on the org and the phoneNumber. Order of precedence: highest tool.server.url, then assistant.serverUrl, then phoneNumber.serverUrl, then org.serverUrl.
41 42 43 |
# File 'lib/vapi_server_sdk/types/update_computer_tool_dto.rb', line 41 def server @server end |
#sub_type ⇒ String (readonly)
Returns The sub type of tool.
24 25 26 |
# File 'lib/vapi_server_sdk/types/update_computer_tool_dto.rb', line 24 def sub_type @sub_type end |
Class Method Details
.from_json(json_object:) ⇒ Vapi::UpdateComputerToolDto
Deserialize a JSON object to an instance of UpdateComputerToolDto
121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 |
# File 'lib/vapi_server_sdk/types/update_computer_tool_dto.rb', line 121 def self.from_json(json_object:) struct = JSON.parse(json_object, object_class: OpenStruct) parsed_json = JSON.parse(json_object) async = parsed_json["async"] = parsed_json["messages"]&.map do |item| item = item.to_json Vapi::UpdateComputerToolDtoMessagesItem.from_json(json_object: item) end sub_type = parsed_json["subType"] if parsed_json["function"].nil? function = nil else function = parsed_json["function"].to_json function = Vapi::OpenAiFunction.from_json(json_object: function) end if parsed_json["server"].nil? server = nil else server = parsed_json["server"].to_json server = Vapi::Server.from_json(json_object: server) end name = parsed_json["name"] display_width_px = parsed_json["displayWidthPx"] display_height_px = parsed_json["displayHeightPx"] display_number = parsed_json["displayNumber"] new( async: async, messages: , sub_type: sub_type, function: function, server: server, name: name, display_width_px: display_width_px, display_height_px: display_height_px, display_number: display_number, additional_properties: struct ) end |
.validate_raw(obj:) ⇒ Void
Leveraged for Union-type generation, validate_raw attempts to parse the given hash and check each fields type against the current object's property definitions.
173 174 175 176 177 178 179 180 181 182 183 |
# File 'lib/vapi_server_sdk/types/update_computer_tool_dto.rb', line 173 def self.validate_raw(obj:) obj.async&.is_a?(Boolean) != false || raise("Passed value for field obj.async is not the expected type, validation failed.") obj.&.is_a?(Array) != false || raise("Passed value for field obj.messages is not the expected type, validation failed.") obj.sub_type&.is_a?(String) != false || raise("Passed value for field obj.sub_type is not the expected type, validation failed.") obj.function.nil? || Vapi::OpenAiFunction.validate_raw(obj: obj.function) obj.server.nil? || Vapi::Server.validate_raw(obj: obj.server) obj.name&.is_a?(String) != false || raise("Passed value for field obj.name is not the expected type, validation failed.") obj.display_width_px&.is_a?(Float) != false || raise("Passed value for field obj.display_width_px is not the expected type, validation failed.") obj.display_height_px&.is_a?(Float) != false || raise("Passed value for field obj.display_height_px is not the expected type, validation failed.") obj.display_number&.is_a?(Float) != false || raise("Passed value for field obj.display_number is not the expected type, validation failed.") end |
Instance Method Details
#to_json(*_args) ⇒ String
Serialize an instance of UpdateComputerToolDto to a JSON object
163 164 165 |
# File 'lib/vapi_server_sdk/types/update_computer_tool_dto.rb', line 163 def to_json(*_args) @_field_set&.to_json end |