Class: Vapi::UpdateOrgDto

Inherits:
Object
  • Object
show all
Defined in:
lib/vapi_server_sdk/types/update_org_dto.rb

Constant Summary collapse

OMIT =
Object.new

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(hipaa_enabled: OMIT, subscription_id: OMIT, name: OMIT, channel: OMIT, billing_limit: OMIT, server: OMIT, concurrency_limit: OMIT, additional_properties: nil) ⇒ Vapi::UpdateOrgDto

Parameters:

  • hipaa_enabled (Boolean) (defaults to: OMIT)

    When this is enabled, no logs, recordings, or transcriptions will be stored. At the end of the call, you will still receive an end-of-call-report message to store on your server. Defaults to false. When HIPAA is enabled, only OpenAI/Custom LLM or Azure Providers will be available for LLM and Voice respectively. This is due to the compliance requirements of HIPAA. Other providers may not meet these requirements.

  • subscription_id (String) (defaults to: OMIT)

    This is the ID of the subscription the org belongs to.

  • name (String) (defaults to: OMIT)

    This is the name of the org. This is just for your own reference.

  • channel (Vapi::UpdateOrgDtoChannel) (defaults to: OMIT)

    This is the channel of the org. There is the cluster the API traffic for the org will be directed.

  • billing_limit (Float) (defaults to: OMIT)

    This is the monthly billing limit for the org. To go beyond $1000/mo, please contact us at [email protected].

  • server (Vapi::Server) (defaults to: OMIT)

    This is where Vapi will send webhooks. You can find all webhooks available along with their shape in ServerMessage schema. The order of precedence is:

    1. assistant.server

    2. phoneNumber.server

    3. org.server

  • concurrency_limit (Float) (defaults to: OMIT)

    This is the concurrency limit for the org. This is the maximum number of calls that can be active at any given time. To go beyond 10, please contact us at [email protected].

  • additional_properties (OpenStruct) (defaults to: nil)

    Additional properties unmapped to the current class definition



71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
# File 'lib/vapi_server_sdk/types/update_org_dto.rb', line 71

def initialize(hipaa_enabled: OMIT, subscription_id: OMIT, name: OMIT, channel: OMIT, billing_limit: OMIT,
               server: OMIT, concurrency_limit: OMIT, additional_properties: nil)
  @hipaa_enabled = hipaa_enabled if hipaa_enabled != OMIT
  @subscription_id = subscription_id if subscription_id != OMIT
  @name = name if name != OMIT
  @channel = channel if channel != OMIT
  @billing_limit = billing_limit if billing_limit != OMIT
  @server = server if server != OMIT
  @concurrency_limit = concurrency_limit if concurrency_limit != OMIT
  @additional_properties = additional_properties
  @_field_set = {
    "hipaaEnabled": hipaa_enabled,
    "subscriptionId": subscription_id,
    "name": name,
    "channel": channel,
    "billingLimit": billing_limit,
    "server": server,
    "concurrencyLimit": concurrency_limit
  }.reject do |_k, v|
    v == OMIT
  end
end

Instance Attribute Details

#additional_propertiesOpenStruct (readonly)

Returns Additional properties unmapped to the current class definition.

Returns:

  • (OpenStruct)

    Additional properties unmapped to the current class definition



40
41
42
# File 'lib/vapi_server_sdk/types/update_org_dto.rb', line 40

def additional_properties
  @additional_properties
end

#billing_limitFloat (readonly)

Returns This is the monthly billing limit for the org. To go beyond $1000/mo, please contact us at [email protected].

Returns:

  • (Float)

    This is the monthly billing limit for the org. To go beyond $1000/mo, please contact us at [email protected].



27
28
29
# File 'lib/vapi_server_sdk/types/update_org_dto.rb', line 27

def billing_limit
  @billing_limit
end

#channelVapi::UpdateOrgDtoChannel (readonly)

Returns This is the channel of the org. There is the cluster the API traffic for the org will be directed.

Returns:

  • (Vapi::UpdateOrgDtoChannel)

    This is the channel of the org. There is the cluster the API traffic for the org will be directed.



24
25
26
# File 'lib/vapi_server_sdk/types/update_org_dto.rb', line 24

def channel
  @channel
end

#concurrency_limitFloat (readonly)

Returns This is the concurrency limit for the org. This is the maximum number of calls that can be active at any given time. To go beyond 10, please contact us at [email protected].

Returns:

  • (Float)

    This is the concurrency limit for the org. This is the maximum number of calls that can be active at any given time. To go beyond 10, please contact us at [email protected].



38
39
40
# File 'lib/vapi_server_sdk/types/update_org_dto.rb', line 38

def concurrency_limit
  @concurrency_limit
end

#hipaa_enabledBoolean (readonly)

Returns When this is enabled, no logs, recordings, or transcriptions will be stored. At the end of the call, you will still receive an end-of-call-report message to store on your server. Defaults to false. When HIPAA is enabled, only OpenAI/Custom LLM or Azure Providers will be available for LLM and Voice respectively. This is due to the compliance requirements of HIPAA. Other providers may not meet these requirements.

Returns:

  • (Boolean)

    When this is enabled, no logs, recordings, or transcriptions will be stored. At the end of the call, you will still receive an end-of-call-report message to store on your server. Defaults to false. When HIPAA is enabled, only OpenAI/Custom LLM or Azure Providers will be available for LLM and Voice respectively. This is due to the compliance requirements of HIPAA. Other providers may not meet these requirements.



17
18
19
# File 'lib/vapi_server_sdk/types/update_org_dto.rb', line 17

def hipaa_enabled
  @hipaa_enabled
end

#nameString (readonly)

Returns This is the name of the org. This is just for your own reference.

Returns:

  • (String)

    This is the name of the org. This is just for your own reference.



21
22
23
# File 'lib/vapi_server_sdk/types/update_org_dto.rb', line 21

def name
  @name
end

#serverVapi::Server (readonly)

Returns This is where Vapi will send webhooks. You can find all webhooks available along with their shape in ServerMessage schema. The order of precedence is:

  1. assistant.server

  2. phoneNumber.server

  3. org.server.

Returns:

  • (Vapi::Server)

    This is where Vapi will send webhooks. You can find all webhooks available along with their shape in ServerMessage schema. The order of precedence is:

    1. assistant.server

    2. phoneNumber.server

    3. org.server



34
35
36
# File 'lib/vapi_server_sdk/types/update_org_dto.rb', line 34

def server
  @server
end

#subscription_idString (readonly)

Returns This is the ID of the subscription the org belongs to.

Returns:

  • (String)

    This is the ID of the subscription the org belongs to.



19
20
21
# File 'lib/vapi_server_sdk/types/update_org_dto.rb', line 19

def subscription_id
  @subscription_id
end

Class Method Details

.from_json(json_object:) ⇒ Vapi::UpdateOrgDto

Deserialize a JSON object to an instance of UpdateOrgDto

Parameters:

  • json_object (String)

Returns:



98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
# File 'lib/vapi_server_sdk/types/update_org_dto.rb', line 98

def self.from_json(json_object:)
  struct = JSON.parse(json_object, object_class: OpenStruct)
  parsed_json = JSON.parse(json_object)
  hipaa_enabled = parsed_json["hipaaEnabled"]
  subscription_id = parsed_json["subscriptionId"]
  name = parsed_json["name"]
  channel = parsed_json["channel"]
  billing_limit = parsed_json["billingLimit"]
  if parsed_json["server"].nil?
    server = nil
  else
    server = parsed_json["server"].to_json
    server = Vapi::Server.from_json(json_object: server)
  end
  concurrency_limit = parsed_json["concurrencyLimit"]
  new(
    hipaa_enabled: hipaa_enabled,
    subscription_id: subscription_id,
    name: name,
    channel: channel,
    billing_limit: billing_limit,
    server: server,
    concurrency_limit: concurrency_limit,
    additional_properties: struct
  )
end

.validate_raw(obj:) ⇒ Void

Leveraged for Union-type generation, validate_raw attempts to parse the given

hash and check each fields type against the current object's property
definitions.

Parameters:

  • obj (Object)

Returns:

  • (Void)


138
139
140
141
142
143
144
145
146
# File 'lib/vapi_server_sdk/types/update_org_dto.rb', line 138

def self.validate_raw(obj:)
  obj.hipaa_enabled&.is_a?(Boolean) != false || raise("Passed value for field obj.hipaa_enabled is not the expected type, validation failed.")
  obj.subscription_id&.is_a?(String) != false || raise("Passed value for field obj.subscription_id is not the expected type, validation failed.")
  obj.name&.is_a?(String) != false || raise("Passed value for field obj.name is not the expected type, validation failed.")
  obj.channel&.is_a?(Vapi::UpdateOrgDtoChannel) != false || raise("Passed value for field obj.channel is not the expected type, validation failed.")
  obj.billing_limit&.is_a?(Float) != false || raise("Passed value for field obj.billing_limit is not the expected type, validation failed.")
  obj.server.nil? || Vapi::Server.validate_raw(obj: obj.server)
  obj.concurrency_limit&.is_a?(Float) != false || raise("Passed value for field obj.concurrency_limit is not the expected type, validation failed.")
end

Instance Method Details

#to_json(*_args) ⇒ String

Serialize an instance of UpdateOrgDto to a JSON object

Returns:

  • (String)


128
129
130
# File 'lib/vapi_server_sdk/types/update_org_dto.rb', line 128

def to_json(*_args)
  @_field_set&.to_json
end