Class: Vapi::VapiModel
- Inherits:
-
Object
- Object
- Vapi::VapiModel
- Defined in:
- lib/vapi_server_sdk/types/vapi_model.rb
Constant Summary collapse
- OMIT =
Object.new
Instance Attribute Summary collapse
-
#additional_properties ⇒ OpenStruct
readonly
Additional properties unmapped to the current class definition.
-
#emotion_recognition_enabled ⇒ Boolean
readonly
This determines whether we detect user's emotion while they speak and send it as an additional info to model.
-
#knowledge_base ⇒ Vapi::CreateCustomKnowledgeBaseDto
readonly
These are the options for the knowledge base.
-
#knowledge_base_id ⇒ String
readonly
This is the ID of the knowledge base the model will use.
-
#max_tokens ⇒ Float
readonly
This is the max number of tokens that the assistant will be allowed to generate in each turn of the conversation.
-
#messages ⇒ Array<Vapi::OpenAiMessage>
readonly
This is the starting state for the conversation.
-
#model ⇒ String
readonly
This is the name of the model.
-
#num_fast_turns ⇒ Float
readonly
This sets how many turns at the start of the conversation to use a smaller, faster model from the same provider before switching to the primary model.
- #steps ⇒ Array<Vapi::VapiModelStepsItem> readonly
-
#temperature ⇒ Float
readonly
This is the temperature that will be used for calls.
-
#tool_ids ⇒ Array<String>
readonly
These are the tools that the assistant can use during the call.
-
#tools ⇒ Array<Vapi::VapiModelToolsItem>
readonly
These are the tools that the assistant can use during the call.
-
#workflow ⇒ Vapi::Workflow
readonly
This is the workflow that will be used for the call.
-
#workflow_id ⇒ String
readonly
This is the workflow that will be used for the call.
Class Method Summary collapse
-
.from_json(json_object:) ⇒ Vapi::VapiModel
Deserialize a JSON object to an instance of VapiModel.
-
.validate_raw(obj:) ⇒ Void
Leveraged for Union-type generation, validate_raw attempts to parse the given hash and check each fields type against the current object's property definitions.
Instance Method Summary collapse
- #initialize(model:, messages: OMIT, tools: OMIT, tool_ids: OMIT, knowledge_base: OMIT, knowledge_base_id: OMIT, steps: OMIT, workflow_id: OMIT, workflow: OMIT, temperature: OMIT, max_tokens: OMIT, emotion_recognition_enabled: OMIT, num_fast_turns: OMIT, additional_properties: nil) ⇒ Vapi::VapiModel constructor
-
#to_json(*_args) ⇒ String
Serialize an instance of VapiModel to a JSON object.
Constructor Details
#initialize(model:, messages: OMIT, tools: OMIT, tool_ids: OMIT, knowledge_base: OMIT, knowledge_base_id: OMIT, steps: OMIT, workflow_id: OMIT, workflow: OMIT, temperature: OMIT, max_tokens: OMIT, emotion_recognition_enabled: OMIT, num_fast_turns: OMIT, additional_properties: nil) ⇒ Vapi::VapiModel
94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 |
# File 'lib/vapi_server_sdk/types/vapi_model.rb', line 94 def initialize(model:, messages: OMIT, tools: OMIT, tool_ids: OMIT, knowledge_base: OMIT, knowledge_base_id: OMIT, steps: OMIT, workflow_id: OMIT, workflow: OMIT, temperature: OMIT, max_tokens: OMIT, emotion_recognition_enabled: OMIT, num_fast_turns: OMIT, additional_properties: nil) @messages = if != OMIT @tools = tools if tools != OMIT @tool_ids = tool_ids if tool_ids != OMIT @knowledge_base = knowledge_base if knowledge_base != OMIT @knowledge_base_id = knowledge_base_id if knowledge_base_id != OMIT @steps = steps if steps != OMIT @workflow_id = workflow_id if workflow_id != OMIT @workflow = workflow if workflow != OMIT @model = model @temperature = temperature if temperature != OMIT @max_tokens = max_tokens if max_tokens != OMIT @emotion_recognition_enabled = emotion_recognition_enabled if emotion_recognition_enabled != OMIT @num_fast_turns = num_fast_turns if num_fast_turns != OMIT @additional_properties = additional_properties @_field_set = { "messages": , "tools": tools, "toolIds": tool_ids, "knowledgeBase": knowledge_base, "knowledgeBaseId": knowledge_base_id, "steps": steps, "workflowId": workflow_id, "workflow": workflow, "model": model, "temperature": temperature, "maxTokens": max_tokens, "emotionRecognitionEnabled": emotion_recognition_enabled, "numFastTurns": num_fast_turns }.reject do |_k, v| v == OMIT end end |
Instance Attribute Details
#additional_properties ⇒ OpenStruct (readonly)
Returns Additional properties unmapped to the current class definition.
56 57 58 |
# File 'lib/vapi_server_sdk/types/vapi_model.rb', line 56 def additional_properties @additional_properties end |
#emotion_recognition_enabled ⇒ Boolean (readonly)
Returns This determines whether we detect user's emotion while they speak and send it as
an additional info to model.
Default false because the model is usually are good at understanding the
user's emotion from text.
@default false.
48 49 50 |
# File 'lib/vapi_server_sdk/types/vapi_model.rb', line 48 def emotion_recognition_enabled @emotion_recognition_enabled end |
#knowledge_base ⇒ Vapi::CreateCustomKnowledgeBaseDto (readonly)
Returns These are the options for the knowledge base.
24 25 26 |
# File 'lib/vapi_server_sdk/types/vapi_model.rb', line 24 def knowledge_base @knowledge_base end |
#knowledge_base_id ⇒ String (readonly)
Returns This is the ID of the knowledge base the model will use.
26 27 28 |
# File 'lib/vapi_server_sdk/types/vapi_model.rb', line 26 def knowledge_base_id @knowledge_base_id end |
#max_tokens ⇒ Float (readonly)
Returns This is the max number of tokens that the assistant will be allowed to generate in each turn of the conversation. Default is 250.
42 43 44 |
# File 'lib/vapi_server_sdk/types/vapi_model.rb', line 42 def max_tokens @max_tokens end |
#messages ⇒ Array<Vapi::OpenAiMessage> (readonly)
Returns This is the starting state for the conversation.
14 15 16 |
# File 'lib/vapi_server_sdk/types/vapi_model.rb', line 14 def @messages end |
#model ⇒ String (readonly)
Returns This is the name of the model. Ex. cognitivecomputations/dolphin-mixtral-8x7b.
36 37 38 |
# File 'lib/vapi_server_sdk/types/vapi_model.rb', line 36 def model @model end |
#num_fast_turns ⇒ Float (readonly)
Returns This sets how many turns at the start of the conversation to use a smaller, faster model from the same provider before switching to the primary model. Example, gpt-3.5-turbo if provider is openai. Default is 0. @default 0.
54 55 56 |
# File 'lib/vapi_server_sdk/types/vapi_model.rb', line 54 def num_fast_turns @num_fast_turns end |
#steps ⇒ Array<Vapi::VapiModelStepsItem> (readonly)
28 29 30 |
# File 'lib/vapi_server_sdk/types/vapi_model.rb', line 28 def steps @steps end |
#temperature ⇒ Float (readonly)
Returns This is the temperature that will be used for calls. Default is 0 to leverage caching for lower latency.
39 40 41 |
# File 'lib/vapi_server_sdk/types/vapi_model.rb', line 39 def temperature @temperature end |
#tool_ids ⇒ Array<String> (readonly)
Returns These are the tools that the assistant can use during the call. To use transient
tools, use tools.
Both tools and toolIds can be used together.
22 23 24 |
# File 'lib/vapi_server_sdk/types/vapi_model.rb', line 22 def tool_ids @tool_ids end |
#tools ⇒ Array<Vapi::VapiModelToolsItem> (readonly)
Returns These are the tools that the assistant can use during the call. To use existing
tools, use toolIds.
Both tools and toolIds can be used together.
18 19 20 |
# File 'lib/vapi_server_sdk/types/vapi_model.rb', line 18 def tools @tools end |
#workflow ⇒ Vapi::Workflow (readonly)
Returns This is the workflow that will be used for the call. To use an existing
workflow, use workflowId instead.
34 35 36 |
# File 'lib/vapi_server_sdk/types/vapi_model.rb', line 34 def workflow @workflow end |
#workflow_id ⇒ String (readonly)
Returns This is the workflow that will be used for the call. To use a transient
workflow, use workflow instead.
31 32 33 |
# File 'lib/vapi_server_sdk/types/vapi_model.rb', line 31 def workflow_id @workflow_id end |
Class Method Details
.from_json(json_object:) ⇒ Vapi::VapiModel
Deserialize a JSON object to an instance of VapiModel
133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 |
# File 'lib/vapi_server_sdk/types/vapi_model.rb', line 133 def self.from_json(json_object:) struct = JSON.parse(json_object, object_class: OpenStruct) parsed_json = JSON.parse(json_object) = parsed_json["messages"]&.map do |item| item = item.to_json Vapi::OpenAiMessage.from_json(json_object: item) end tools = parsed_json["tools"]&.map do |item| item = item.to_json Vapi::VapiModelToolsItem.from_json(json_object: item) end tool_ids = parsed_json["toolIds"] if parsed_json["knowledgeBase"].nil? knowledge_base = nil else knowledge_base = parsed_json["knowledgeBase"].to_json knowledge_base = Vapi::CreateCustomKnowledgeBaseDto.from_json(json_object: knowledge_base) end knowledge_base_id = parsed_json["knowledgeBaseId"] steps = parsed_json["steps"]&.map do |item| item = item.to_json Vapi::VapiModelStepsItem.from_json(json_object: item) end workflow_id = parsed_json["workflowId"] if parsed_json["workflow"].nil? workflow = nil else workflow = parsed_json["workflow"].to_json workflow = Vapi::Workflow.from_json(json_object: workflow) end model = parsed_json["model"] temperature = parsed_json["temperature"] max_tokens = parsed_json["maxTokens"] emotion_recognition_enabled = parsed_json["emotionRecognitionEnabled"] num_fast_turns = parsed_json["numFastTurns"] new( messages: , tools: tools, tool_ids: tool_ids, knowledge_base: knowledge_base, knowledge_base_id: knowledge_base_id, steps: steps, workflow_id: workflow_id, workflow: workflow, model: model, temperature: temperature, max_tokens: max_tokens, emotion_recognition_enabled: emotion_recognition_enabled, num_fast_turns: num_fast_turns, additional_properties: struct ) end |
.validate_raw(obj:) ⇒ Void
Leveraged for Union-type generation, validate_raw attempts to parse the given hash and check each fields type against the current object's property definitions.
199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 |
# File 'lib/vapi_server_sdk/types/vapi_model.rb', line 199 def self.validate_raw(obj:) obj.&.is_a?(Array) != false || raise("Passed value for field obj.messages is not the expected type, validation failed.") obj.tools&.is_a?(Array) != false || raise("Passed value for field obj.tools is not the expected type, validation failed.") obj.tool_ids&.is_a?(Array) != false || raise("Passed value for field obj.tool_ids is not the expected type, validation failed.") obj.knowledge_base.nil? || Vapi::CreateCustomKnowledgeBaseDto.validate_raw(obj: obj.knowledge_base) obj.knowledge_base_id&.is_a?(String) != false || raise("Passed value for field obj.knowledge_base_id is not the expected type, validation failed.") obj.steps&.is_a?(Array) != false || raise("Passed value for field obj.steps is not the expected type, validation failed.") obj.workflow_id&.is_a?(String) != false || raise("Passed value for field obj.workflow_id is not the expected type, validation failed.") obj.workflow.nil? || Vapi::Workflow.validate_raw(obj: obj.workflow) obj.model.is_a?(String) != false || raise("Passed value for field obj.model is not the expected type, validation failed.") obj.temperature&.is_a?(Float) != false || raise("Passed value for field obj.temperature is not the expected type, validation failed.") obj.max_tokens&.is_a?(Float) != false || raise("Passed value for field obj.max_tokens is not the expected type, validation failed.") obj.emotion_recognition_enabled&.is_a?(Boolean) != false || raise("Passed value for field obj.emotion_recognition_enabled is not the expected type, validation failed.") obj.num_fast_turns&.is_a?(Float) != false || raise("Passed value for field obj.num_fast_turns is not the expected type, validation failed.") end |
Instance Method Details
#to_json(*_args) ⇒ String
Serialize an instance of VapiModel to a JSON object
189 190 191 |
# File 'lib/vapi_server_sdk/types/vapi_model.rb', line 189 def to_json(*_args) @_field_set&.to_json end |