Class: Vapi::VapiPhoneNumber

Inherits:
Object
  • Object
show all
Defined in:
lib/vapi_server_sdk/types/vapi_phone_number.rb

Constant Summary collapse

OMIT =
Object.new

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(id:, org_id:, created_at:, updated_at:, sip_uri:, fallback_destination: OMIT, name: OMIT, assistant_id: OMIT, squad_id: OMIT, server: OMIT, authentication: OMIT, additional_properties: nil) ⇒ Vapi::VapiPhoneNumber

Parameters:

  • fallback_destination (Vapi::VapiPhoneNumberFallbackDestination) (defaults to: OMIT)

    This is the fallback destination an inbound call will be transferred to if:

    1. assistantId is not set

    2. squadId is not set

    3. and, assistant-request message to the serverUrl fails

    If this is not set and above conditions are met, the inbound call is hung up with an error message.

  • id (String)

    This is the unique identifier for the phone number.

  • org_id (String)

    This is the unique identifier for the org that this phone number belongs to.

  • created_at (DateTime)

    This is the ISO 8601 date-time string of when the phone number was created.

  • updated_at (DateTime)

    This is the ISO 8601 date-time string of when the phone number was last updated.

  • name (String) (defaults to: OMIT)

    This is the name of the phone number. This is just for your own reference.

  • assistant_id (String) (defaults to: OMIT)

    This is the assistant that will be used for incoming calls to this phone number. If neither assistantId nor squadId is set, assistant-request will be sent to your Server URL. Check ServerMessage and ServerMessageResponse for the shape of the message and response that is expected.

  • squad_id (String) (defaults to: OMIT)

    This is the squad that will be used for incoming calls to this phone number. If neither assistantId nor squadId is set, assistant-request will be sent to your Server URL. Check ServerMessage and ServerMessageResponse for the shape of the message and response that is expected.

  • server (Vapi::Server) (defaults to: OMIT)

    This is where Vapi will send webhooks. You can find all webhooks available along with their shape in ServerMessage schema. The order of precedence is:

    1. assistant.server

    2. phoneNumber.server

    3. org.server

  • sip_uri (String)

    This is the SIP URI of the phone number. You can SIP INVITE this. The assistant attached to this number will answer. This is case-insensitive.

  • authentication (Vapi::SipAuthentication) (defaults to: OMIT)

    This enables authentication for incoming SIP INVITE requests to the sipUri. If not set, any username/password to the 401 challenge of the SIP INVITE will be accepted.

  • additional_properties (OpenStruct) (defaults to: nil)

    Additional properties unmapped to the current class definition



95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
# File 'lib/vapi_server_sdk/types/vapi_phone_number.rb', line 95

def initialize(id:, org_id:, created_at:, updated_at:, sip_uri:, fallback_destination: OMIT, name: OMIT, assistant_id: OMIT,
               squad_id: OMIT, server: OMIT, authentication: OMIT, additional_properties: nil)
  @fallback_destination = fallback_destination if fallback_destination != OMIT
  @id = id
  @org_id = org_id
  @created_at = created_at
  @updated_at = updated_at
  @name = name if name != OMIT
  @assistant_id = assistant_id if assistant_id != OMIT
  @squad_id = squad_id if squad_id != OMIT
  @server = server if server != OMIT
  @sip_uri = sip_uri
  @authentication = authentication if authentication != OMIT
  @additional_properties = additional_properties
  @_field_set = {
    "fallbackDestination": fallback_destination,
    "id": id,
    "orgId": org_id,
    "createdAt": created_at,
    "updatedAt": updated_at,
    "name": name,
    "assistantId": assistant_id,
    "squadId": squad_id,
    "server": server,
    "sipUri": sip_uri,
    "authentication": authentication
  }.reject do |_k, v|
    v == OMIT
  end
end

Instance Attribute Details

#additional_propertiesOpenStruct (readonly)

Returns Additional properties unmapped to the current class definition.

Returns:

  • (OpenStruct)

    Additional properties unmapped to the current class definition



55
56
57
# File 'lib/vapi_server_sdk/types/vapi_phone_number.rb', line 55

def additional_properties
  @additional_properties
end

#assistant_idString (readonly)

Returns This is the assistant that will be used for incoming calls to this phone number. If neither assistantId nor squadId is set, assistant-request will be sent to your Server URL. Check ServerMessage and ServerMessageResponse for the shape of the message and response that is expected.

Returns:

  • (String)

    This is the assistant that will be used for incoming calls to this phone number. If neither assistantId nor squadId is set, assistant-request will be sent to your Server URL. Check ServerMessage and ServerMessageResponse for the shape of the message and response that is expected.



33
34
35
# File 'lib/vapi_server_sdk/types/vapi_phone_number.rb', line 33

def assistant_id
  @assistant_id
end

#authenticationVapi::SipAuthentication (readonly)

Returns This enables authentication for incoming SIP INVITE requests to the sipUri. If not set, any username/password to the 401 challenge of the SIP INVITE will be accepted.

Returns:

  • (Vapi::SipAuthentication)

    This enables authentication for incoming SIP INVITE requests to the sipUri. If not set, any username/password to the 401 challenge of the SIP INVITE will be accepted.



53
54
55
# File 'lib/vapi_server_sdk/types/vapi_phone_number.rb', line 53

def authentication
  @authentication
end

#created_atDateTime (readonly)

Returns This is the ISO 8601 date-time string of when the phone number was created.

Returns:

  • (DateTime)

    This is the ISO 8601 date-time string of when the phone number was created.



24
25
26
# File 'lib/vapi_server_sdk/types/vapi_phone_number.rb', line 24

def created_at
  @created_at
end

#fallback_destinationVapi::VapiPhoneNumberFallbackDestination (readonly)

Returns This is the fallback destination an inbound call will be transferred to if:

  1. assistantId is not set

  2. squadId is not set

  3. and, assistant-request message to the serverUrl fails

If this is not set and above conditions are met, the inbound call is hung up with an error message.

Returns:

  • (Vapi::VapiPhoneNumberFallbackDestination)

    This is the fallback destination an inbound call will be transferred to if:

    1. assistantId is not set

    2. squadId is not set

    3. and, assistant-request message to the serverUrl fails

    If this is not set and above conditions are met, the inbound call is hung up with an error message.



18
19
20
# File 'lib/vapi_server_sdk/types/vapi_phone_number.rb', line 18

def fallback_destination
  @fallback_destination
end

#idString (readonly)

Returns This is the unique identifier for the phone number.

Returns:

  • (String)

    This is the unique identifier for the phone number.



20
21
22
# File 'lib/vapi_server_sdk/types/vapi_phone_number.rb', line 20

def id
  @id
end

#nameString (readonly)

Returns This is the name of the phone number. This is just for your own reference.

Returns:

  • (String)

    This is the name of the phone number. This is just for your own reference.



28
29
30
# File 'lib/vapi_server_sdk/types/vapi_phone_number.rb', line 28

def name
  @name
end

#org_idString (readonly)

Returns This is the unique identifier for the org that this phone number belongs to.

Returns:

  • (String)

    This is the unique identifier for the org that this phone number belongs to.



22
23
24
# File 'lib/vapi_server_sdk/types/vapi_phone_number.rb', line 22

def org_id
  @org_id
end

#serverVapi::Server (readonly)

Returns This is where Vapi will send webhooks. You can find all webhooks available along with their shape in ServerMessage schema. The order of precedence is:

  1. assistant.server

  2. phoneNumber.server

  3. org.server.

Returns:

  • (Vapi::Server)

    This is where Vapi will send webhooks. You can find all webhooks available along with their shape in ServerMessage schema. The order of precedence is:

    1. assistant.server

    2. phoneNumber.server

    3. org.server



45
46
47
# File 'lib/vapi_server_sdk/types/vapi_phone_number.rb', line 45

def server
  @server
end

#sip_uriString (readonly)

Returns This is the SIP URI of the phone number. You can SIP INVITE this. The assistant attached to this number will answer. This is case-insensitive.

Returns:

  • (String)

    This is the SIP URI of the phone number. You can SIP INVITE this. The assistant attached to this number will answer. This is case-insensitive.



49
50
51
# File 'lib/vapi_server_sdk/types/vapi_phone_number.rb', line 49

def sip_uri
  @sip_uri
end

#squad_idString (readonly)

Returns This is the squad that will be used for incoming calls to this phone number. If neither assistantId nor squadId is set, assistant-request will be sent to your Server URL. Check ServerMessage and ServerMessageResponse for the shape of the message and response that is expected.

Returns:

  • (String)

    This is the squad that will be used for incoming calls to this phone number. If neither assistantId nor squadId is set, assistant-request will be sent to your Server URL. Check ServerMessage and ServerMessageResponse for the shape of the message and response that is expected.



38
39
40
# File 'lib/vapi_server_sdk/types/vapi_phone_number.rb', line 38

def squad_id
  @squad_id
end

#updated_atDateTime (readonly)

Returns This is the ISO 8601 date-time string of when the phone number was last updated.

Returns:

  • (DateTime)

    This is the ISO 8601 date-time string of when the phone number was last updated.



26
27
28
# File 'lib/vapi_server_sdk/types/vapi_phone_number.rb', line 26

def updated_at
  @updated_at
end

Class Method Details

.from_json(json_object:) ⇒ Vapi::VapiPhoneNumber

Deserialize a JSON object to an instance of VapiPhoneNumber

Parameters:

  • json_object (String)

Returns:



130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
# File 'lib/vapi_server_sdk/types/vapi_phone_number.rb', line 130

def self.from_json(json_object:)
  struct = JSON.parse(json_object, object_class: OpenStruct)
  parsed_json = JSON.parse(json_object)
  if parsed_json["fallbackDestination"].nil?
    fallback_destination = nil
  else
    fallback_destination = parsed_json["fallbackDestination"].to_json
    fallback_destination = Vapi::VapiPhoneNumberFallbackDestination.from_json(json_object: fallback_destination)
  end
  id = parsed_json["id"]
  org_id = parsed_json["orgId"]
  created_at = (DateTime.parse(parsed_json["createdAt"]) unless parsed_json["createdAt"].nil?)
  updated_at = (DateTime.parse(parsed_json["updatedAt"]) unless parsed_json["updatedAt"].nil?)
  name = parsed_json["name"]
  assistant_id = parsed_json["assistantId"]
  squad_id = parsed_json["squadId"]
  if parsed_json["server"].nil?
    server = nil
  else
    server = parsed_json["server"].to_json
    server = Vapi::Server.from_json(json_object: server)
  end
  sip_uri = parsed_json["sipUri"]
  if parsed_json["authentication"].nil?
    authentication = nil
  else
    authentication = parsed_json["authentication"].to_json
    authentication = Vapi::SipAuthentication.from_json(json_object: authentication)
  end
  new(
    fallback_destination: fallback_destination,
    id: id,
    org_id: org_id,
    created_at: created_at,
    updated_at: updated_at,
    name: name,
    assistant_id: assistant_id,
    squad_id: squad_id,
    server: server,
    sip_uri: sip_uri,
    authentication: authentication,
    additional_properties: struct
  )
end

.validate_raw(obj:) ⇒ Void

Leveraged for Union-type generation, validate_raw attempts to parse the given

hash and check each fields type against the current object's property
definitions.

Parameters:

  • obj (Object)

Returns:

  • (Void)


188
189
190
191
192
193
194
195
196
197
198
199
200
# File 'lib/vapi_server_sdk/types/vapi_phone_number.rb', line 188

def self.validate_raw(obj:)
  obj.fallback_destination.nil? || Vapi::VapiPhoneNumberFallbackDestination.validate_raw(obj: obj.fallback_destination)
  obj.id.is_a?(String) != false || raise("Passed value for field obj.id is not the expected type, validation failed.")
  obj.org_id.is_a?(String) != false || raise("Passed value for field obj.org_id is not the expected type, validation failed.")
  obj.created_at.is_a?(DateTime) != false || raise("Passed value for field obj.created_at is not the expected type, validation failed.")
  obj.updated_at.is_a?(DateTime) != false || raise("Passed value for field obj.updated_at is not the expected type, validation failed.")
  obj.name&.is_a?(String) != false || raise("Passed value for field obj.name is not the expected type, validation failed.")
  obj.assistant_id&.is_a?(String) != false || raise("Passed value for field obj.assistant_id is not the expected type, validation failed.")
  obj.squad_id&.is_a?(String) != false || raise("Passed value for field obj.squad_id is not the expected type, validation failed.")
  obj.server.nil? || Vapi::Server.validate_raw(obj: obj.server)
  obj.sip_uri.is_a?(String) != false || raise("Passed value for field obj.sip_uri is not the expected type, validation failed.")
  obj.authentication.nil? || Vapi::SipAuthentication.validate_raw(obj: obj.authentication)
end

Instance Method Details

#to_json(*_args) ⇒ String

Serialize an instance of VapiPhoneNumber to a JSON object

Returns:

  • (String)


178
179
180
# File 'lib/vapi_server_sdk/types/vapi_phone_number.rb', line 178

def to_json(*_args)
  @_field_set&.to_json
end