Class: Vapi::Assistant
- Inherits:
-
Object
- Object
- Vapi::Assistant
- Defined in:
- lib/vapi_server_sdk/types/assistant.rb
Constant Summary collapse
- OMIT =
Object.new
Instance Attribute Summary collapse
-
#additional_properties ⇒ OpenStruct
readonly
Additional properties unmapped to the current class definition.
-
#analysis_plan ⇒ Vapi::AnalysisPlan
readonly
This is the plan for analysis of assistant’s calls.
-
#artifact_plan ⇒ Vapi::ArtifactPlan
readonly
This is the plan for artifacts generated during assistant’s calls.
-
#background_denoising_enabled ⇒ Boolean
readonly
This enables filtering of noise and background speech while the user is talking.
-
#background_sound ⇒ Vapi::AssistantBackgroundSound
readonly
This is the background sound in the call.
-
#client_messages ⇒ Array<Vapi::AssistantClientMessagesItem>
readonly
These are the messages that will be sent to your Client SDKs.
-
#created_at ⇒ DateTime
readonly
This is the ISO 8601 date-time string of when the assistant was created.
-
#credential_ids ⇒ Array<String>
readonly
These are the credentials that will be used for the assistant calls.
-
#credentials ⇒ Array<Vapi::AssistantCredentialsItem>
readonly
These are dynamic credentials that will be used for the assistant calls.
-
#end_call_message ⇒ String
readonly
This is the message that the assistant will say if it ends the call.
-
#end_call_phrases ⇒ Array<String>
readonly
This list contains phrases that, if spoken by the assistant, will trigger the call to be hung up.
-
#first_message ⇒ String
readonly
This is the first message that the assistant will say.
-
#first_message_mode ⇒ Vapi::AssistantFirstMessageMode
readonly
This is the mode for the first message.
-
#hipaa_enabled ⇒ Boolean
readonly
When this is enabled, no logs, recordings, or transcriptions will be stored.
-
#id ⇒ String
readonly
This is the unique identifier for the assistant.
-
#max_duration_seconds ⇒ Float
readonly
This is the maximum number of seconds that the call will last.
-
#message_plan ⇒ Vapi::MessagePlan
readonly
This is the plan for static predefined messages that can be spoken by the assistant during the call, like
idleMessages. -
#metadata ⇒ Hash{String => Object}
readonly
This is for metadata you want to store on the assistant.
-
#model ⇒ Vapi::AssistantModel
readonly
These are the options for the assistant’s LLM.
-
#model_output_in_messages_enabled ⇒ Boolean
readonly
This determines whether the model’s output is used in conversation history rather than the transcription of assistant’s speech.
-
#monitor_plan ⇒ Vapi::MonitorPlan
readonly
This is the plan for real-time monitoring of the assistant’s calls.
-
#name ⇒ String
readonly
This is the name of the assistant.
-
#org_id ⇒ String
readonly
This is the unique identifier for the org that this assistant belongs to.
-
#server ⇒ Vapi::Server
readonly
This is where Vapi will send webhooks.
-
#server_messages ⇒ Array<Vapi::AssistantServerMessagesItem>
readonly
These are the messages that will be sent to your Server URL.
-
#silence_timeout_seconds ⇒ Float
readonly
How many seconds of silence to wait before ending the call.
-
#start_speaking_plan ⇒ Vapi::StartSpeakingPlan
readonly
This is the plan for when the assistant should start talking.
-
#stop_speaking_plan ⇒ Vapi::StopSpeakingPlan
readonly
This is the plan for when assistant should stop talking on customer interruption.
-
#transcriber ⇒ Vapi::AssistantTranscriber
readonly
These are the options for the assistant’s transcriber.
-
#transport_configurations ⇒ Array<Vapi::TransportConfigurationTwilio>
readonly
These are the configurations to be passed to the transport providers of assistant’s calls, like Twilio.
-
#updated_at ⇒ DateTime
readonly
This is the ISO 8601 date-time string of when the assistant was last updated.
-
#voice ⇒ Vapi::AssistantVoice
readonly
These are the options for the assistant’s voice.
-
#voicemail_detection ⇒ Vapi::TwilioVoicemailDetection
readonly
These are the settings to configure or disable voicemail detection.
-
#voicemail_message ⇒ String
readonly
This is the message that the assistant will say if the call is forwarded to voicemail.
Class Method Summary collapse
-
.from_json(json_object:) ⇒ Vapi::Assistant
Deserialize a JSON object to an instance of Assistant.
-
.validate_raw(obj:) ⇒ Void
Leveraged for Union-type generation, validate_raw attempts to parse the given hash and check each fields type against the current object’s property definitions.
Instance Method Summary collapse
- #initialize(id:, org_id:, created_at:, updated_at:, transcriber: OMIT, model: OMIT, voice: OMIT, first_message: OMIT, first_message_mode: OMIT, hipaa_enabled: OMIT, client_messages: OMIT, server_messages: OMIT, silence_timeout_seconds: OMIT, max_duration_seconds: OMIT, background_sound: OMIT, background_denoising_enabled: OMIT, model_output_in_messages_enabled: OMIT, transport_configurations: OMIT, credentials: OMIT, name: OMIT, voicemail_detection: OMIT, voicemail_message: OMIT, end_call_message: OMIT, end_call_phrases: OMIT, metadata: OMIT, analysis_plan: OMIT, artifact_plan: OMIT, message_plan: OMIT, start_speaking_plan: OMIT, stop_speaking_plan: OMIT, monitor_plan: OMIT, credential_ids: OMIT, server: OMIT, additional_properties: nil) ⇒ Vapi::Assistant constructor
-
#to_json(*_args) ⇒ String
Serialize an instance of Assistant to a JSON object.
Constructor Details
#initialize(id:, org_id:, created_at:, updated_at:, transcriber: OMIT, model: OMIT, voice: OMIT, first_message: OMIT, first_message_mode: OMIT, hipaa_enabled: OMIT, client_messages: OMIT, server_messages: OMIT, silence_timeout_seconds: OMIT, max_duration_seconds: OMIT, background_sound: OMIT, background_denoising_enabled: OMIT, model_output_in_messages_enabled: OMIT, transport_configurations: OMIT, credentials: OMIT, name: OMIT, voicemail_detection: OMIT, voicemail_message: OMIT, end_call_message: OMIT, end_call_phrases: OMIT, metadata: OMIT, analysis_plan: OMIT, artifact_plan: OMIT, message_plan: OMIT, start_speaking_plan: OMIT, stop_speaking_plan: OMIT, monitor_plan: OMIT, credential_ids: OMIT, server: OMIT, additional_properties: nil) ⇒ Vapi::Assistant
295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 |
# File 'lib/vapi_server_sdk/types/assistant.rb', line 295 def initialize(id:, org_id:, created_at:, updated_at:, transcriber: OMIT, model: OMIT, voice: OMIT, first_message: OMIT, first_message_mode: OMIT, hipaa_enabled: OMIT, client_messages: OMIT, server_messages: OMIT, silence_timeout_seconds: OMIT, max_duration_seconds: OMIT, background_sound: OMIT, background_denoising_enabled: OMIT, model_output_in_messages_enabled: OMIT, transport_configurations: OMIT, credentials: OMIT, name: OMIT, voicemail_detection: OMIT, voicemail_message: OMIT, end_call_message: OMIT, end_call_phrases: OMIT, metadata: OMIT, analysis_plan: OMIT, artifact_plan: OMIT, message_plan: OMIT, start_speaking_plan: OMIT, stop_speaking_plan: OMIT, monitor_plan: OMIT, credential_ids: OMIT, server: OMIT, additional_properties: nil) @transcriber = transcriber if transcriber != OMIT @model = model if model != OMIT @voice = voice if voice != OMIT = if != OMIT = if != OMIT @hipaa_enabled = hipaa_enabled if hipaa_enabled != OMIT = if != OMIT = if != OMIT @silence_timeout_seconds = silence_timeout_seconds if silence_timeout_seconds != OMIT @max_duration_seconds = max_duration_seconds if max_duration_seconds != OMIT @background_sound = background_sound if background_sound != OMIT @background_denoising_enabled = background_denoising_enabled if background_denoising_enabled != OMIT = if != OMIT @transport_configurations = transport_configurations if transport_configurations != OMIT @credentials = credentials if credentials != OMIT @name = name if name != OMIT @voicemail_detection = voicemail_detection if voicemail_detection != OMIT = if != OMIT = if != OMIT @end_call_phrases = end_call_phrases if end_call_phrases != OMIT = if != OMIT @analysis_plan = analysis_plan if analysis_plan != OMIT @artifact_plan = artifact_plan if artifact_plan != OMIT = if != OMIT @start_speaking_plan = start_speaking_plan if start_speaking_plan != OMIT @stop_speaking_plan = stop_speaking_plan if stop_speaking_plan != OMIT @monitor_plan = monitor_plan if monitor_plan != OMIT @credential_ids = credential_ids if credential_ids != OMIT @server = server if server != OMIT @id = id @org_id = org_id @created_at = created_at @updated_at = updated_at @additional_properties = additional_properties @_field_set = { "transcriber": transcriber, "model": model, "voice": voice, "firstMessage": , "firstMessageMode": , "hipaaEnabled": hipaa_enabled, "clientMessages": , "serverMessages": , "silenceTimeoutSeconds": silence_timeout_seconds, "maxDurationSeconds": max_duration_seconds, "backgroundSound": background_sound, "backgroundDenoisingEnabled": background_denoising_enabled, "modelOutputInMessagesEnabled": , "transportConfigurations": transport_configurations, "credentials": credentials, "name": name, "voicemailDetection": voicemail_detection, "voicemailMessage": , "endCallMessage": , "endCallPhrases": end_call_phrases, "metadata": , "analysisPlan": analysis_plan, "artifactPlan": artifact_plan, "messagePlan": , "startSpeakingPlan": start_speaking_plan, "stopSpeakingPlan": stop_speaking_plan, "monitorPlan": monitor_plan, "credentialIds": credential_ids, "server": server, "id": id, "orgId": org_id, "createdAt": created_at, "updatedAt": updated_at }.reject do |_k, v| v == OMIT end end |
Instance Attribute Details
#additional_properties ⇒ OpenStruct (readonly)
Returns Additional properties unmapped to the current class definition.
173 174 175 |
# File 'lib/vapi_server_sdk/types/assistant.rb', line 173 def additional_properties @additional_properties end |
#analysis_plan ⇒ Vapi::AnalysisPlan (readonly)
Returns This is the plan for analysis of assistant’s calls. Stored in call.analysis.
113 114 115 |
# File 'lib/vapi_server_sdk/types/assistant.rb', line 113 def analysis_plan @analysis_plan end |
#artifact_plan ⇒ Vapi::ArtifactPlan (readonly)
Returns This is the plan for artifacts generated during assistant’s calls. Stored in call.artifact. Note: recordingEnabled is currently at the root level. It will be moved to artifactPlan in the future, but will remain backwards compatible.
118 119 120 |
# File 'lib/vapi_server_sdk/types/assistant.rb', line 118 def artifact_plan @artifact_plan end |
#background_denoising_enabled ⇒ Boolean (readonly)
Returns This enables filtering of noise and background speech while the user is talking. Default false while in beta. @default false.
73 74 75 |
# File 'lib/vapi_server_sdk/types/assistant.rb', line 73 def background_denoising_enabled @background_denoising_enabled end |
#background_sound ⇒ Vapi::AssistantBackgroundSound (readonly)
Returns This is the background sound in the call. Default for phone calls is ‘office’ and default for web calls is ‘off’.
69 70 71 |
# File 'lib/vapi_server_sdk/types/assistant.rb', line 69 def background_sound @background_sound end |
#client_messages ⇒ Array<Vapi::AssistantClientMessagesItem> (readonly)
Returns These are the messages that will be sent to your Client SDKs. Default is tatus-update,transfer-update,transcript,tool-calls,user-interrupted,voice-input. You can check the shape of the messages in ClientMessage schema.
55 56 57 |
# File 'lib/vapi_server_sdk/types/assistant.rb', line 55 def end |
#created_at ⇒ DateTime (readonly)
Returns This is the ISO 8601 date-time string of when the assistant was created.
169 170 171 |
# File 'lib/vapi_server_sdk/types/assistant.rb', line 169 def created_at @created_at end |
#credential_ids ⇒ Array<String> (readonly)
Returns These are the credentials that will be used for the assistant calls. By default, all the credentials are available for use in the call but you can provide a subset using this.
156 157 158 |
# File 'lib/vapi_server_sdk/types/assistant.rb', line 156 def credential_ids @credential_ids end |
#credentials ⇒ Array<Vapi::AssistantCredentialsItem> (readonly)
Returns These are dynamic credentials that will be used for the assistant calls. By default, all the credentials are available for use in the call but you can supplement an additional credentials using this. Dynamic credentials override existing credentials.
88 89 90 |
# File 'lib/vapi_server_sdk/types/assistant.rb', line 88 def credentials @credentials end |
#end_call_message ⇒ String (readonly)
Returns This is the message that the assistant will say if it ends the call. If unspecified, it will hang up without saying anything.
106 107 108 |
# File 'lib/vapi_server_sdk/types/assistant.rb', line 106 def end |
#end_call_phrases ⇒ Array<String> (readonly)
Returns This list contains phrases that, if spoken by the assistant, will trigger the call to be hung up. Case insensitive.
109 110 111 |
# File 'lib/vapi_server_sdk/types/assistant.rb', line 109 def end_call_phrases @end_call_phrases end |
#first_message ⇒ String (readonly)
Returns This is the first message that the assistant will say. This can also be a URL to a containerized audio file (mp3, wav, etc.). If unspecified, assistant will wait for user to speak and use the model to respond once they speak.
36 37 38 |
# File 'lib/vapi_server_sdk/types/assistant.rb', line 36 def end |
#first_message_mode ⇒ Vapi::AssistantFirstMessageMode (readonly)
Returns This is the mode for the first message. Default is ‘assistant-speaks-first’. Use:
-
‘assistant-speaks-first’ to have the assistant speak first.
-
‘assistant-waits-for-user’ to have the assistant wait for the user to speak
first.
-
‘assistant-speaks-first-with-model-generated-message’ to have the assistant
speak first with a message generated by the model based on the conversation state. (assistant.model.messages at call start, call.messages at squad transfer points). @default ‘assistant-speaks-first’.
47 48 49 |
# File 'lib/vapi_server_sdk/types/assistant.rb', line 47 def end |
#hipaa_enabled ⇒ Boolean (readonly)
Returns When this is enabled, no logs, recordings, or transcriptions will be stored. At the end of the call, you will still receive an end-of-call-report message to store on your server. Defaults to false.
51 52 53 |
# File 'lib/vapi_server_sdk/types/assistant.rb', line 51 def hipaa_enabled @hipaa_enabled end |
#id ⇒ String (readonly)
Returns This is the unique identifier for the assistant.
165 166 167 |
# File 'lib/vapi_server_sdk/types/assistant.rb', line 165 def id @id end |
#max_duration_seconds ⇒ Float (readonly)
Returns This is the maximum number of seconds that the call will last. When the call reaches this duration, it will be ended. @default 600 (10 minutes).
66 67 68 |
# File 'lib/vapi_server_sdk/types/assistant.rb', line 66 def max_duration_seconds @max_duration_seconds end |
#message_plan ⇒ Vapi::MessagePlan (readonly)
Returns This is the plan for static predefined messages that can be spoken by the assistant during the call, like idleMessages. Note: firstMessage, voicemailMessage, and endCallMessage are currently at the root level. They will be moved to messagePlan in the future, but will remain backwards compatible.
124 125 126 |
# File 'lib/vapi_server_sdk/types/assistant.rb', line 124 def end |
#metadata ⇒ Hash{String => Object} (readonly)
Returns This is for metadata you want to store on the assistant.
111 112 113 |
# File 'lib/vapi_server_sdk/types/assistant.rb', line 111 def end |
#model ⇒ Vapi::AssistantModel (readonly)
Returns These are the options for the assistant’s LLM.
29 30 31 |
# File 'lib/vapi_server_sdk/types/assistant.rb', line 29 def model @model end |
#model_output_in_messages_enabled ⇒ Boolean (readonly)
Returns This determines whether the model’s output is used in conversation history rather than the transcription of assistant’s speech. Default false while in beta. @default false.
78 79 80 |
# File 'lib/vapi_server_sdk/types/assistant.rb', line 78 def end |
#monitor_plan ⇒ Vapi::MonitorPlan (readonly)
Returns This is the plan for real-time monitoring of the assistant’s calls. Usage:
-
To enable live listening of the assistant’s calls, set
monitorPlan.listenEnabled to true.
-
To enable live control of the assistant’s calls, set
monitorPlan.controlEnabled to true. Note, serverMessages, clientMessages, serverUrl and serverUrlSecret are currently at the root level but will be moved to monitorPlan in the future. Will remain backwards compatible.
152 153 154 |
# File 'lib/vapi_server_sdk/types/assistant.rb', line 152 def monitor_plan @monitor_plan end |
#name ⇒ String (readonly)
Returns This is the name of the assistant. This is required when you want to transfer between assistants in a call.
91 92 93 |
# File 'lib/vapi_server_sdk/types/assistant.rb', line 91 def name @name end |
#org_id ⇒ String (readonly)
Returns This is the unique identifier for the org that this assistant belongs to.
167 168 169 |
# File 'lib/vapi_server_sdk/types/assistant.rb', line 167 def org_id @org_id end |
#server ⇒ Vapi::Server (readonly)
Returns This is where Vapi will send webhooks. You can find all webhooks available along with their shape in ServerMessage schema. The order of precedence is:
-
assistant.server.url
-
phoneNumber.serverUrl
-
org.serverUrl.
163 164 165 |
# File 'lib/vapi_server_sdk/types/assistant.rb', line 163 def server @server end |
#server_messages ⇒ Array<Vapi::AssistantServerMessagesItem> (readonly)
Returns These are the messages that will be sent to your Server URL. Default is h-update,status-update,tool-calls,transfer-destination-request,user-interrupted. You can check the shape of the messages in ServerMessage schema.
59 60 61 |
# File 'lib/vapi_server_sdk/types/assistant.rb', line 59 def end |
#silence_timeout_seconds ⇒ Float (readonly)
Returns How many seconds of silence to wait before ending the call. Defaults to 30. @default 30.
62 63 64 |
# File 'lib/vapi_server_sdk/types/assistant.rb', line 62 def silence_timeout_seconds @silence_timeout_seconds end |
#start_speaking_plan ⇒ Vapi::StartSpeakingPlan (readonly)
Returns This is the plan for when the assistant should start talking. You should configure this if you’re running into these issues:
-
The assistant is too slow to start talking after the customer is done
speaking.
-
The assistant is too fast to start talking after the customer is done
speaking.
-
The assistant is so fast that it’s actually interrupting the customer.
132 133 134 |
# File 'lib/vapi_server_sdk/types/assistant.rb', line 132 def start_speaking_plan @start_speaking_plan end |
#stop_speaking_plan ⇒ Vapi::StopSpeakingPlan (readonly)
Returns This is the plan for when assistant should stop talking on customer interruption. You should configure this if you’re running into these issues:
-
The assistant is too slow to recognize customer’s interruption.
-
The assistant is too fast to recognize customer’s interruption.
-
The assistant is getting interrupted by phrases that are just acknowledgments.
-
The assistant is getting interrupted by background noises.
-
The assistant is not properly stopping – it starts talking right after
getting interrupted.
142 143 144 |
# File 'lib/vapi_server_sdk/types/assistant.rb', line 142 def stop_speaking_plan @stop_speaking_plan end |
#transcriber ⇒ Vapi::AssistantTranscriber (readonly)
Returns These are the options for the assistant’s transcriber.
27 28 29 |
# File 'lib/vapi_server_sdk/types/assistant.rb', line 27 def transcriber @transcriber end |
#transport_configurations ⇒ Array<Vapi::TransportConfigurationTwilio> (readonly)
Returns These are the configurations to be passed to the transport providers of assistant’s calls, like Twilio. You can store multiple configurations for different transport providers. For a call, only the configuration matching the call transport provider is used.
83 84 85 |
# File 'lib/vapi_server_sdk/types/assistant.rb', line 83 def transport_configurations @transport_configurations end |
#updated_at ⇒ DateTime (readonly)
Returns This is the ISO 8601 date-time string of when the assistant was last updated.
171 172 173 |
# File 'lib/vapi_server_sdk/types/assistant.rb', line 171 def updated_at @updated_at end |
#voice ⇒ Vapi::AssistantVoice (readonly)
Returns These are the options for the assistant’s voice.
31 32 33 |
# File 'lib/vapi_server_sdk/types/assistant.rb', line 31 def voice @voice end |
#voicemail_detection ⇒ Vapi::TwilioVoicemailDetection (readonly)
Returns These are the settings to configure or disable voicemail detection. Alternatively, voicemail detection can be configured using the model.tools=[VoicemailTool]. This uses Twilio’s built-in detection while the VoicemailTool relies on the model to detect if a voicemail was reached. You can use neither of them, one of them, or both of them. By default, Twilio built-in detection is enabled while VoicemailTool is not.
99 100 101 |
# File 'lib/vapi_server_sdk/types/assistant.rb', line 99 def voicemail_detection @voicemail_detection end |
#voicemail_message ⇒ String (readonly)
Returns This is the message that the assistant will say if the call is forwarded to voicemail. If unspecified, it will hang up.
103 104 105 |
# File 'lib/vapi_server_sdk/types/assistant.rb', line 103 def end |
Class Method Details
.from_json(json_object:) ⇒ Vapi::Assistant
Deserialize a JSON object to an instance of Assistant
374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 |
# File 'lib/vapi_server_sdk/types/assistant.rb', line 374 def self.from_json(json_object:) struct = JSON.parse(json_object, object_class: OpenStruct) parsed_json = JSON.parse(json_object) if parsed_json["transcriber"].nil? transcriber = nil else transcriber = parsed_json["transcriber"].to_json transcriber = Vapi::AssistantTranscriber.from_json(json_object: transcriber) end if parsed_json["model"].nil? model = nil else model = parsed_json["model"].to_json model = Vapi::AssistantModel.from_json(json_object: model) end if parsed_json["voice"].nil? voice = nil else voice = parsed_json["voice"].to_json voice = Vapi::AssistantVoice.from_json(json_object: voice) end = parsed_json["firstMessage"] = parsed_json["firstMessageMode"] hipaa_enabled = parsed_json["hipaaEnabled"] = parsed_json["clientMessages"] = parsed_json["serverMessages"] silence_timeout_seconds = parsed_json["silenceTimeoutSeconds"] max_duration_seconds = parsed_json["maxDurationSeconds"] background_sound = parsed_json["backgroundSound"] background_denoising_enabled = parsed_json["backgroundDenoisingEnabled"] = parsed_json["modelOutputInMessagesEnabled"] transport_configurations = parsed_json["transportConfigurations"]&.map do |item| item = item.to_json Vapi::TransportConfigurationTwilio.from_json(json_object: item) end credentials = parsed_json["credentials"]&.map do |item| item = item.to_json Vapi::AssistantCredentialsItem.from_json(json_object: item) end name = parsed_json["name"] if parsed_json["voicemailDetection"].nil? voicemail_detection = nil else voicemail_detection = parsed_json["voicemailDetection"].to_json voicemail_detection = Vapi::TwilioVoicemailDetection.from_json(json_object: voicemail_detection) end = parsed_json["voicemailMessage"] = parsed_json["endCallMessage"] end_call_phrases = parsed_json["endCallPhrases"] = parsed_json["metadata"] if parsed_json["analysisPlan"].nil? analysis_plan = nil else analysis_plan = parsed_json["analysisPlan"].to_json analysis_plan = Vapi::AnalysisPlan.from_json(json_object: analysis_plan) end if parsed_json["artifactPlan"].nil? artifact_plan = nil else artifact_plan = parsed_json["artifactPlan"].to_json artifact_plan = Vapi::ArtifactPlan.from_json(json_object: artifact_plan) end if parsed_json["messagePlan"].nil? = nil else = parsed_json["messagePlan"].to_json = Vapi::MessagePlan.from_json(json_object: ) end if parsed_json["startSpeakingPlan"].nil? start_speaking_plan = nil else start_speaking_plan = parsed_json["startSpeakingPlan"].to_json start_speaking_plan = Vapi::StartSpeakingPlan.from_json(json_object: start_speaking_plan) end if parsed_json["stopSpeakingPlan"].nil? stop_speaking_plan = nil else stop_speaking_plan = parsed_json["stopSpeakingPlan"].to_json stop_speaking_plan = Vapi::StopSpeakingPlan.from_json(json_object: stop_speaking_plan) end if parsed_json["monitorPlan"].nil? monitor_plan = nil else monitor_plan = parsed_json["monitorPlan"].to_json monitor_plan = Vapi::MonitorPlan.from_json(json_object: monitor_plan) end credential_ids = parsed_json["credentialIds"] if parsed_json["server"].nil? server = nil else server = parsed_json["server"].to_json server = Vapi::Server.from_json(json_object: server) end id = parsed_json["id"] org_id = parsed_json["orgId"] created_at = (DateTime.parse(parsed_json["createdAt"]) unless parsed_json["createdAt"].nil?) updated_at = (DateTime.parse(parsed_json["updatedAt"]) unless parsed_json["updatedAt"].nil?) new( transcriber: transcriber, model: model, voice: voice, first_message: , first_message_mode: , hipaa_enabled: hipaa_enabled, client_messages: , server_messages: , silence_timeout_seconds: silence_timeout_seconds, max_duration_seconds: max_duration_seconds, background_sound: background_sound, background_denoising_enabled: background_denoising_enabled, model_output_in_messages_enabled: , transport_configurations: transport_configurations, credentials: credentials, name: name, voicemail_detection: voicemail_detection, voicemail_message: , end_call_message: , end_call_phrases: end_call_phrases, metadata: , analysis_plan: analysis_plan, artifact_plan: artifact_plan, message_plan: , start_speaking_plan: start_speaking_plan, stop_speaking_plan: stop_speaking_plan, monitor_plan: monitor_plan, credential_ids: credential_ids, server: server, id: id, org_id: org_id, created_at: created_at, updated_at: updated_at, additional_properties: struct ) end |
.validate_raw(obj:) ⇒ Void
Leveraged for Union-type generation, validate_raw attempts to parse the given
hash and check each fields type against the current object's property
definitions.
522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 |
# File 'lib/vapi_server_sdk/types/assistant.rb', line 522 def self.validate_raw(obj:) obj.transcriber.nil? || Vapi::AssistantTranscriber.validate_raw(obj: obj.transcriber) obj.model.nil? || Vapi::AssistantModel.validate_raw(obj: obj.model) obj.voice.nil? || Vapi::AssistantVoice.validate_raw(obj: obj.voice) obj.&.is_a?(String) != false || raise("Passed value for field obj.first_message is not the expected type, validation failed.") obj.&.is_a?(Vapi::AssistantFirstMessageMode) != false || raise("Passed value for field obj.first_message_mode is not the expected type, validation failed.") obj.hipaa_enabled&.is_a?(Boolean) != false || raise("Passed value for field obj.hipaa_enabled is not the expected type, validation failed.") obj.&.is_a?(Array) != false || raise("Passed value for field obj.client_messages is not the expected type, validation failed.") obj.&.is_a?(Array) != false || raise("Passed value for field obj.server_messages is not the expected type, validation failed.") obj.silence_timeout_seconds&.is_a?(Float) != false || raise("Passed value for field obj.silence_timeout_seconds is not the expected type, validation failed.") obj.max_duration_seconds&.is_a?(Float) != false || raise("Passed value for field obj.max_duration_seconds is not the expected type, validation failed.") obj.background_sound&.is_a?(Vapi::AssistantBackgroundSound) != false || raise("Passed value for field obj.background_sound is not the expected type, validation failed.") obj.background_denoising_enabled&.is_a?(Boolean) != false || raise("Passed value for field obj.background_denoising_enabled is not the expected type, validation failed.") obj.&.is_a?(Boolean) != false || raise("Passed value for field obj.model_output_in_messages_enabled is not the expected type, validation failed.") obj.transport_configurations&.is_a?(Array) != false || raise("Passed value for field obj.transport_configurations is not the expected type, validation failed.") obj.credentials&.is_a?(Array) != false || raise("Passed value for field obj.credentials is not the expected type, validation failed.") obj.name&.is_a?(String) != false || raise("Passed value for field obj.name is not the expected type, validation failed.") obj.voicemail_detection.nil? || Vapi::TwilioVoicemailDetection.validate_raw(obj: obj.voicemail_detection) obj.&.is_a?(String) != false || raise("Passed value for field obj.voicemail_message is not the expected type, validation failed.") obj.&.is_a?(String) != false || raise("Passed value for field obj.end_call_message is not the expected type, validation failed.") obj.end_call_phrases&.is_a?(Array) != false || raise("Passed value for field obj.end_call_phrases is not the expected type, validation failed.") obj.&.is_a?(Hash) != false || raise("Passed value for field obj.metadata is not the expected type, validation failed.") obj.analysis_plan.nil? || Vapi::AnalysisPlan.validate_raw(obj: obj.analysis_plan) obj.artifact_plan.nil? || Vapi::ArtifactPlan.validate_raw(obj: obj.artifact_plan) obj..nil? || Vapi::MessagePlan.validate_raw(obj: obj.) obj.start_speaking_plan.nil? || Vapi::StartSpeakingPlan.validate_raw(obj: obj.start_speaking_plan) obj.stop_speaking_plan.nil? || Vapi::StopSpeakingPlan.validate_raw(obj: obj.stop_speaking_plan) obj.monitor_plan.nil? || Vapi::MonitorPlan.validate_raw(obj: obj.monitor_plan) obj.credential_ids&.is_a?(Array) != false || raise("Passed value for field obj.credential_ids is not the expected type, validation failed.") obj.server.nil? || Vapi::Server.validate_raw(obj: obj.server) obj.id.is_a?(String) != false || raise("Passed value for field obj.id is not the expected type, validation failed.") obj.org_id.is_a?(String) != false || raise("Passed value for field obj.org_id is not the expected type, validation failed.") obj.created_at.is_a?(DateTime) != false || raise("Passed value for field obj.created_at is not the expected type, validation failed.") obj.updated_at.is_a?(DateTime) != false || raise("Passed value for field obj.updated_at is not the expected type, validation failed.") end |
Instance Method Details
#to_json(*_args) ⇒ String
Serialize an instance of Assistant to a JSON object
512 513 514 |
# File 'lib/vapi_server_sdk/types/assistant.rb', line 512 def to_json(*_args) @_field_set&.to_json end |