Class: Vapi::CreateByoPhoneNumberDto
- Inherits:
-
Object
- Object
- Vapi::CreateByoPhoneNumberDto
- Defined in:
- lib/vapi_server_sdk/types/create_byo_phone_number_dto.rb
Constant Summary collapse
- OMIT =
Object.new
Instance Attribute Summary collapse
-
#additional_properties ⇒ OpenStruct
readonly
Additional properties unmapped to the current class definition.
-
#assistant_id ⇒ String
readonly
This is the assistant that will be used for incoming calls to this phone number.
-
#credential_id ⇒ String
readonly
This is the credential of your own SIP trunk or Carrier (type
byo-sip-trunk) which can be used to make calls to this phone number. -
#fallback_destination ⇒ Vapi::CreateByoPhoneNumberDtoFallbackDestination
readonly
This is the fallback destination an inbound call will be transferred to if: 1.
-
#name ⇒ String
readonly
This is the name of the phone number.
-
#number ⇒ String
readonly
This is the number of the customer.
-
#number_e_164_check_enabled ⇒ Boolean
readonly
This is the flag to toggle the E164 check for the
numberfield. -
#server ⇒ Vapi::Server
readonly
This is where Vapi will send webhooks.
-
#squad_id ⇒ String
readonly
This is the squad that will be used for incoming calls to this phone number.
Class Method Summary collapse
-
.from_json(json_object:) ⇒ Vapi::CreateByoPhoneNumberDto
Deserialize a JSON object to an instance of CreateByoPhoneNumberDto.
-
.validate_raw(obj:) ⇒ Void
Leveraged for Union-type generation, validate_raw attempts to parse the given hash and check each fields type against the current object's property definitions.
Instance Method Summary collapse
- #initialize(credential_id:, fallback_destination: OMIT, number_e_164_check_enabled: OMIT, number: OMIT, name: OMIT, assistant_id: OMIT, squad_id: OMIT, server: OMIT, additional_properties: nil) ⇒ Vapi::CreateByoPhoneNumberDto constructor
-
#to_json(*_args) ⇒ String
Serialize an instance of CreateByoPhoneNumberDto to a JSON object.
Constructor Details
#initialize(credential_id:, fallback_destination: OMIT, number_e_164_check_enabled: OMIT, number: OMIT, name: OMIT, assistant_id: OMIT, squad_id: OMIT, server: OMIT, additional_properties: nil) ⇒ Vapi::CreateByoPhoneNumberDto
100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 |
# File 'lib/vapi_server_sdk/types/create_byo_phone_number_dto.rb', line 100 def initialize(credential_id:, fallback_destination: OMIT, number_e_164_check_enabled: OMIT, number: OMIT, name: OMIT, assistant_id: OMIT, squad_id: OMIT, server: OMIT, additional_properties: nil) @fallback_destination = fallback_destination if fallback_destination != OMIT @number_e_164_check_enabled = number_e_164_check_enabled if number_e_164_check_enabled != OMIT @number = number if number != OMIT @credential_id = credential_id @name = name if name != OMIT @assistant_id = assistant_id if assistant_id != OMIT @squad_id = squad_id if squad_id != OMIT @server = server if server != OMIT @additional_properties = additional_properties @_field_set = { "fallbackDestination": fallback_destination, "numberE164CheckEnabled": number_e_164_check_enabled, "number": number, "credentialId": credential_id, "name": name, "assistantId": assistant_id, "squadId": squad_id, "server": server }.reject do |_k, v| v == OMIT end end |
Instance Attribute Details
#additional_properties ⇒ OpenStruct (readonly)
Returns Additional properties unmapped to the current class definition.
55 56 57 |
# File 'lib/vapi_server_sdk/types/create_byo_phone_number_dto.rb', line 55 def additional_properties @additional_properties end |
#assistant_id ⇒ String (readonly)
Returns This is the assistant that will be used for incoming calls to this phone number.
If neither assistantId nor squadId is set, assistant-request will be sent
to your Server URL. Check ServerMessage and ServerMessageResponse for the
shape of the message and response that is expected.
41 42 43 |
# File 'lib/vapi_server_sdk/types/create_byo_phone_number_dto.rb', line 41 def assistant_id @assistant_id end |
#credential_id ⇒ String (readonly)
Returns This is the credential of your own SIP trunk or Carrier (type byo-sip-trunk)
which can be used to make calls to this phone number.
You can add the SIP trunk or Carrier credential in the Provider Credentials page
on the Dashboard to get the credentialId.
34 35 36 |
# File 'lib/vapi_server_sdk/types/create_byo_phone_number_dto.rb', line 34 def credential_id @credential_id end |
#fallback_destination ⇒ Vapi::CreateByoPhoneNumberDtoFallbackDestination (readonly)
Returns This is the fallback destination an inbound call will be transferred to if:
assistantIdis not setsquadIdis not set- and,
assistant-requestmessage to theserverUrlfails If this is not set and above conditions are met, the inbound call is hung up with an error message.
16 17 18 |
# File 'lib/vapi_server_sdk/types/create_byo_phone_number_dto.rb', line 16 def fallback_destination @fallback_destination end |
#name ⇒ String (readonly)
Returns This is the name of the phone number. This is just for your own reference.
36 37 38 |
# File 'lib/vapi_server_sdk/types/create_byo_phone_number_dto.rb', line 36 def name @name end |
#number ⇒ String (readonly)
Returns This is the number of the customer.
29 30 31 |
# File 'lib/vapi_server_sdk/types/create_byo_phone_number_dto.rb', line 29 def number @number end |
#number_e_164_check_enabled ⇒ Boolean (readonly)
Returns This is the flag to toggle the E164 check for the number field. This is an
advanced property which should be used if you know your use case requires it.
Use cases:
false: To allow non-E164 numbers like+001234567890,1234, orabc. This is useful for dialing out to non-E164 numbers on your SIP trunks.true(default): To allow only E164 numbers like+14155551234. This is standard for PSTN calls. Iffalse, thenumberis still required to only contain alphanumeric characters (regex:/^\+?[a-zA-Z0-9]+$/). @default true (E164 check is enabled).
27 28 29 |
# File 'lib/vapi_server_sdk/types/create_byo_phone_number_dto.rb', line 27 def number_e_164_check_enabled @number_e_164_check_enabled end |
#server ⇒ Vapi::Server (readonly)
Returns This is where Vapi will send webhooks. You can find all webhooks available along with their shape in ServerMessage schema. The order of precedence is:
- assistant.server
- phoneNumber.server
- org.server.
53 54 55 |
# File 'lib/vapi_server_sdk/types/create_byo_phone_number_dto.rb', line 53 def server @server end |
#squad_id ⇒ String (readonly)
Returns This is the squad that will be used for incoming calls to this phone number.
If neither assistantId nor squadId is set, assistant-request will be sent
to your Server URL. Check ServerMessage and ServerMessageResponse for the
shape of the message and response that is expected.
46 47 48 |
# File 'lib/vapi_server_sdk/types/create_byo_phone_number_dto.rb', line 46 def squad_id @squad_id end |
Class Method Details
.from_json(json_object:) ⇒ Vapi::CreateByoPhoneNumberDto
Deserialize a JSON object to an instance of CreateByoPhoneNumberDto
129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 |
# File 'lib/vapi_server_sdk/types/create_byo_phone_number_dto.rb', line 129 def self.from_json(json_object:) struct = JSON.parse(json_object, object_class: OpenStruct) parsed_json = JSON.parse(json_object) if parsed_json["fallbackDestination"].nil? fallback_destination = nil else fallback_destination = parsed_json["fallbackDestination"].to_json fallback_destination = Vapi::CreateByoPhoneNumberDtoFallbackDestination.from_json(json_object: fallback_destination) end number_e_164_check_enabled = parsed_json["numberE164CheckEnabled"] number = parsed_json["number"] credential_id = parsed_json["credentialId"] name = parsed_json["name"] assistant_id = parsed_json["assistantId"] squad_id = parsed_json["squadId"] if parsed_json["server"].nil? server = nil else server = parsed_json["server"].to_json server = Vapi::Server.from_json(json_object: server) end new( fallback_destination: fallback_destination, number_e_164_check_enabled: number_e_164_check_enabled, number: number, credential_id: credential_id, name: name, assistant_id: assistant_id, squad_id: squad_id, server: server, additional_properties: struct ) end |
.validate_raw(obj:) ⇒ Void
Leveraged for Union-type generation, validate_raw attempts to parse the given hash and check each fields type against the current object's property definitions.
176 177 178 179 180 181 182 183 184 185 |
# File 'lib/vapi_server_sdk/types/create_byo_phone_number_dto.rb', line 176 def self.validate_raw(obj:) obj.fallback_destination.nil? || Vapi::CreateByoPhoneNumberDtoFallbackDestination.validate_raw(obj: obj.fallback_destination) obj.number_e_164_check_enabled&.is_a?(Boolean) != false || raise("Passed value for field obj.number_e_164_check_enabled is not the expected type, validation failed.") obj.number&.is_a?(String) != false || raise("Passed value for field obj.number is not the expected type, validation failed.") obj.credential_id.is_a?(String) != false || raise("Passed value for field obj.credential_id is not the expected type, validation failed.") obj.name&.is_a?(String) != false || raise("Passed value for field obj.name is not the expected type, validation failed.") obj.assistant_id&.is_a?(String) != false || raise("Passed value for field obj.assistant_id is not the expected type, validation failed.") obj.squad_id&.is_a?(String) != false || raise("Passed value for field obj.squad_id is not the expected type, validation failed.") obj.server.nil? || Vapi::Server.validate_raw(obj: obj.server) end |
Instance Method Details
#to_json(*_args) ⇒ String
Serialize an instance of CreateByoPhoneNumberDto to a JSON object
166 167 168 |
# File 'lib/vapi_server_sdk/types/create_byo_phone_number_dto.rb', line 166 def to_json(*_args) @_field_set&.to_json end |