Class: Vapi::CreateVonagePhoneNumberDto
- Inherits:
-
Object
- Object
- Vapi::CreateVonagePhoneNumberDto
- Defined in:
- lib/vapi_server_sdk/types/create_vonage_phone_number_dto.rb
Constant Summary collapse
- OMIT =
Object.new
Instance Attribute Summary collapse
-
#additional_properties ⇒ OpenStruct
readonly
Additional properties unmapped to the current class definition.
-
#assistant_id ⇒ String
readonly
This is the assistant that will be used for incoming calls to this phone number.
-
#credential_id ⇒ String
readonly
This is the credential that is used to make outgoing calls, and do operations like call transfer and hang up.
-
#fallback_destination ⇒ Vapi::CreateVonagePhoneNumberDtoFallbackDestination
readonly
This is the fallback destination an inbound call will be transferred to if: 1.
-
#name ⇒ String
readonly
This is the name of the phone number.
-
#number ⇒ String
readonly
These are the digits of the phone number you own on your Vonage.
-
#server ⇒ Vapi::Server
readonly
This is where Vapi will send webhooks.
-
#squad_id ⇒ String
readonly
This is the squad that will be used for incoming calls to this phone number.
Class Method Summary collapse
-
.from_json(json_object:) ⇒ Vapi::CreateVonagePhoneNumberDto
Deserialize a JSON object to an instance of CreateVonagePhoneNumberDto.
-
.validate_raw(obj:) ⇒ Void
Leveraged for Union-type generation, validate_raw attempts to parse the given hash and check each fields type against the current object's property definitions.
Instance Method Summary collapse
- #initialize(number:, credential_id:, fallback_destination: OMIT, name: OMIT, assistant_id: OMIT, squad_id: OMIT, server: OMIT, additional_properties: nil) ⇒ Vapi::CreateVonagePhoneNumberDto constructor
-
#to_json(*_args) ⇒ String
Serialize an instance of CreateVonagePhoneNumberDto to a JSON object.
Constructor Details
#initialize(number:, credential_id:, fallback_destination: OMIT, name: OMIT, assistant_id: OMIT, squad_id: OMIT, server: OMIT, additional_properties: nil) ⇒ Vapi::CreateVonagePhoneNumberDto
75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 |
# File 'lib/vapi_server_sdk/types/create_vonage_phone_number_dto.rb', line 75 def initialize(number:, credential_id:, fallback_destination: OMIT, name: OMIT, assistant_id: OMIT, squad_id: OMIT, server: OMIT, additional_properties: nil) @fallback_destination = fallback_destination if fallback_destination != OMIT @number = number @credential_id = credential_id @name = name if name != OMIT @assistant_id = assistant_id if assistant_id != OMIT @squad_id = squad_id if squad_id != OMIT @server = server if server != OMIT @additional_properties = additional_properties @_field_set = { "fallbackDestination": fallback_destination, "number": number, "credentialId": credential_id, "name": name, "assistantId": assistant_id, "squadId": squad_id, "server": server }.reject do |_k, v| v == OMIT end end |
Instance Attribute Details
#additional_properties ⇒ OpenStruct (readonly)
Returns Additional properties unmapped to the current class definition.
42 43 44 |
# File 'lib/vapi_server_sdk/types/create_vonage_phone_number_dto.rb', line 42 def additional_properties @additional_properties end |
#assistant_id ⇒ String (readonly)
Returns This is the assistant that will be used for incoming calls to this phone number.
If neither assistantId nor squadId is set, assistant-request will be sent
to your Server URL. Check ServerMessage and ServerMessageResponse for the
shape of the message and response that is expected.
28 29 30 |
# File 'lib/vapi_server_sdk/types/create_vonage_phone_number_dto.rb', line 28 def assistant_id @assistant_id end |
#credential_id ⇒ String (readonly)
Returns This is the credential that is used to make outgoing calls, and do operations like call transfer and hang up.
21 22 23 |
# File 'lib/vapi_server_sdk/types/create_vonage_phone_number_dto.rb', line 21 def credential_id @credential_id end |
#fallback_destination ⇒ Vapi::CreateVonagePhoneNumberDtoFallbackDestination (readonly)
Returns This is the fallback destination an inbound call will be transferred to if:
assistantIdis not setsquadIdis not set- and,
assistant-requestmessage to theserverUrlfails If this is not set and above conditions are met, the inbound call is hung up with an error message.
16 17 18 |
# File 'lib/vapi_server_sdk/types/create_vonage_phone_number_dto.rb', line 16 def fallback_destination @fallback_destination end |
#name ⇒ String (readonly)
Returns This is the name of the phone number. This is just for your own reference.
23 24 25 |
# File 'lib/vapi_server_sdk/types/create_vonage_phone_number_dto.rb', line 23 def name @name end |
#number ⇒ String (readonly)
Returns These are the digits of the phone number you own on your Vonage.
18 19 20 |
# File 'lib/vapi_server_sdk/types/create_vonage_phone_number_dto.rb', line 18 def number @number end |
#server ⇒ Vapi::Server (readonly)
Returns This is where Vapi will send webhooks. You can find all webhooks available along with their shape in ServerMessage schema. The order of precedence is:
- assistant.server
- phoneNumber.server
- org.server.
40 41 42 |
# File 'lib/vapi_server_sdk/types/create_vonage_phone_number_dto.rb', line 40 def server @server end |
#squad_id ⇒ String (readonly)
Returns This is the squad that will be used for incoming calls to this phone number.
If neither assistantId nor squadId is set, assistant-request will be sent
to your Server URL. Check ServerMessage and ServerMessageResponse for the
shape of the message and response that is expected.
33 34 35 |
# File 'lib/vapi_server_sdk/types/create_vonage_phone_number_dto.rb', line 33 def squad_id @squad_id end |
Class Method Details
.from_json(json_object:) ⇒ Vapi::CreateVonagePhoneNumberDto
Deserialize a JSON object to an instance of CreateVonagePhoneNumberDto
102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 |
# File 'lib/vapi_server_sdk/types/create_vonage_phone_number_dto.rb', line 102 def self.from_json(json_object:) struct = JSON.parse(json_object, object_class: OpenStruct) parsed_json = JSON.parse(json_object) if parsed_json["fallbackDestination"].nil? fallback_destination = nil else fallback_destination = parsed_json["fallbackDestination"].to_json fallback_destination = Vapi::CreateVonagePhoneNumberDtoFallbackDestination.from_json(json_object: fallback_destination) end number = parsed_json["number"] credential_id = parsed_json["credentialId"] name = parsed_json["name"] assistant_id = parsed_json["assistantId"] squad_id = parsed_json["squadId"] if parsed_json["server"].nil? server = nil else server = parsed_json["server"].to_json server = Vapi::Server.from_json(json_object: server) end new( fallback_destination: fallback_destination, number: number, credential_id: credential_id, name: name, assistant_id: assistant_id, squad_id: squad_id, server: server, additional_properties: struct ) end |
.validate_raw(obj:) ⇒ Void
Leveraged for Union-type generation, validate_raw attempts to parse the given hash and check each fields type against the current object's property definitions.
147 148 149 150 151 152 153 154 155 |
# File 'lib/vapi_server_sdk/types/create_vonage_phone_number_dto.rb', line 147 def self.validate_raw(obj:) obj.fallback_destination.nil? || Vapi::CreateVonagePhoneNumberDtoFallbackDestination.validate_raw(obj: obj.fallback_destination) obj.number.is_a?(String) != false || raise("Passed value for field obj.number is not the expected type, validation failed.") obj.credential_id.is_a?(String) != false || raise("Passed value for field obj.credential_id is not the expected type, validation failed.") obj.name&.is_a?(String) != false || raise("Passed value for field obj.name is not the expected type, validation failed.") obj.assistant_id&.is_a?(String) != false || raise("Passed value for field obj.assistant_id is not the expected type, validation failed.") obj.squad_id&.is_a?(String) != false || raise("Passed value for field obj.squad_id is not the expected type, validation failed.") obj.server.nil? || Vapi::Server.validate_raw(obj: obj.server) end |
Instance Method Details
#to_json(*_args) ⇒ String
Serialize an instance of CreateVonagePhoneNumberDto to a JSON object
137 138 139 |
# File 'lib/vapi_server_sdk/types/create_vonage_phone_number_dto.rb', line 137 def to_json(*_args) @_field_set&.to_json end |