Class: Vapi::TextEditorTool
- Inherits:
-
Object
- Object
- Vapi::TextEditorTool
- Defined in:
- lib/vapi_server_sdk/types/text_editor_tool.rb
Constant Summary collapse
- OMIT =
Object.new
Instance Attribute Summary collapse
-
#additional_properties ⇒ OpenStruct
readonly
Additional properties unmapped to the current class definition.
-
#async ⇒ Boolean
readonly
This determines if the tool is async.
-
#created_at ⇒ DateTime
readonly
This is the ISO 8601 date-time string of when the tool was created.
-
#function ⇒ Vapi::OpenAiFunction
readonly
This is the function definition of the tool.
-
#id ⇒ String
readonly
This is the unique identifier for the tool.
-
#messages ⇒ Array<Vapi::TextEditorToolMessagesItem>
readonly
These are the messages that will be spoken to the user as the tool is running.
-
#name ⇒ String
readonly
The name of the tool, fixed to ‘str_replace_editor’.
-
#org_id ⇒ String
readonly
This is the unique identifier for the organization that this tool belongs to.
-
#server ⇒ Vapi::Server
readonly
This is the server that will be hit when this tool is requested by the model.
-
#sub_type ⇒ String
readonly
The sub type of tool.
-
#updated_at ⇒ DateTime
readonly
This is the ISO 8601 date-time string of when the tool was last updated.
Class Method Summary collapse
-
.from_json(json_object:) ⇒ Vapi::TextEditorTool
Deserialize a JSON object to an instance of TextEditorTool.
-
.validate_raw(obj:) ⇒ Void
Leveraged for Union-type generation, validate_raw attempts to parse the given hash and check each fields type against the current object’s property definitions.
Instance Method Summary collapse
- #initialize(sub_type:, id:, org_id:, created_at:, updated_at:, name:, async: OMIT, messages: OMIT, function: OMIT, server: OMIT, additional_properties: nil) ⇒ Vapi::TextEditorTool constructor
-
#to_json(*_args) ⇒ String
Serialize an instance of TextEditorTool to a JSON object.
Constructor Details
#initialize(sub_type:, id:, org_id:, created_at:, updated_at:, name:, async: OMIT, messages: OMIT, function: OMIT, server: OMIT, additional_properties: nil) ⇒ Vapi::TextEditorTool
94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 |
# File 'lib/vapi_server_sdk/types/text_editor_tool.rb', line 94 def initialize(sub_type:, id:, org_id:, created_at:, updated_at:, name:, async: OMIT, messages: OMIT, function: OMIT, server: OMIT, additional_properties: nil) @async = async if async != OMIT @messages = if != OMIT @sub_type = sub_type @id = id @org_id = org_id @created_at = created_at @updated_at = updated_at @function = function if function != OMIT @server = server if server != OMIT @name = name @additional_properties = additional_properties @_field_set = { "async": async, "messages": , "subType": sub_type, "id": id, "orgId": org_id, "createdAt": created_at, "updatedAt": updated_at, "function": function, "server": server, "name": name }.reject do |_k, v| v == OMIT end end |
Instance Attribute Details
#additional_properties ⇒ OpenStruct (readonly)
Returns Additional properties unmapped to the current class definition.
54 55 56 |
# File 'lib/vapi_server_sdk/types/text_editor_tool.rb', line 54 def additional_properties @additional_properties end |
#async ⇒ Boolean (readonly)
Returns This determines if the tool is async. If async, the assistant will move forward without waiting for your server to respond. This is useful if you just want to trigger something on your server. If sync, the assistant will wait for your server to respond. This is useful if want assistant to respond with the result from your server. Defaults to synchronous (false).
18 19 20 |
# File 'lib/vapi_server_sdk/types/text_editor_tool.rb', line 18 def async @async end |
#created_at ⇒ DateTime (readonly)
Returns This is the ISO 8601 date-time string of when the tool was created.
31 32 33 |
# File 'lib/vapi_server_sdk/types/text_editor_tool.rb', line 31 def created_at @created_at end |
#function ⇒ Vapi::OpenAiFunction (readonly)
Returns This is the function definition of the tool. For endCall, transferCall, and dtmf tools, this is auto-filled based on tool-specific fields like tool.destinations. But, even in those cases, you can provide a custom function definition for advanced use cases. An example of an advanced use case is if you want to customize the message that’s spoken for endCall tool. You can specify a function where it returns an argument “reason”. Then, in messages array, you can have many “request-complete” messages. One of these messages will be triggered if the messages[].conditions matches the “reason” argument.
43 44 45 |
# File 'lib/vapi_server_sdk/types/text_editor_tool.rb', line 43 def function @function end |
#id ⇒ String (readonly)
Returns This is the unique identifier for the tool.
27 28 29 |
# File 'lib/vapi_server_sdk/types/text_editor_tool.rb', line 27 def id @id end |
#messages ⇒ Array<Vapi::TextEditorToolMessagesItem> (readonly)
Returns These are the messages that will be spoken to the user as the tool is running. For some tools, this is auto-filled based on special fields like tool.destinations. For others like the function tool, these can be custom configured.
23 24 25 |
# File 'lib/vapi_server_sdk/types/text_editor_tool.rb', line 23 def @messages end |
#name ⇒ String (readonly)
Returns The name of the tool, fixed to ‘str_replace_editor’.
52 53 54 |
# File 'lib/vapi_server_sdk/types/text_editor_tool.rb', line 52 def name @name end |
#org_id ⇒ String (readonly)
Returns This is the unique identifier for the organization that this tool belongs to.
29 30 31 |
# File 'lib/vapi_server_sdk/types/text_editor_tool.rb', line 29 def org_id @org_id end |
#server ⇒ Vapi::Server (readonly)
Returns This is the server that will be hit when this tool is requested by the model. All requests will be sent with the call object among other things. You can find more details in the Server URL documentation. This overrides the serverUrl set on the org and the phoneNumber. Order of precedence: highest tool.server.url, then assistant.serverUrl, then phoneNumber.serverUrl, then org.serverUrl.
50 51 52 |
# File 'lib/vapi_server_sdk/types/text_editor_tool.rb', line 50 def server @server end |
#sub_type ⇒ String (readonly)
Returns The sub type of tool.
25 26 27 |
# File 'lib/vapi_server_sdk/types/text_editor_tool.rb', line 25 def sub_type @sub_type end |
#updated_at ⇒ DateTime (readonly)
Returns This is the ISO 8601 date-time string of when the tool was last updated.
33 34 35 |
# File 'lib/vapi_server_sdk/types/text_editor_tool.rb', line 33 def updated_at @updated_at end |
Class Method Details
.from_json(json_object:) ⇒ Vapi::TextEditorTool
Deserialize a JSON object to an instance of TextEditorTool
127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 |
# File 'lib/vapi_server_sdk/types/text_editor_tool.rb', line 127 def self.from_json(json_object:) struct = JSON.parse(json_object, object_class: OpenStruct) parsed_json = JSON.parse(json_object) async = parsed_json["async"] = parsed_json["messages"]&.map do |item| item = item.to_json Vapi::TextEditorToolMessagesItem.from_json(json_object: item) end sub_type = parsed_json["subType"] id = parsed_json["id"] org_id = parsed_json["orgId"] created_at = (DateTime.parse(parsed_json["createdAt"]) unless parsed_json["createdAt"].nil?) updated_at = (DateTime.parse(parsed_json["updatedAt"]) unless parsed_json["updatedAt"].nil?) if parsed_json["function"].nil? function = nil else function = parsed_json["function"].to_json function = Vapi::OpenAiFunction.from_json(json_object: function) end if parsed_json["server"].nil? server = nil else server = parsed_json["server"].to_json server = Vapi::Server.from_json(json_object: server) end name = parsed_json["name"] new( async: async, messages: , sub_type: sub_type, id: id, org_id: org_id, created_at: created_at, updated_at: updated_at, function: function, server: server, name: name, additional_properties: struct ) end |
.validate_raw(obj:) ⇒ Void
Leveraged for Union-type generation, validate_raw attempts to parse the given
hash and check each fields type against the current object's property
definitions.
181 182 183 184 185 186 187 188 189 190 191 192 |
# File 'lib/vapi_server_sdk/types/text_editor_tool.rb', line 181 def self.validate_raw(obj:) obj.async&.is_a?(Boolean) != false || raise("Passed value for field obj.async is not the expected type, validation failed.") obj.&.is_a?(Array) != false || raise("Passed value for field obj.messages is not the expected type, validation failed.") obj.sub_type.is_a?(String) != false || raise("Passed value for field obj.sub_type is not the expected type, validation failed.") obj.id.is_a?(String) != false || raise("Passed value for field obj.id is not the expected type, validation failed.") obj.org_id.is_a?(String) != false || raise("Passed value for field obj.org_id is not the expected type, validation failed.") obj.created_at.is_a?(DateTime) != false || raise("Passed value for field obj.created_at is not the expected type, validation failed.") obj.updated_at.is_a?(DateTime) != false || raise("Passed value for field obj.updated_at is not the expected type, validation failed.") obj.function.nil? || Vapi::OpenAiFunction.validate_raw(obj: obj.function) obj.server.nil? || Vapi::Server.validate_raw(obj: obj.server) obj.name.is_a?(String) != false || raise("Passed value for field obj.name is not the expected type, validation failed.") end |
Instance Method Details
#to_json(*_args) ⇒ String
Serialize an instance of TextEditorTool to a JSON object
171 172 173 |
# File 'lib/vapi_server_sdk/types/text_editor_tool.rb', line 171 def to_json(*_args) @_field_set&.to_json end |