Class: Vapi::TrieveKnowledgeBaseCreate
- Inherits:
-
Object
- Object
- Vapi::TrieveKnowledgeBaseCreate
- Defined in:
- lib/vapi_server_sdk/types/trieve_knowledge_base_create.rb
Constant Summary collapse
- OMIT =
Object.new
Instance Attribute Summary collapse
-
#additional_properties ⇒ OpenStruct
readonly
Additional properties unmapped to the current class definition.
-
#chunk_plans ⇒ Array<Vapi::TrieveKnowledgeBaseChunkPlan>
readonly
These are the chunk plans used to create the dataset.
Class Method Summary collapse
-
.from_json(json_object:) ⇒ Vapi::TrieveKnowledgeBaseCreate
Deserialize a JSON object to an instance of TrieveKnowledgeBaseCreate.
-
.validate_raw(obj:) ⇒ Void
Leveraged for Union-type generation, validate_raw attempts to parse the given hash and check each fields type against the current object's property definitions.
Instance Method Summary collapse
- #initialize(chunk_plans:, additional_properties: nil) ⇒ Vapi::TrieveKnowledgeBaseCreate constructor
-
#to_json(*_args) ⇒ String
Serialize an instance of TrieveKnowledgeBaseCreate to a JSON object.
Constructor Details
#initialize(chunk_plans:, additional_properties: nil) ⇒ Vapi::TrieveKnowledgeBaseCreate
22 23 24 25 26 |
# File 'lib/vapi_server_sdk/types/trieve_knowledge_base_create.rb', line 22 def initialize(chunk_plans:, additional_properties: nil) @chunk_plans = chunk_plans @additional_properties = additional_properties @_field_set = { "chunkPlans": chunk_plans } end |
Instance Attribute Details
#additional_properties ⇒ OpenStruct (readonly)
Returns Additional properties unmapped to the current class definition.
12 13 14 |
# File 'lib/vapi_server_sdk/types/trieve_knowledge_base_create.rb', line 12 def additional_properties @additional_properties end |
#chunk_plans ⇒ Array<Vapi::TrieveKnowledgeBaseChunkPlan> (readonly)
Returns These are the chunk plans used to create the dataset.
10 11 12 |
# File 'lib/vapi_server_sdk/types/trieve_knowledge_base_create.rb', line 10 def chunk_plans @chunk_plans end |
Class Method Details
.from_json(json_object:) ⇒ Vapi::TrieveKnowledgeBaseCreate
Deserialize a JSON object to an instance of TrieveKnowledgeBaseCreate
32 33 34 35 36 37 38 39 40 |
# File 'lib/vapi_server_sdk/types/trieve_knowledge_base_create.rb', line 32 def self.from_json(json_object:) struct = JSON.parse(json_object, object_class: OpenStruct) parsed_json = JSON.parse(json_object) chunk_plans = parsed_json["chunkPlans"]&.map do |item| item = item.to_json Vapi::TrieveKnowledgeBaseChunkPlan.from_json(json_object: item) end new(chunk_plans: chunk_plans, additional_properties: struct) end |
.validate_raw(obj:) ⇒ Void
Leveraged for Union-type generation, validate_raw attempts to parse the given hash and check each fields type against the current object's property definitions.
55 56 57 |
# File 'lib/vapi_server_sdk/types/trieve_knowledge_base_create.rb', line 55 def self.validate_raw(obj:) obj.chunk_plans.is_a?(Array) != false || raise("Passed value for field obj.chunk_plans is not the expected type, validation failed.") end |
Instance Method Details
#to_json(*_args) ⇒ String
Serialize an instance of TrieveKnowledgeBaseCreate to a JSON object
45 46 47 |
# File 'lib/vapi_server_sdk/types/trieve_knowledge_base_create.rb', line 45 def to_json(*_args) @_field_set&.to_json end |