Class: Vapi::Types::ServerMessageMessage

Inherits:
Internal::Types::Model show all
Extended by:
Internal::Types::Union
Defined in:
lib/vapi/types/server_message_message.rb

Overview

These are all the messages that can be sent to your server before, after and during the call. Configure the messages you’d like to receive in ‘assistant.serverMessages`.

The server where the message is sent is determined by the following precedence order:

  1. ‘tool.server.url` (if configured, and only for “tool-calls” message)

  2. ‘assistant.serverUrl` (if configure)

  3. ‘phoneNumber.serverUrl` (if configured)

  4. ‘org.serverUrl` (if configured)

Method Summary

Methods included from Internal::Types::Union

coerce, discriminant, load, member, members, type_member?

Methods included from Internal::Types::Type

#coerce, #strict!, #strict?

Methods included from Internal::JSON::Serializable

#dump, #load

Methods inherited from Internal::Types::Model

#==, ===, add_extra_field_definition, coerce, extra_fields, field, fields, #initialize, #inspect, literal, load, #to_h

Constructor Details

This class inherits a constructor from Vapi::Internal::Types::Model